<?PHP
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

// V 1.0 First release
// V 1.0.1 Install-functions file includes
// V 1.0.2 Mod for module-dir outsourcing
// V 1.0.3 Mod of includes
// V 1.0.4 Includes reordered
// V 1.1.0 Total recode
// V 1.1.1 Some minor improvements
// V 1.1.2 Changed https detection
// V 1.2 Global mods for CMM3 V6
///////////////////////////////////////////////////////////////

mb_internal_encoding("UTF-8");
ini_set('display_errors', true);
error_reporting(7); // 7 = Warnungen, 8 = alle


// Get loaction of current script
$GLOBALS['isBackend'] = true;
$rootUrl = ((empty($_SERVER['HTTPS']) || stristr($_SERVER['HTTPS'],'off')) ? 'http' : 'https').'://'.$_SERVER['HTTP_HOST'].rtrim(dirname(dirname($_SERVER['PHP_SELF'])),'/\\').'/';
$rootDir = rtrim(dirname(dirname($_SERVER['SCRIPT_FILENAME'])),'/\\').'/';
define('CMM_ROOT_URL',$rootUrl);
define('CMM_ROOT_DIR',$rootDir);


//////////////////////////////////////////////////////////////////
// STANDARD INCLUDES                                            //
//////////////////////////////////////////////////////////////////
require_once(CMM_ROOT_DIR.'CMM/functions/functions-common.php');
require_once(CMM_ROOT_DIR.'CMM/functions/functions-admin.php');
require_once(CMM_ROOT_DIR.'CMM/functions/functions-admin-gui.php');
require_once(CMM_ROOT_DIR.'CMM/functions/functions-admin-input.php');
require_once(CMM_ROOT_DIR.'CMM/functions/functions-admin-sql.php');
require_once(CMM_ROOT_DIR.'CMM/functions/functions-admin-files.php');

require_once(CMM_ROOT_DIR.'CMM/classes/class.template.php');
require_once(CMM_ROOT_DIR.'CMM/classes/class.plugin.php');
require_once(CMM_ROOT_DIR.'CMM/classes/class.image.php');
require_once(CMM_ROOT_DIR.'CMM/classes/class.cache.php');

require_once(CMM_ROOT_DIR.'CMM/incl/connect.php');
require_once(CMM_ROOT_DIR.'CMM/incl/session-admin.php');

// Include config
require_once(CMM_ROOT_DIR.'config.php');
CMM_connectDB();
CMM_getCustomConfig();
require_once(CMM_ROOT_DIR.'CMM/config.php');
require_once(CMM_ROOT_DIR.'CMM/structure.php');
if(!empty($CUSTOM['CMM']))
	{ $CONFIG['CMM'] = array_replace_recursive($CONFIG['CMM'],$CUSTOM['CMM']); }

// Run initial functions
CMM_checkEnv();
CMM_setGlobals();
CMM_setConstants();


///////////////////////////////////////////////////////////////////
// BASIC-CMS_NAME-SETTINGS                                       //
///////////////////////////////////////////////////////////////////
empty($CONFIG['CMM']['BE']['label']) ? $CONFIG['CMM']['BE']['label'] = 'CMM3' : '';
empty($CONFIG['CMM']['BE']['logo']) ? $CONFIG['CMM']['BE']['logo'] = 'skins/{CMM_SKIN}/pix/logo.svg' : '';
empty($CONFIG['CMM']['BE']['copyright']) ? $CONFIG['CMM']['BE']['copyright'] = 'CMM3 CMS-Framework - Version '.$CONFIG['CMM']['version'].' &bull; Copyright © 2009-'.date('Y').' Nicolas Berg<br> Erweiterungen sind Eigentum ihrer Autoren. Sie nutzen diese Software OHNE GEWÄHRLEISTUNG. <br>Das Erscheinen dieses Hinweises zu verhindern, ist ein Verstoß gegen die Nutzungsbedingungen.' : '';


///////////////////////////////////////////////////////////////////
// CHECK CURRENT LOGIN/LOGOUT-ACTION                             //
///////////////////////////////////////////////////////////////////
$loginStatus = CMM_userCheckLoginStatus();


//////////////////////////////////////////////////////////////////
// ANZEIGEMODUS                                                 //
//////////////////////////////////////////////////////////////////
$backendMode = CMM_userSetBackendMode();


//////////////////////////////////////////////////////////////////
// SKIN FUER USER AUSWAEHLEN                                    //
//////////////////////////////////////////////////////////////////
$backendSkin = CMM_setBackendSkin();


//////////////////////////////////////////////////////////////////
// VERFUEGBARE MODULE AUFLISTEN                                 //
//////////////////////////////////////////////////////////////////
$modulesExisting = CMM_getModulesExisting();
$modulesInstalled = CMM_getModulesInstalled($modulesExisting);
$modulesAllowed = CMM_getModulesAllowed($modulesInstalled);


///////////////////////////////////////////////////////////////////
// GET CONFIG AND STRUCTURE OF OTHER MODULES                     //
///////////////////////////////////////////////////////////////////
if($loginStatus == true)
	{
	foreach($modulesInstalled as $module)
		{
		// Skip basic module
		if($module == 'CMM')
			{ continue; }
		// Get config
		if(file_exists(CMM_ROOT_DIR.$module.'/config.php'))
			{ include_once(CMM_ROOT_DIR.$module.'/config.php'); }
		// Get structure
		if(file_exists(CMM_ROOT_DIR.$module.'/structure.php'))
			{ include_once(CMM_ROOT_DIR.$module.'/structure.php'); }
		// Overrride global with local config
		if(!empty($CUSTOM[$module]))
			{ $CONFIG[$module] = array_replace_recursive($CONFIG[$module],$CUSTOM[$module]); }
		}
	}


///////////////////////////////////////////////////////////////////
// GET PHP-INCLUDES OF BASIC- AND CURRENT MODULE                 //
///////////////////////////////////////////////////////////////////
// Get modules
if($loginStatus == true && $CURRENT['module'] == 'CMM')
	{ $modulesIncludePHP = $modulesExisting; }
else if($loginStatus == true)
	{ $modulesIncludePHP = array('CMM',$CURRENT['module']); }
else
	{ $modulesIncludePHP = array('CMM'); }

// Include files
foreach($modulesIncludePHP as $module)
	{
	if(!empty($CONFIG[$module]['BE']['include']['PHP']))
		{
		foreach($CONFIG[$module]['BE']['include']['PHP'] as $includeFile)
			{
			if(file_exists(CMM_ROOT_DIR.$includeFile))
				{ include_once(CMM_ROOT_DIR.$includeFile); }
			else
				{ CMM_setMessage(LANG_CMM_INCLUDE_FILE_NOT_FOUND.' '.CMM_ROOT_DIR.$includeFile,'error','big'); }
			}
		}
	}


//////////////////////////////////////////////////////////////////
// INCLUDE LANGUAGE-FILES                                       //
//////////////////////////////////////////////////////////////////
// Get modules
if($loginStatus == true)
	{ $modulesIncludeLang = $modulesInstalled; }
else
	{ $modulesIncludeLang = array('CMM'); }

// Include files
foreach($modulesIncludeLang as $module)
	{ CMM_includeLanguageFile($module,'admin'); }

// Get default language
if($loginStatus == true && empty($_SESSION['defaultLanguage']))
	{ $_SESSION['defaultLanguage'] = $CURRENT['languageDefault'] = CMM_getDefaultLanguage(); }



//////////////////////////////////////////////////////////////////
// INCLUDE CSS AND JS                                           //
//////////////////////////////////////////////////////////////////
// Get modules
if($loginStatus == true && $CURRENT['module'] != 'CMM')
	{ $modulesIncludeCssJs = array('CMM',$CURRENT['module']); }
else
	{ $modulesIncludeCssJs = array('CMM'); }

// Include files
$tempHeadCSS = '';
$tempHeadJS = '';
foreach($modulesIncludeCssJs as $module)
	{
	// CSS-files of module
	if(!empty($CONFIG[$module]['BE']['include']['CSS']))
		{
		foreach($CONFIG[$module]['BE']['include']['CSS'] as $includeFile)
			{
			$includeFile = str_replace('{CMM_SKIN}',CMM_SKIN,$includeFile);
			// External file
			if(strstr($includeFile,'://') || substr($includeFile,0,2)=='//')
				{ $tempHeadCSS.= '<link href="'.$includeFile.'" rel="stylesheet" type="text/css" />'.PHP_EOL; }
			// Internal file
			else if(file_exists(CMM_ROOT_DIR.$includeFile))
				{ $tempHeadCSS.= '<link href="../'.$includeFile.'" rel="stylesheet" type="text/css" />'.PHP_EOL; }
			}
		}

	// JS-files of module
	if(!empty($CONFIG[$module]['BE']['include']['JS']))
		{
		foreach($CONFIG[$module]['BE']['include']['JS'] as $includeFile)
			{
			$includeFile = str_replace('{CMM_SKIN}',CMM_SKIN,$includeFile);
			// External file
			if(strstr($includeFile,'://') || substr($includeFile,0,2)=='//')
				{ $tempHeadCSS.= '<script type="text/javascript" src="'.$includeFile.'"></script>'.PHP_EOL; }
			// Internal file
			else if(file_exists(CMM_ROOT_DIR.$includeFile))
				{ $tempHeadJS.= '<script type="text/javascript" src="../'.$includeFile.'"></script>'.PHP_EOL; }
			}
		}
	}



///////////////////////////////////////////////////////////////////
// PREPARE OUTPUT                                                //
///////////////////////////////////////////////////////////////////
$globalOutput = array();
// CURRENT-Variable
$globalOutput['CURRENT'] = $CURRENT;
// CMS-Name
$globalOutput['Label'] = $CONFIG['CMM']['BE']['label'];
// CMS-Logo
$globalOutput['Logo'] = $CONFIG['CMM']['BE']['logo'];
// CSS
$globalOutput['HeadCSS'] = $tempHeadCSS;
// JS
$globalOutput['HeadJS'] = $tempHeadJS;


///////////////////////////////////////////////////////////////////
// Ausgewaehltes Modul integrieren                               //
///////////////////////////////////////////////////////////////////
// Modul-Ausgabe in $moduleContent
if(!empty($CURRENT['module']))
	{
	if(file_exists(CMM_ROOT_DIR.$CURRENT['module'].'/admin.php'))
		{ include_once(CMM_ROOT_DIR.$CURRENT['module'].'/admin.php'); }

	// Get global messages
	$globalOutput['message'] = CMM_getAllMessages();

	// deprecated
	$globalOutput['ModuleContent'] = $moduleContent;
	// current
	$globalOutput['ColumnPlaygroundHead'] = $columnPlaygroundHead;
	$globalOutput['ColumnPlaygroundContent'] = $columnPlaygroundContent;
	}


///////////////////////////////////////////////////////////////////
// ADMIN-ANZEIGE (wenn Login erfolgreich)                        //
///////////////////////////////////////////////////////////////////
if($loginStatus == true)
	{
	// Template fuer Hauptansicht
	$loginPageObj = new Template;
//	$loginPageObj->setTemplateStringFromFile(CMM_ROOT_DIR.'CMM/skins/'.CMM_SKIN.'/html/main.html');
	$loginPageObj->setTemplateString('{$ModuleContent}{$ColumnPlaygroundHead}{$message}{$ColumnPlaygroundContent}');
	$loginPageObj->input = $globalOutput;

	echo $loginPageObj->templateIt();
	}
else
	{
	echo '
	<h3>Achtung</h3>
	<p>Ihr Login ist abgelaufen<br />
	<a href="index.php">Bitte loggen Sie sich neu ein.</a></p>';
	}
?>