/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////////
// V 1.0 First release
// V 1.1 Div. mod.
///////////////////////////////////////////////////////////////


function CMM_ajaxProgressBarStart()
	{
	$("#progress").animate({'width':'50%'},500,'easeOutQuad',function() {
		});
	}


///////////////////////////////////////////////////////////////


function CMM_ajaxProgressBarFinish()
	{
	$("#progress").stop().animate({'width':'100%'},500,'easeInQuad',function() {
		CMM_ajaxProgressBarReset();
		});
	}


///////////////////////////////////////////////////////////////


function CMM_ajaxProgressBarReset()
	{
	$("#progress").stop();
	setTimeout(function() {
		$("#progress").fadeOut(function() {
			$(this).css({'width':0,'display':'block'});
			});
		}, 250);
	}


///////////////////////////////////////////////////////////////


function CMM_ajaxLoadAdminSection(element,href)
	{
	if($(element).length && href!='')
		{
		// Start progress-bar
		CMM_ajaxProgressBarStart();

		// Fade out content
		$(element).animate({'opacity':0},500,function() {
			// Make ajax request
			$.ajax({
				url: href,
				success: function(data) {
					// Get new content
					newData = $(data).find(element).contents();
					// Replace content with new content
					$(element).html(newData);
					// Fade in new content
					$(element).animate({'opacity':1},500);
					// Finish progress-bar
					CMM_ajaxProgressBarFinish();

					// Restart tooltip
					$('A[title], IMG[title], I[title], SPAN[title]','#contentContainer').tipTip({defaultPosition:'top', edgeOffset:5});
					// Restart context-menu
					$('.CMM_treeIcon','.CMM_adminTree').cmm3contextMenu({ menu:'#contextMenuTemplate', cmm_menuitems:'' });
					// Restart lightbox
					$("a.lightbox").colorbox({rel:$(this).attr('data-group'), maxWidth:'95%', maxHeight:'95%',previous:'&#xf053;' ,next:'&#xf054;' ,close:'&#xf00d;', current:'', slideshow:true, slideshowAuto:false, slideshowStart:'&#xf04b;' , slideshowStop:'&#xf04c;'});
					// Restart context-menu on file-list
					$('.fileicon','.CMM_filelist').cmm3contextMenu({ menu:'#contextMenuTemplate', leftButton:true, cmm_menuitems:'' });


					// Update history
					var pageObj = {};
					var title = $(document).find("title").text();
					if((window.history != null) && (window.history.pushState != null)) {
						return history.pushState(pageObj, title, href);
						}
					}
				});
			});
		}
	}


///////////////////////////////////////////////////////////////


// jQuery-Plugins starten
$(document).ready(function() {

	// Detect if ajax mode is enabled
	var ajaxEnabled = false;
	if($('BODY').data('beajax') && $('BODY').data('beajax') == 1)
		{
		var ajaxEnabled = true;
		console.log('BE-Ajax-Mode enabled.');
		}


	// Ajax load contentContainer
	if(ajaxEnabled == true)
		{
		$(document).on('click','#headLogo A, #headColumnLogo A, #headUserInfo A, .dashboardModules A, #CMM_mainNavi A',function(evt) { 
		    evt.preventDefault();
			var url = $(this).attr('href');
			CMM_ajaxLoadAdminSection('#contentContainer',url);
			});
		}


	// Language select
	if(ajaxEnabled == true)
		{
		$(document).on('change','#CMM_language',function(evt) {
			var url = $(this).closest('form').attr('action')+'?' + $(this).closest('form').serialize();
			CMM_ajaxLoadAdminSection('#contentContainer',url);
			});
		}
	else
		{
		$('#CMM_language').on('change',function(evt) { 
			$(this).closest('form').submit();
			});
		}


	// Show/hide forbidden files
	if(ajaxEnabled == true)
		{
		$(document).on('click','#showForbiddenFiles',function(evt) { 
			var url = $(this).closest('form').attr('action')+'?' + $(this).closest('form').serialize();
			CMM_ajaxLoadAdminSection('#contentContainer',url);
			});
		}
	else
		{
		$('#showForbiddenFiles').on('click',function(evt) { 
			$(this).closest('form').submit();
			});
		}


	// Ajax load playground
	if(ajaxEnabled == true)
		{
		// Tree column
		$(document).on('click','.CMM_sortBarContent A, .CMM_adminPageNaviPages A',function(evt) { 
			evt.preventDefault();
			CMM_ajaxLoadAdminSection('.contentColumnPlayground',$(this).attr('href'));
			});
		// Content column
		$(document).on('click','#CMM_adminPageTree A, #CMM_adminDirTree A',function(evt) { 
			evt.preventDefault();
			CMM_ajaxLoadAdminSection('.contentColumnPlayground',$(this).attr('href'));
			// Update selected tree item
			$('LI.cur','.CMM_adminTree').each(function() {
				$(this).removeClass('cur');
				$(this).find('UL').length > 0 ? $(this).addClass('act') : $(this).addClass('nor');
				});
			$(this).closest('LI').removeClass('nor act').addClass('cur');
			});
		}


	// Limit select
	if(ajaxEnabled == true)
		{
		$(document).on('change','#CMM_limit',function(evt) {
			// Send form
			var url = $(this).closest('form').attr('action')+'?' + $(this).closest('form').serialize();
			CMM_ajaxLoadAdminSection('.contentColumnPlayground',url);
			});
		}
	else
		{
		$('#CMM_limit').on('change',function(evt) {
			$(this).closest('form').submit();
			});
		}


	// Filter form - remove filter
	if(ajaxEnabled == true)
		{
		$(document).on('click','#CMM_filterForm .filterDelete',function(evt) {
			// Remove selection and value
			var tempFilterRow = $(this).closest('TR');
			$('SELECT,INPUT[type=text]',tempFilterRow).val('');
			// Send form
			var url = $(this).closest('FORM').attr('action')+'?' + $(this).closest('FORM').serialize();
			CMM_ajaxLoadAdminSection('.contentColumnPlayground',url);
			});
		}
	else
		{
		$('#CMM_filterForm .filterDelete').on('click',function(evt) {
			// Remove selection and value
			var tempFilterRow = $(this).closest('TR');
			$('SELECT,INPUT[type=text]',tempFilterRow).val('');
			$(this).closest('form').submit();
			});
		}


	// Filter form - submit
	if(ajaxEnabled == true)
		{
		$(document).on('submit','#CMM_filterForm',function(evt) {
			var filterForm = $(this);
		    evt.preventDefault();
			var url = filterForm.attr('action')+'?'+filterForm.serialize();
			CMM_ajaxLoadAdminSection('.contentColumnPlayground',url);
			});
		}


	// Filelist - subdirs
	if(ajaxEnabled == true)
		{
		// Filter form - remove filter
		$(document).on('click','.CMM_filelist A:not(.lightbox)',function(evt) {
		    evt.preventDefault();
			CMM_ajaxLoadAdminSection('.contentColumnPlayground',$(this).attr('href'));
			});
		}

	});
