/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////////
// V 1.0 First release
// ...
// V 1.7.0 CMM_showIconDialog() mod.
// V 1.7.1 CMM_showDirDialog() add.
// V 1.7.2 CMM_loadPageTreeSub(), CMM_loadDirTreeSub() mod.
// V 1.7.3 Modified RTE-init (visible/ivisible RTEs)
// V 1.7.4 CMM_inputShyfieldsShow() added and some live mods
// V 1.7.5 CMM_getCursorPosition() and CMM_setCursorPosition() added
// V 1.7.6 CMM_ajaxProgressBarStart() and CMM_ajaxProgressBarReset() added
// V 1.7.7 CMM_inputImageListDirectionsSelect() added
// V 1.7.8 CMM_formeditValidateFieldValues() mod for special-chars in labels/texts
// V 1.7.9 CMM_inputShyfieldsShow() and CMM_inputShyfieldsToggle() mod/add
// V 1.8.0 CMM_showColorDialog() recoded
// V 1.8.1 CMM_initRTE() outsourced as file CMM_initRTE.js.php
// V 1.8.2 CMM_showDialog() added
// V 1.8.3 CMM_configStringToObject() added
// V 1.8.4 CMM_inputCreateWordCounter() added
// V 1.8.5 Changes for cmm3contextMenu
// V 1.9 Placed some functions into separate files
// V 1.9.2 CMM_adminListToggleItem() and CMM_adminListToggleAll() added
// V 1.9.3 DIv. mod.
///////////////////////////////////////////////////////////////


// Detect the currently used browser
function CMM_getBrowser()
	{
	var browserString = '';

    // Opera 8+
	var isOpera = (!!window.opr && !!opr.addons) || !!window.opera || navigator.userAgent.indexOf(' OPR/') >= 0;
	// Firefox 1+
	var isFirefox = typeof InstallTrigger !== 'undefined';
	// At least Safari 3+: "[object HTMLElementConstructor]"
	var isSafari = Object.prototype.toString.call(window.HTMLElement).indexOf('Constructor') > 0;
	// Chrome 1+
	var isChrome = !!window.chrome && !!window.chrome.webstore;
	// Blink engine detection
	var isBlink = (isChrome || isOpera) && !!window.CSS;
	// Internet Explorer 6-11
	var isIE = /*@cc_on!@*/false || !!document.documentMode;
	// Edge 20+
	var isEdge = !isIE && !!window.StyleMedia;

	// Set browser-class in HTML-tag
	if(isOpera)
		{ browserString = "opera"; }
	if(isFirefox)
		{ browserString = "firefox"; }
	if(isSafari)
		{ browserString = "safari"; }
	if(isChrome)
		{ browserString = "chrome"; }
	if(isBlink)
		{ browserString+= " blink"; }

	if(isIE && $.browser.version == 6)
		{ browserString = "ie ie6"; }
	if(isIE && $.browser.version == 7)
		{ browserString = "ie ie7"; }
	if(isIE && $.browser.version == 8)
		{ browserString = "ie ie8"; }
	if(isIE && $.browser.version == 9)
		{ browserString = "ie ie9"; }
	if(isIE && $.browser.version == 10)
		{ browserString = "ie ie10"; }
	if(!!navigator.userAgent.match(/Trident.*rv\:11\./))
		{ browserString = "ie ie11"; }
	if(isEdge)
		{ browserString = "edge"; }
	
	return browserString;
	}


////////////////////////////////////////////////////////////////


// Check if is touch device
function CMM_isTouch()
	{
	return (('ontouchstart' in window)
    || (navigator.MaxTouchPoints > 0)
    || (navigator.msMaxTouchPoints > 0));
	}


////////////////////////////////////////////////////////////////


// Check if is mobile device
function CMM_isMobile()
	{
	if(/(iphone|ipod|ipad|android|iemobile|webos|fennec|blackberry|kindle|series60|playbook|opera\smini|opera\smobi|opera\stablet|symbianos|palmsource|palmos|blazer|windows\sce|windows\sphone|wp7|bolt|doris|dorothy|gobrowser|iris|maemo|minimo|netfront|semc-browser|skyfire|teashark|teleca|uzardweb|avantgo|docomo|kddi|ddipocket|polaris|eudoraweb|opwv|plink|plucker|pie|xiino|benq|playbook|bb|cricket|dell|bb10|nintendo|up.browser|playstation|tear|mib|obigo|midp|mobile|tablet)/.test(navigator.userAgent.toLowerCase()))
		{ return true; }
	else
		{ return false; }
	}


///////////////////////////////////////////////////////////////


// Get cursor-position in textarea
function CMM_getCursorPosition(element)
	{
	var el = $(element).get(0);
	var pos = 0;
	// Get last char#pos
	pos = $(el).val().length;

	// Get current cursor pos
	if('selectionStart' in el)
		{
		pos = el.selectionStart;
		}
	else if('selection' in document)
		{
		el.focus();
		var sel = document.selection.createRange();
		var selLength = document.selection.createRange().text.length;
		sel.moveStart('character', -el.value.length);
		pos = sel.text.length - selLength;
		}

	return pos;
	}


///////////////////////////////////////////////////////////////


// Set cursor-position in textarea
function CMM_setCursorPosition(element,pos)
	{
	var el = $(element).get(0);

	if(el.setSelectionRange)
		{
		el.setSelectionRange(pos, pos);
		}
	else if(el.createTextRange)
		{
		var range = el.createTextRange();
		range.collapse(true);
		if(pos < 0)
			{ pos = $(el).val().length + pos; }
		range.moveEnd('character', pos);
		range.moveStart('character', pos);
		range.select();
		}
	}


///////////////////////////////////////////////////////////////


// Clear cache
function CMM_clearCache(type)
	{
	// Set cache dele type
	if(type == 'DB')
		{ action = 'CLEARCACHEDB'; }
	else if(type == 'FILES')
		{ action = 'CLEARCACHEFILES'; }
	else
		{ action = 'CLEARCACHE'; }

	$.ajax({
		type: "POST",
		url: 'blank.php',
		data: 'CMM_module=CMM&CMM_view=DUMMY&CMM_action='+action,
		beforeSend: function(data) {
			// Start spin button icon
			$('#headButCache I').addClass('fa-spin');
			},
		success: function(data) {
			// Stop spin button icon
			setTimeout(function(){ $('#headButCache I').removeClass('fa-spin'); },500)
			// Output message as head-message
			$('#headMessage').empty().append($(data)).fadeIn();
			$('#headMessage').on('click',function() { $(this).fadeOut(); });
			setTimeout(function(){ $("#headMessage").fadeOut(); },5000)
			},
		// Not to process data or worry about content-type.
	//	processData: false,
	//	contentType: false,
		cache: false
		});

	return false;
	}


///////////////////////////////////////////////////////////////


// Converts a string with jquery-plugin-options to an object
function CMM_configStringToObject(confString)
	{
	var confObject = {};
	
	if(typeof confString == 'undefined')
		{ confObject = {}; }
	else if(typeof confString == 'object')
		{ confObject = confString; }
	else if(typeof confString == 'string' && confString.indexOf(';') > -1)
		{
		confString = confString.split(";");
		confString.map(function(element,index) {
			if(element.indexOf(':') > -1)
				{
				element = element.split(':');
				element[1] == 'true' ? element[1] = true : '';
				element[1] == 'false' ? element[1] = false : '';
				confObject[element[0]] = element[1];
				}
			});
		}

	return confObject;
	}


///////////////////////////////////////////////////////////////


// Seitenbaum laden
function CMM_loadPageTree(url)
	{
//	$("#CMM_adminPageTree UL").css('visibility','hidden');
	$("#CMM_adminPageTree").parent().slideUp(500, function() { 
		$("#CMM_adminPageTree").load(url, function() { 
			$("#CMM_adminPageTree").parent().slideDown(500, function() {
				// Tooltip reanimieren
				$('A[title], IMG[title], I[title], SPAN[title]','#contentContainer').tipTip({defaultPosition:'top', edgeOffset:5});
				// Kontext-Menus
				$('.CMM_treeIcon','.CMM_adminTree').cmm3contextMenu({ menu:'#contextMenuTemplate', cmm_menuitems:'' });
				});
			});
		});
	}


///////////////////////////////////////////////////////////////


// Teil-Seitenbaum aus-/einklappen
// item -> DOM-Item
// url -> URL to load the subitems
function CMM_loadPageTreeSub(item,url)
	{
	// Plus/Minus tauschen
	expandIcon = item;
	listNode = item.closest('LI');
	listLink = listNode.find('> DIV A');

	if(listNode.has('UL').length)
		{
		nodeStatus = true;
		expandIcon.removeClass('fa-minus');
		expandIcon.addClass('fa-plus');
		}
	else
		{
		nodeStatus = false;
		expandIcon.removeClass('fa-plus');
		expandIcon.addClass('fa-minus');
		}

	// einklappen
	if(nodeStatus == true)
		{
		// Teilbaum nachladen, aber nicht einbauen - nur fuer Registrierung des Einklappens
		$("<div>").load(url,function() {
			// Referenz auf Teilbaum in Variable uebernehmen
			subtree = listNode.find("> UL");
			// Teilbaum ausblenden
			subtree.stop().slideUp(500,'easeOutQuint', function() {
				// Teilbaum entfernen
				$(this).remove();
				});
			});
		}
	// ausklappen
	else
		{
		// Loader einblenden
		listLink.addClass('loading');
		// Teilbaum nachladen
		$("<div>").load(url,function() {
			// Teilbaum ohne Dummy-DIV in Variable uebernehmen
			subtree = $(this).children(":first");
			// Teilbaum ausblenden
			subtree.hide();
			// Teilbaum einfuegen
			listNode.append(subtree).each(function() {
				// Teilbaum einblenden
				$('> UL',listNode).stop().css({opacity:0}).slideDown(500,'easeOutQuint',function() {
					$(this).animate({opacity:1});
					// Loader entfernen
					listLink.removeClass('loading');
					});
				// Tooltip reanimieren
				$('A[title], IMG[title], I[title], SPAN[title]','#contentContainer').tipTip({defaultPosition:'top', edgeOffset:5});
				// Kontext-Menus
				$('.CMM_treeIcon',listNode).cmm3contextMenu({ menu:'#contextMenuTemplate', cmm_menuitems:'' });

				// If use in page-select dialog -> Override link-behaviour
				$('A.CMM_treeLabel','#CMM_adminPageSelect').each(function() {
					$(this).on('click',function(e){
						// Klick verhindern
						e.preventDefault();
						// Seiten-ID aus Link ermitteln
						pageSelectString = $(this).attr('href').match(/CMM_page=(\d+)/i);
						pageSelectID = pageSelectString[1];
						//alert(pageSelectID);
						// Referenz zu Return-Feld ermitteln
						field = $('#CMM_adminPageSelect').data('returnField');
						// ID an Feld uebergeben
						field.val(pageSelectID);
						// Dialog ausblenden
						dialog.fadeOut();
						});
					});
				});
			});
		}
	}


///////////////////////////////////////////////////////////////


// Verzeichnisbaum laden
function CMM_loadDirTree(url)
	{
	$("#CMM_adminDirTree UL").css('visibility','hidden');
	$("#CMM_adminDirTree").parent().slideUp(500, function() { 
		$("#CMM_adminDirTree").load(url, function() { 
			$("#CMM_adminDirTree").parent().slideDown(500, function() {
				// Tooltip reanimieren
				$('A[title], IMG[title], I[title], SPAN[title]','#contentContainer').tipTip({defaultPosition:'top', edgeOffset:5});
				// Kontext-Menus
				$('.CMM_treeIcon','.CMM_adminTree').cmm3contextMenu({ menu:'#contextMenuTemplate', cmm_menuitems:'' });
				});
			});
		});
	}


///////////////////////////////////////////////////////////////


// Teil-Verzeichnisbaum aus-/einklappen
// item -> DOM-Item
// url -> URL to load the subitems
function CMM_loadDirTreeSub(item,url)
	{
	// Plus/Minus tauschen
	expandIcon = item;
	listNode = item.closest('LI');
	listLink = listNode.find('> DIV A');

	if(listNode.has('UL').length)
		{
		nodeStatus = true;
		expandIcon.removeClass('fa-minus');
		expandIcon.addClass('fa-plus');
		}
	else
		{
		nodeStatus = false;
		expandIcon.removeClass('fa-plus');
		expandIcon.addClass('fa-minus');
		}

	// einklappen
	if(nodeStatus == true)
		{
		// Teilbaum nachladen, aber nicht einbauen - nur fuer Registrierung des Einklappens
		$("<div>").load(url,function() {
			// Referenz auf Teilbaum in Variable uebernehmen
			subtree = listNode.find("> UL");
			// Teilbaum ausblenden
			subtree.stop().slideUp(500,'easeInOutQuint', function() {
				// Teilbaum entfernen
				$(this).remove();
				});
			});
		}
	// ausklappen
	else
		{
		// Loader einblenden
		listLink.addClass('loading');
		// Teilbaum nachladen
		$("<div>").load(url,function() {
			// Teilbaum ohne Dummy-DIV in Variable uebernehmen
			subtree = $(this).children(":first");
			// Teilbaum ausblenden
			subtree.hide();
			// Teilbaum einfuegen
			listNode.append(subtree).each(function() {
				// Teilbaum einblenden
				$('> UL',listNode).stop().css({opacity:0}).slideDown(500,'easeOutQuint',function() {
					$(this).animate({opacity:1});
					// Loader entfernen
					listLink.removeClass('loading');
					});
				// Tooltip reanimieren
				$('A[title], IMG[title], I[title], SPAN[title]','#contentContainer').tipTip({defaultPosition:'top', edgeOffset:5});
				// Kontext-Menus
				$('.CMM_treeIcon',listNode).cmm3contextMenu({ menu:'#contextMenuTemplate', cmm_menuitems:'' });

				// If use in dir-select dialog -> Override link-behaviour
				$('A.CMM_treeLabel','#CMM_adminDirSelect').each(function() {
					$(this).on('click',function(e){
						// Klick verhindern
						e.preventDefault();
						// Seiten-ID aus Link ermitteln
						dirSelectString = $(this).attr('href').match(/CMM_dir=([a-zA-Z0-9-_\/]+)/i);
						dirSelectPath = dirSelectString[1];
						//alert(dirSelectPath);
						// Referenz zu Return-Feld ermitteln
						field = $('#CMM_adminDirSelect').data('returnField');
						// ID an Feld uebergeben
						field.val(dirSelectPath);
						// Dialog ausblenden
						dialog.fadeOut();
						});
					});
				});
			});
		}
	}


///////////////////////////////////////////////////////////////


// Plugin-Parameter laden
function CMM_loadPluginParams(container,url)
	{
	// Werte aus Formularfelder auslesen
	var inputs = $(":input",container).serializeArray();

	// Formular ausblenden, nachladen, einblenden
	$(container).slideUp(500, function() { 
		$(container).load(url, function() { 
			$(container).slideDown(500, function() {
			// Werte in gleichnamige Felder zurueckschreiben
				jQuery.each(inputs, function(i, input){
					$('INPUT[name="'+input.name+'"]').val(input.value);
					$('TEXTAREA[name="'+input.name+'"]').val(input.value);
					});

				// Shy fields - show if set or not empty
				setTimeout(function() {
					// Shy fields - show if set or not empty and add toggle
					$('.CMM_inputBoxShy',container).each(function() {
						CMM_inputShyfieldsShow($(this));
						});
					$('.CMM_inputBoxShy',container).each(function() {
						CMM_inputShyfieldsToggle($(this));
						});
					},250);

				// Multiselect reaktivieren
				$('.multiselect').multiselect({labelLeft: 'verfügbar', labelRight: 'ausgewählt'});
				}) 
			})
		});
	}


///////////////////////////////////////////////////////////////


// Plugin-Parameter laden
function CMM_loadFormParams(container,url)
	{
	// Werte aus Formularfelder auslesen
	var inputs = $(":input",container).serializeArray();

	// Formular ausblenden, nachladen, einblenden
	$(container).slideUp(500, function() { 
		$(container).load(url, function() { 
			$(container).slideDown(500, function() {
				// Werte in gleichnamige Felder zurueckschreiben
				jQuery.each(inputs, function(i, input)
					{
					// Name des zu bearbeitenden Feldes ermitteln
					var currentField = '';
					var currentFieldName = input.name;
					var currentFieldValue = input.value;

					// get textarea and content
					if($('textarea[name="'+currentFieldName+'"]').length)
						{
						currentField = $('textarea[name="'+currentFieldName+'"]');
						currentField.val(currentFieldValue);
						}
					// get select and selected value
					else if($('select[name="'+currentFieldName+'"]').length)
						{
						currentField = $('select[name="'+currentFieldName+'"]');
						currentField.val(currentFieldValue);
						}
					// get input and value
					else if($('input[name="'+currentFieldName+'"]').length)
						{
						currentField = $('input[name="'+currentFieldName+'"]');
	
						// subtype checkbox
						if(currentField.attr('type') == 'checkbox')
							{
							// if value equals -> check
							if(currentField.val() == currentFieldValue)
								{ currentField.attr('checked', true); }
							}
						// subtype radio
						else if(currentField.attr('type') == 'radio')
							{
							// if value equals -> check
							currentField.each(function() {
								if($(this).val() == currentFieldValue)
									{ $(this).attr('checked', true); }
								})
							}
						// subtypes text, password, hidden
						else
							{
							currentField.val(currentFieldValue);
							}
						}
					});

				// Shy fields - show if set or not empty
				setTimeout(function() {
					// Shy fields - show if set or not empty and add toggle
					$('.CMM_inputBoxShy',container).each(function() {
						CMM_inputShyfieldsShow($(this));
						});
					$('.CMM_inputBoxShy',container).each(function() {
						CMM_inputShyfieldsToggle($(this));
						});
					},250);
				});
			});
		});

	// Tabs nach Ajax-Load initialisieren
	$(document).ajaxComplete(function(event, xhr, settings) {
		$('.CMM_adminFormSelectTabs').cmm3tabs({
			/*selectorToggleSet:'UL', selectorToggle:'LI', selectorContentSet:'> DIV', selectorContent:'> DIV', */
			classContainer:'CMM_adminFormSelectTabs', classToggleSet:'CMM_adminFormSelectTabsTabs', classToggle:'CMM_adminFormSelectTabsTab', classContentSet:'CMM_adminFormSelectTabsLayers', classContent:'CMM_adminFormSelectTabsLayer', classSelected:'selected',
			useHashID: false,
			});
		});
	}


///////////////////////////////////////////////////////////////


// Funktion zum Anzeigen einer Dialogbox
function CMM_showDialog(module,action,source)
	{
	dialog = $('#dialog');
	dialogBoxContent = $('#dialogContent');

	dialogBoxContent.html('');

	// Show dialog
	CMM_dialogBoxShow(500,500);
	// Set loader
	dialogBoxContent.addClass('loading');
	// Load wizard
	dialogBoxContent.load('blank.php?CMM_module='+module+'&CMM_view=DIALOG&CMM_action='+action+'&CMM_path='+source,function(){
		// Remove loader
		dialogBoxContent.removeClass('loading');
		});

	}


///////////////////////////////////////////////////////////////


// Handle the dialog for dir-selection
function CMM_showDirDialog(field)
	{
	dialog = $('#dialog');
	dialogBox = $('#dialogBox');
	dialogBoxTitle = $('P','#dialogHead');
	dialogBoxContent = $('#dialogContent');

	dialogBoxTitle.html('Verzeichnis auswählen');
	dialogBoxContent.html('');

	// vorhandene Seite auswaehlen
	selectedItem = field.val();

	// Show dialog
	CMM_dialogBoxShow(500,500);
	// Set loader
	dialogBoxContent.addClass('loading');
	// Load wizard
	dialogBoxContent.load('wizards/wizard-dirselect.php?CMM_dirSelected='+selectedItem,function(){
		// Remove loader
		dialogBoxContent.removeClass('loading');
		// Referenz zu Input-Feld speichern fuer Auf-/Zuklappen des Seitenbaumes
		$('#CMM_adminDirSelect').data('returnField',field);
		// MODUS: PAGE-SELECT -> Link-Verhalten ueberschreiben
		$('A.CMM_treeLabel','#CMM_adminDirSelect').each(function() {
			$(this).on('click',function(e){
				// Klick verhindern
				e.preventDefault();
				// Seiten-ID aus Link ermitteln
				dirSelectString = $(this).attr('href').match(/CMM_dir=([a-zA-Z0-9-_\/]+)/i);
				dirSelectPath = dirSelectString[1];
				//alert(dirSelectPath);
				// Referenz zu Return-Feld ermitteln
				field = $('#CMM_adminDirSelect').data('returnField');
				// ID an Feld uebergeben
				field.val(dirSelectPath);
				// Dialog ausblenden
				dialog.fadeOut();
				});
			});
		});

	// Tooltip reanimieren
	$('A[title], IMG[title], I[title], SPAN[title]','#contentContainer').tipTip({defaultPosition:'top', edgeOffset:5});

	return false;
	}


///////////////////////////////////////////////////////////////


// Handle the dialog for page-selection
function CMM_showPageDialog(field)
	{
	dialog = $('#dialog');
	dialogBox = $('#dialogBox');
	dialogBoxTitle = $('P','#dialogHead');
	dialogBoxContent = $('#dialogContent');

	dialogBoxTitle.html('Seite auswählen');
	dialogBoxContent.html('');

	// vorhandene Seite auswaehlen
	selectedItem = field.val();

	// Show dialog
	CMM_dialogBoxShow(500,500);
	// Set loader
	dialogBoxContent.addClass('loading');
	// Load wizard
	dialogBoxContent.load('wizards/wizard-pageselect.php?CMM_pageSelected='+selectedItem,function(){
		// Remove loader
		dialogBoxContent.removeClass('loading');
		// Referenz zu Input-Feld speichern fuer Auf-/Zuklappen des Seitenbaumes
		$('#CMM_adminPageSelect').data('returnField',field);

		// MODUS: PAGE-SELECT -> Link-Verhalten ueberschreiben
		$('A.CMM_treeLabel','#CMM_adminPageSelect').each(function() {
			$(this).on('click',function(e){
				// Klick verhindern
				e.preventDefault();
				// Seiten-ID aus Link ermitteln
				pageSelectString = $(this).attr('href').match(/CMM_page=(\d+)/i);
				pageSelectID = pageSelectString[1];
				//alert(pageSelectID);
				// Referenz zu Return-Feld ermitteln
				field = $('#CMM_adminPageSelect').data('returnField');
				// ID an Feld uebergeben
				field.val(pageSelectID);
				// Dialog ausblenden
				dialog.fadeOut();
				});
			});
		});

	// Tooltip reanimieren
	$('A[title], IMG[title], I[title], SPAN[title]','#contentContainer').tipTip({defaultPosition:'top', edgeOffset:5});

	return false;
	}


///////////////////////////////////////////////////////////////


// Handle the dialog for icon-selection
function CMM_showIconDialog(field)
	{
	dialog = $('#dialog');
	dialogBox = $('#dialogBox');
	dialogBoxTitle = $('P','#dialogHead');
	dialogBoxContent = $('#dialogContent');

	dialogBoxTitle.html('Icon auswählen');
	dialogBoxContent.html('');

	// vorhandenes Icon auswaehlen
	selectedItem = field.val().replace(' ','+').replace(' ','+').replace(' ','+');

	// Show dialog
	CMM_dialogBoxShow(800,500);
	// Set loader
	dialogBoxContent.addClass('loading');

	// Load wizard
	dialogBoxContent.load('wizards/wizard-iconselect.php?CMM_iconSelected='+selectedItem,function(){
		// Remove loader
		dialogBoxContent.removeClass('loading');
		// Set dialog container
		var iconDialog = $('#CMM_adminIconSelect');
		// Insert field-name in data-attribute
		iconDialog.data('returnField',field);

		// Search icon
		$('#iconSearch',iconDialog).on('keyup', function() {
			// Clear result list
			$('.CMM_adminIconSelectSearch UL',iconDialog).empty();
			// Search for matching icons
			if($(this).val().length >= 2)
				{
				// Get matching icons
				var tempIcons = $('.CMM_adminIconSelectList I[title*="'+$(this).val()+'"]',iconDialog);
				// Loop icon list
				tempIcons.each(function(index,elem) {
					// Check if icon with same class is already in result list
					if($('.CMM_adminIconSelectSearch I[class*="'+$(elem).attr('class')+'"]',iconDialog).length==0)
						{ $(elem).parent().clone(true).appendTo('.CMM_adminIconSelectSearch UL',iconDialog); }
					});
				// Hide list
				if($('.CMM_adminIconSelectList',iconDialog).is(":visible"))
					{ $('.CMM_adminIconSelectList',iconDialog).css('display','none'); }
				}
			else
				{
				// Show list
				if($('.CMM_adminIconSelectList',iconDialog).is(":visible") == false)
					{ $('.CMM_adminIconSelectList',iconDialog).css('display','block'); }
				}
			});

		// Select icon
		$('I','#CMM_adminIconSelect').on('click',function(e){
			// Klick verhindern
			//e.preventDefault();
			// Seiten-ID aus Link ermitteln
			iconClass = $(this).attr('class');
			// Referenz zu Return-Feld ermitteln
			field = $('#CMM_adminIconSelect').data('returnField');
			fieldPreview = field.prev();
			// ID an Feld uebergeben
			field.val(iconClass);
			fieldPreview.attr('class','iconpreview '+iconClass);
			// Dialog ausblenden
			dialog.fadeOut();
			});
		});

	// Tooltip reanimieren
	$('A[title], IMG[title], I[title], SPAN[title]','#contentContainer').tipTip({defaultPosition:'top', edgeOffset:5});

	return false;
	}


///////////////////////////////////////////////////////////////


// Funktion zum Anzeigen eines Dropdownfeldes zur Farbauswahl
function CMM_showColorDialog(field)
	{
	var dialog = $('#dialog');
	var dialogBox = $('#dialogBox');
	var dialogBoxTitle = $('P','#dialogHead');
	var dialogBoxContent = $('#dialogContent');

	dialogBoxTitle.html('Farbe auswählen');
	dialogBoxContent.html('');

	// vorhandene Farbe auswaehlen
	colorValue = field.val();
	colorValue=='' ? colorValue='#000000' : '';

	// Create colors
	hexChars = ['0','1','2','3','4','5','6','7','8','9','A','B','C','D','E','F'];
	colors = [];

	// Create container
	colorDialog = $('<div id="colorDialog"></div>');

	// Create color list
	colorDialogList = $('<div class="colorDialogList"></div>');
	colorDialogListBlock = $('<ul></ul>');
	for(r=0;r<16;r+=3)
		{
		for(g=0;g<16;g+=3)
			{
			for(b=0;b<16;b+=3)
				{
				color = '#'+hexChars[r]+hexChars[r]+hexChars[g]+hexChars[g]+hexChars[b]+hexChars[b];
				colors.push(color);
				}
			}
		}

	// Reorder colors
	colorsOrdered = [];
	colorsOrdered = colorsOrdered.concat(colors.slice(0,18));
	colorsOrdered = colorsOrdered.concat(colors.slice(36,54));
	colorsOrdered = colorsOrdered.concat(colors.slice(72,90));
	colorsOrdered = colorsOrdered.concat(colors.slice(108,126));
	colorsOrdered = colorsOrdered.concat(colors.slice(144,162));
	colorsOrdered = colorsOrdered.concat(colors.slice(180,198));
	colorsOrdered = colorsOrdered.concat(colors.slice(18,36));
	colorsOrdered = colorsOrdered.concat(colors.slice(54,72));
	colorsOrdered = colorsOrdered.concat(colors.slice(90,108));
	colorsOrdered = colorsOrdered.concat(colors.slice(126,144));
	colorsOrdered = colorsOrdered.concat(colors.slice(162,180));
	colorsOrdered = colorsOrdered.concat(colors.slice(198,216));
	colors = colorsOrdered;

	// Create clickable items
	for(i=0; i<colors.length; i++)
		{
		color = colors[i];

		colorDialogListBlockItem = $('<li style="background-color:'+color+';" data-color="'+color+'" title="'+color+'"></li>');
		// Add click event
		colorDialogListBlockItem.on('click',function() {
			// Get color
			currentColor = $(this).data('color');
			// Set color to field an preview
			previewTextColor = (parseInt(currentColor.substr(1,2),16)*0.299 + parseInt(currentColor.substr(3,2),16)*0.587 + parseInt(currentColor.substr(5,2),16)*0.114) / 256 < 0.5 ? '#FFFFFF' : '#000000';
			colorDialogPreviewField.val(currentColor);
			colorDialogPreviewField.css('background-color',currentColor);
			colorDialogPreviewField.css('color',previewTextColor);
			// Set slider values
			colorDialogSliderRedLabel.text('R: '+parseInt(currentColor.substr(1,2),16));
			colorDialogSliderRedRange.val(parseInt(currentColor.substr(1,2),16));
			// Green
			colorDialogSliderGreenLabel.text('G: '+parseInt(currentColor.substr(3,2),16));
			colorDialogSliderGreenRange.val(parseInt(currentColor.substr(3,2),16));
			// Blue
			colorDialogSliderBlueLabel.text('B: '+parseInt(currentColor.substr(5,2),16));
			colorDialogSliderBlueRange.val(parseInt(currentColor.substr(5,2),16));
			});

		colorDialogListBlockItem.appendTo(colorDialogListBlock);
		}

	colorDialogListBlock.appendTo(colorDialogList);
	colorDialogList.appendTo(colorDialog);

	// Create color-sliders
	colorDialogSliders = $('<div class="colorDialogSliders"></div>');
	colorDialogSlidersList = $('<ul></ul>');
	colorDialogSlidersList.appendTo(colorDialogSliders);
	// Red
	colorDialogSliderRed = $('<li></li>');
	colorDialogSliderRed.appendTo(colorDialogSlidersList);
	colorDialogSliderRedLabel = $('<span class="rangeSliderLabel" />');
	colorDialogSliderRedLabel.text('R: '+parseInt(colorValue.substr(1,2),16));
	colorDialogSliderRedLabel.appendTo(colorDialogSliderRed);
	colorDialogSliderRedRange = $('<input class="datatype_int rangeSlider colorDialogSliderRed" type="range" min="0" max="255" step="1" data-color="R" />');
	colorDialogSliderRedRange.val(parseInt(colorValue.substr(1,2),16));
	colorDialogSliderRedRange.appendTo(colorDialogSliderRed);
	// Green
	colorDialogSliderGreen = $('<li></li>');
	colorDialogSliderGreen.appendTo(colorDialogSlidersList);
	colorDialogSliderGreenLabel = $('<span class="rangeSliderLabel" />');
	colorDialogSliderGreenLabel.text('G: '+parseInt(colorValue.substr(3,2),16));
	colorDialogSliderGreenLabel.appendTo(colorDialogSliderGreen);
	colorDialogSliderGreenRange = $('<input class="datatype_int rangeSlider colorDialogSliderGreen" type="range" min="0" max="255" step="1" data-color="G" />');
	colorDialogSliderGreenRange.val(parseInt(colorValue.substr(3,2),16));
	colorDialogSliderGreenRange.appendTo(colorDialogSliderGreen);
	// Blue
	colorDialogSliderBlue = $('<li></li>');
	colorDialogSliderBlue.appendTo(colorDialogSlidersList);
	colorDialogSliderBlueLabel = $('<span class="rangeSliderLabel" />');
	colorDialogSliderBlueLabel.text('B: '+parseInt(colorValue.substr(5,2),16));
	colorDialogSliderBlueLabel.appendTo(colorDialogSliderBlue);
	colorDialogSliderBlueRange = $('<input class="datatype_int rangeSlider colorDialogSliderBlue" type="range" min="0" max="255" step="1" data-color="B" />');
	colorDialogSliderBlueRange.val(parseInt(colorValue.substr(5,2),16));
	colorDialogSliderBlueRange.appendTo(colorDialogSliderBlue);
	// Append

	// Add oninput event
	$('INPUT[type="range"]',colorDialogSliders).on('input',function() {
		// Update label
		$(this).prev().text($(this).data('color')+': '+$(this).val());
		// Get color
		var hexColor = '#';
		$('INPUT[type="range"]',colorDialogSliders).each(function() {
			hexColorComponent = parseFloat($(this).val()).toString(16).toUpperCase();
			hexColor += (hexColorComponent.length == 1 ? "0"+hexColorComponent : hexColorComponent);
			});
		// Set color to field and preview
		previewTextColor = (parseInt(hexColor.substr(1,2),16)*0.299 + parseInt(hexColor.substr(3,2),16)*0.587 + parseInt(hexColor.substr(5,2),16)*0.114) / 256 < 0.5 ? '#FFFFFF' : '#000000';
		colorDialogPreviewField.val(hexColor);
		colorDialogPreviewField.css('background-color',hexColor);
		colorDialogPreviewField.css('color',previewTextColor);
		});
	colorDialogSliders.appendTo(colorDialog);

	// Create preview
	previewTextColor = (parseInt(colorValue.substr(1,2),16)*0.299 + parseInt(colorValue.substr(3,2),16)*0.587 + parseInt(colorValue.substr(5,2),16)*0.114) / 256 < 0.5 ? '#FFFFFF' : '#000000';
	colorDialogPreview = $('<div class="colorDialogPreview"></div>');
	colorDialogPreviewField = $('<input type="text" value="'+colorValue+'" id="colorDialogPreview" readonly>');
	colorDialogPreviewField.css('background-color',colorValue);
	colorDialogPreviewField.css('color',previewTextColor);
	colorDialogPreviewField.appendTo(colorDialogPreview);
	colorDialogPreview.appendTo(colorDialog);

	// Create submit-button
	colorDialogButtonContainer = $('<div class="colorDialogButton"></div>');
	colorDialogButton = $('<input type="button" class="CMM_button" value="Übernehmen">').on('click',function() {
		// Transfer selected color to field
		field.val(colorDialogPreviewField.val());
		field.prev().css('background-color',colorDialogPreviewField.val());
		// Close and empty dialog
		$('#dialog').fadeOut();
		});
	colorDialogButton.appendTo(colorDialogButtonContainer);
	colorDialogButtonContainer.appendTo(colorDialog);

	// Add colorDialog to input field
	dialogBoxContent.html(colorDialog);

	// Show dialog
	CMM_dialogBoxShow(320,400);

	return false;
	}


///////////////////////////////////////////////////////////////


// Administration: Show dialog with input fields for content-options
function CMM_showAnimationDialog(field)
	{
	dialog = $('#dialog');
	dialogBox = $('#dialogBox');
	dialogBoxTitle = $('P','#dialogHead');
	dialogBoxContent = $('#dialogContent');

	dialogBoxTitle.html('Optionen auswählen');
	dialogBoxContent.html('');

	// Get animation config
	contentAnimationString = field.val();

	// Show dialog
	CMM_dialogBoxShow(800,500);

	// Set loader
	dialogBoxContent.addClass('loading');
	// Load wizard
	dialogBoxContent.load('../CMM_Contents/wizards/wizard-animationconfig.php?contentAnimationString='+contentAnimationString, function() {
		// Remove loader
		dialogBoxContent.removeClass('loading');
		// Get dialog
		contentConfigDialog = $('#contentAnimationDialog');
		// Shy fields - show if set or not empty
		setTimeout(function() {
			// Shy fields - show if set or not empty and add toggle
			$('.CMM_inputBoxShy',contentConfigDialog).each(function() {
				CMM_inputShyfieldsShow($(this));
				});
			$('.CMM_inputBoxShy',contentConfigDialog).each(function() {
				CMM_inputShyfieldsToggle($(this));
				});
			},250);
		// Set action on submit-button
		$('#contentAnimationDialogButton').on('click',function() {
			// Collect data
			resultData = '';
			$('.CMM_inputBox SELECT,.CMM_inputBox INPUT',contentConfigDialog).each(function() {
				// Get field name
				itemName = $(this).attr('name');
				// Modify select name
				if($(this).is('SELECT'))
					{ itemName = itemName.replace('[select]',''); }
				// Collect value only if not empty
				if($(this).val() != '')
					{ resultData+= itemName+':'+$(this).val()+';'; }
				});
	console.log(resultData);
			// Send data to field
			field.val(resultData);
			// Close and empty dialog
			$('#dialog').fadeOut();
			});
		});
	}


///////////////////////////////////////////////////////////////


// Handle the dialog for geo-selection
function CMM_showGeoDialog(field)
	{
	dialog = $('#dialog');
	dialogBox = $('#dialogBox');
	dialogBoxTitle = $('P','#dialogHead');
	dialogBoxContent = $('#dialogContent');

	dialogBoxTitle.html('Ort auswählen');
	dialogBoxContent.html('');

	var geoAddress = '';
	var geoLat = '';
	var geoLng = '';

	// Get GEO-fields and values
	if(field.attr('data-geo-fields')) {
		dataGeoFields = field.attr('data-geo-fields');
		dataGeoFields = dataGeoFields.split(',');
		// Lat
		fieldLat = $('#datafield_'+dataGeoFields[0])
		geoLat = fieldLat.val();
		// Long
		fieldLng = $('#datafield_'+dataGeoFields[1]);
		geoLng = fieldLng.val();
		}

	// Get Address-fields and values
	if(field.attr('data-address-fields')) {
		dataAddressFields = fieldLat.attr('data-address-fields');
		dataAddressFields = dataAddressFields.split(',');
		$.map(dataAddressFields,function(val,i) {
			// If field exists
			if($('#datafield_'+val).length > 0)
				{
				geoAddress+= (i>0 ? ', ' : '');
				// if select -> get option label
				if($('#datafield_'+val).is('select'))
					{ geoAddress+= $('#datafield_'+val+' option:selected').text(); }
				// if input -> get content
				else
					{ geoAddress+= $('#datafield_'+val).val().replace(/\r?\n|\r/g,' '); }
				}
			});
		console.log(geoAddress);
		}

	// Show dialog
	CMM_dialogBoxShow(500,500);
	// Set loader
	dialogBoxContent.addClass('loading');
	dialogBoxContent.load('wizards/wizard-geoselect.php?CMM_geoLat='+geoLat+'&amp;CMM_geoLng='+geoLng,function(){
		// Remove loader
		dialogBoxContent.removeClass('loading');
		// Referenz zu Input-Feld speichern fuer Auf-/Zuklappen des Seitenbaumes
	//	$('#CMM_adminGeoSelect').data('returnFieldLat',fieldLat);
	//	$('#CMM_adminGeoSelect').data('returnFieldLng',fieldLng);

		// Load map and set fields
		function CMM_showGeoDialog_callbackPopulate() {

			// Koordinaten
			if(geoLat!='' && geoLng!='')
				{ $('input#geocomplete','#CMM_adminGeoSelect').val(parseFloat(geoLat)+','+parseFloat(geoLng)); }
			// Strasse, Ort, ...
			else
				{ $('input#geocomplete','#CMM_adminGeoSelect').val(geoAddress); }
	
			$("#geocomplete").geocomplete({
				map: ".map_canvas",
				details: "form ",
				markerOptions: { draggable: true }
				});
	
			$("#geocomplete").bind("geocode:dragged", function(event, latLng){
				$("input#geolat").val(latLng.lat());
				$("input#geolng").val(latLng.lng());
				$("#reset").show();
				});
	
			$("#reset").click(function(){
				$("#geocomplete").geocomplete("resetMarker");
				$("#reset").hide();
				return false;
				});
	
			$("#find").click(function(){
				$("#geocomplete").trigger("geocode");
				}).click();

			$("#return").click(function(){
				// Daten an Hauptformular uebertragen
				fieldLat.val($("input#geolat").val());
				fieldLng.val($("input#geolng").val());
				// Dialog ausblenden
				dialog.fadeOut();
				});

			}

		// If maps object already loaded - call function
		if(typeof google === 'object' && typeof google.maps === 'object')
			{
			CMM_showGeoDialog_callbackPopulate();
			}
		// Else - first load maps object, then call function
		else
			{
			// Get API-key from html-data-attrib of dialog - set in cms-config
			var googleApiKey = $('#CMM_adminGeoSelect').data('googleapikey');
			$.getScript("//maps.googleapis.com/maps/api/js?libraries=places&key="+googleApiKey, function() {
				CMM_showGeoDialog_callbackPopulate();
				});
			}
		});

	return false;
	}


///////////////////////////////////////////////////////////////


// Center and show box
function CMM_dialogBoxShow(width,height)
	{
	var dialog = $('#dialog');
	var dialogBox = $('#dialogBox');

	typeof width == 'undefined' ? width=500 : '';
	typeof height == 'undefined' ? height=500 : '';

	// Calculate negative margin
	marginTop = Math.round(height / 2);
	marginLeft = Math.round(width / 2);

	// Box: Remove dragged position, set size and make temporary opaque
	dialogBox.css({'top':'','left':'','width':width+'px','height':height+'px','margin-left':'-'+marginLeft+'px','margin-top':'-'+marginTop+'px'});

	// Dialog: fade in
	setTimeout(function() {
		dialog.fadeIn(500);
		}, 100);

	return true;
	}


///////////////////////////////////////////////////////////////


// Check and send a data-form
function CMM_adminFormSubmit(form,href,target,fields,message)
	{
	// Fix form
	(typeof form !== 'string' && $('form[name="'+form+'"]').length == 0) ? form = '' : '';
	// Fix href
	(typeof href !== 'string' ? href = '' : '');
	// Fix target
	(typeof target !== 'string' ? target = '' : '');
	// Fix fields
	(typeof fields !== 'object' ? fields = {} : '');
	// Fix message
	(typeof message !== 'string' ? message = '' : '');

	// get form or exit
	if($('form[name="'+form+'"]').length > 0)
		{ theForm = $('form[name="'+form+'"]').first(); }
	else
		{ return false; }

	// If href empty - get from form
	href == '' ? href = theForm.attr('action').replace(/#.*$/, "") : '';
	// If href empty - get from page
	href == '' ? href = '//'+document.location.hostname+document.location.pathname : '';

	// If action contains "SAVE" - check required fields
	requiredErrors = 0;
	if(typeof fields.CMM_action != 'undefined' && fields.CMM_action.indexOf('SAVE') >= 0)
		{
		// Get all required fields
		requiredFields = $('input[required],textarea[required],select[required]',theForm);
		// Check all required fields
		requiredFields.each(function(index,element) {
			if($(this).val().trim() == '')
				{
				requiredErrors++;
				$(this).closest('.CMM_inputBoxField').addClass('CMM_inputBoxFieldError');
				}
			else
				{
				$(this).closest('.CMM_inputBoxField').removeClass('CMM_inputBoxFieldError');
				}
			});
		}

	// Check confirm message
	confirmStatus = true;
	if(requiredErrors==0 && message != '')
		{ confirmStatus = confirm(message); }

	// Alert required
	if(requiredErrors > 0)
		{ alert('Es wurden nicht alle Pflichtfelder ausgefüllt!'); }
	// Check confirm status
	else if(confirmStatus == true)
		{
		// Change the form-action
		if(href != '')
			{ theForm.attr('action',href); }

		// Append tab-anchor to form-action
		if($('[name="CMM_tab"]',theForm).length > 0 && $('[name="CMM_tab"]',theForm).val()!='')
			{ theForm.attr('action',theForm.attr('action') + $('[name="CMM_tab"]',theForm).val()); }

		// Change the form-target
		if(target != '')
			{
			theForm.attr('target',target);
			if(target == '_blank')
				{
				NewWindow = window.open('blank.html','JsWindow','width=680,height=500,left=80,top=80,status=1,scrollbars=1,menubar=1,resizable=1');
				NewWindow.focus();
				theForm.attr('target','JsWindow');
				}
			}

		// Loop fields
		$.each(fields, function( key, value ) {
			// Create new field and insert value
			if($('[name='+key+']',theForm).length == 0)
				{ theForm.append('<input type="hidden" name="'+key+'" value="'+value+'">'); }
			// Insert value in present field
			else
				{ $('[name='+key+']',theForm).val(value); }
			});

		// Submit the form
		theForm.submit();
		}

	return true;
	}


///////////////////////////////////////////////////////////////


// Remove white-spaces
jQuery.fn.cleanWhitespace = function()
	{
    textNodes = this.contents().filter(function() { return (this.nodeType == 3 && !/\S/.test(this.nodeValue)); }).remove();

    return this;
	}


///////////////////////////////////////////////////////////////


// Slide up/down one list item
function CMM_adminListToggleItem(listItem)
	{
	var listItemToggle = $('.CMM_adminItemToggle',listItem).first();
	var listItemBody = $('> .CMM_adminItemContent > .CMM_adminItemBody',listItem);

	if(listItemToggle.hasClass('open'))
		{
		listItemBody.slideUp(500).animate({opacity:0},{queue:false, duration:250});
		listItem.removeClass('CMM_adminItemOpen');
		listItemToggle.removeClass('open');
		}
	else
		{
		listItemBody.css({opacity:0}).slideDown(500).animate({opacity:1},{queue:false, duration:750});
		listItem.addClass('CMM_adminItemOpen');
		listItemToggle.addClass('open');
		}
	}


///////////////////////////////////////////////////////////////


// Slide up/down all list items
function CMM_adminListToggleAll(listItem)
	{
	var listItemToggle = $('.CMM_adminItemToggle',listItem);
	var list = listItem.closest('.CMM_adminList, .CMM_adminGrid');
	var listItemIsOpen = listItemToggle.hasClass('open');

	$('.CMM_adminItem',list).each(function() {
		var thisListItem = $(this);
		var thisListItemToggle = $('.CMM_adminItemToggle',thisListItem);
		var thisListItemBody = $('> .CMM_adminItemContent > .CMM_adminItemBody',thisListItem);

		if(listItemIsOpen==true)
			{
			thisListItemBody.slideUp(500).animate({opacity:0},{queue:false, duration:250});
			thisListItem.removeClass('CMM_adminItemOpen');
			thisListItemToggle.removeClass('open');
			}
		else
			{
			thisListItemBody.css({opacity:0}).slideDown(500).animate({opacity:1},{queue:false, duration:750});
			thisListItem.addClass('CMM_adminItemOpen');
			thisListItemToggle.addClass('open');
			}
		});
	}


///////////////////////////////////////////////////////////////


// Init jQuery-Plugins
$(document).ready(function() {

	// Scroll tree to prior scroll-position
	if($('.contentColumnTree .contentColumnContent').length > 0)
		{
		// Check if is dir- or page-tree
		treeType = 'page';
		if($('#CMM_adminDirTree','.contentColumnTree .contentColumnContent').length > 0)
			{ treeType = 'dir'; }
		
		// Scroll to saved position
		treeScrollTop = localStorage.getItem(treeType+'TreeScrollTop');
		if(treeScrollTop !== null && treeScrollTop > 0)
			{ $('.contentColumnTree .contentColumnContent').scrollTop(treeScrollTop); }

		// Update current scroll position
		$('.contentColumnTree .contentColumnContent').scroll(function() {
			localStorage.setItem(treeType+'TreeScrollTop',$('.contentColumnTree .contentColumnContent').scrollTop());
			});
		}


	// Detect browser
	var browserClass = CMM_getBrowser();
	$("HTML").addClass(browserClass);

	// Check touch
	var touchClass = CMM_isTouch()==true ? 'is-touch' : 'is-no-touch';
	$('BODY').addClass(touchClass);

	// Check mobile
	var mobileClass = CMM_isMobile()==true ? 'is-mobile' : 'is-no-mobile';
	$('BODY').addClass(mobileClass);


	// Add license domain
	var numberLicenseDomains = 3;
	$('.CMM_licenseInfoBlockDomains').each(function() {
		if($('LI',this).length < numberLicenseDomains)
			{ $('.plus',this).css('display','block'); }
		});

	$('.plus','.CMM_licenseInfoBlockDomains').on('click', function(evt) {
		evt.preventDefault();
	    var plus = $(this);
		var container = $(this).closest('.CMM_licenseInfoBlockDomains');
		var list = $('UL',container);
		// Get template
		var $fieldTemplate = $('LI',container).eq(0).clone(false);
		$fieldTemplate.find('INPUT').prop('readonly', false).val('');
		$fieldTemplate.css('display','none');
		$fieldTemplate.append('<i class="minus fa fa-times-circle"></i>');
		$fieldTemplate.find('.minus').on('click',function() {
			$(this).closest('LI').slideUp(function() {
				$(this).remove();
				// Remove plus if limit reached
				if($('LI',list).length < numberLicenseDomains)
					{ plus.css('display','block'); }
				else
					{ plus.css('display','none'); }
				});
			});
		// Insert new field
		list.append($fieldTemplate)
		$fieldTemplate.slideDown();
		// Remove plus if limit reached
		if($('LI',list).length < numberLicenseDomains)
			{ plus.css('display','block'); }
		else
			{ plus.css('display','none'); }
		});


	// Close dialog box - when click on overlay
	$('#dialog').on('click',function(evt) {
		if(evt.target === this)
			{ $(this).fadeOut(); }
		});


	// Content messages
	var smallMessages = $('#contentContainer .CMM_messageSmall, #messageArea .CMM_messageSmall');
	if(smallMessages.length > 0)
		{
		$('#headMessage').empty().append(smallMessages).fadeIn();
		$('#headMessage').on('click',function() { $(this).fadeOut(); });
		setTimeout(function(){ $("#headMessage").fadeOut(); },5000)
		}


	// Content messages big
	if($('.CMM_messageBig').length)
		{
		$('.CMM_messageBig').prepend('<div class="CMM_messageBigClose">');
		$('.CMM_messageBigClose').on('click',function(evt) { $(this).parent().slideUp(); });
		}


	// Toggle cache-options
	$('#headButCache > A').on('click',function() {
		$(this).parent().toggleClass('act');
		$(this).next().fadeToggle();
		});
	$('#headButCache UL LI A').on('click',function() {
		$(this).closest('UL').fadeOut();
		$(this).closest('UL').closest('LI').removeClass('act');
		});


	// Action-Icons - toggle hover class
	$(document).on('mouseenter','.CMM_adminItem',function() {
		$(this).addClass('hover');
		}).on('mouseleave','.CMM_adminItem',function() {
		$(this).removeClass('hover');
		});


	// Toggle one list item
	$('.CMM_adminItemToggle .toggleOne').on('click',function() {
		listItem = $(this).closest('.CMM_adminItem');
		CMM_adminListToggleItem(listItem);
		});

	// Toggle all list items
	$('.CMM_adminItemToggle .toggleAll').on('click',function() {
		var listItem = $(this).closest('.CMM_adminItem');
		CMM_adminListToggleAll(listItem);
		});

	// Dashboard - toggle boxes
	$('#dashboardActions').cmm3showhide({selectorToggle:'> .dashboardBoxHead', selectorPanel:"next()", useCookie:true, cookieName:'dashboardActions', defaultOpen:false, classSelected:'selected'});
	$('#dashboardLogins').cmm3showhide({selectorToggle:'> .dashboardBoxHead', selectorPanel:"next()", useCookie:true, cookieName:'dashboardLogins', defaultOpen:false, classSelected:'selected'});
	$('#dashboardErrors').cmm3showhide({selectorToggle:'> .dashboardBoxHead', selectorPanel:"next()", useCookie:true, cookieName:'dashboardErrors', defaultOpen:false, classSelected:'selected'});
	$('#dashboardServer').cmm3showhide({selectorToggle:'> .dashboardBoxHead', selectorPanel:"next()", useCookie:true, cookieName:'dashboardServer', defaultOpen:false, classSelected:'selected'});
	$('#dashboardDocu').cmm3showhide({selectorToggle:'> .dashboardBoxHead', selectorPanel:"next()", useCookie:true, cookieName:'dashboardDocu', defaultOpen:false, classSelected:'selected'});

	// Documentation-Boxes
	if($('#docu .accordion').length)
		{
		$('#docu .accordion').each(function() {
			$(this).cmm3accordion({selectorToggle:'.accordionToggle', selectorPanel:"next()", classSelected:'selected', defaultOpen:false, multipleOpen:true});
			});
		}

	// License-overview
	if($('.licenseOverview').length)
		{
		$('.licenseOverview').each(function() {
			$(this).cmm3accordion({selectorToggle:'H3', selectorPanel:"next()", classSelected:'selected', defaultOpen:false, multipleOpen:true});
			});
		}

	// Documentation scroll to block
	$("#docu .index A").on('click',function(e) { 
	    e.preventDefault();
		sectionAnchor = $(this).attr('href');
      	// Call the scroll function(switch for flexbox or body)
		if($('.contentColumnPlayground').css('display').indexOf('flex') != -1)
	  		{ $('.contentColumnPlayground .contentColumnContent').animate({scrollTop: $(sectionAnchor).offset().top-130},$(sectionAnchor).offset().top/2,'easeInOutQuad'); }
		else
	  		{ $('html,body').animate({scrollTop: $(sectionAnchor).offset().top-130},$(sectionAnchor).offset().top/2,'easeInOutQuad'); }
		});

	// Backup-Element ein-/ausklappen
	if($('.CMM_backupItem').length)
		{ $('.CMM_backupItem').cmm3showhide({selectorToggle:'.CMM_backupItemLabel', selectorPanel:"next()", classSelected:'selected'}); }
	// Backup - alle markieren/demarkieren
	$('.CMM_backupItemContentModule').each(function() {
		var currentModule = $(this);
		// Check/uncheck all children
		$('LEGEND INPUT',currentModule).on('click', function() {
			if($(this).prop('checked') == true)
				{ currentModule.find('DIV INPUT').each(function() { $(this).prop('checked',true); }); }
			else
				{ currentModule.find('DIV INPUT').each(function() { $(this).prop('checked',false); }); }
			});
		// Check/uncheck parent if all children are checked/unchecked
		$('DIV INPUT',currentModule).on('click', function() {
			var allUnchecked = true;
			$('DIV INPUT',currentModule).each(function() {
				if($(this).prop('checked') == true)
					{ allUnchecked=false; }
				});
			if(allUnchecked == true)
				{ $('LEGEND INPUT',currentModule).prop('checked',false); }
			else
				{ $('LEGEND INPUT',currentModule).prop('checked',true); }
			});
		});
		
	// Navi-Toggle
	$('#naviToggle').on('click',function(e) {
		e.preventDefault();
		$('.contentColumnNavi').toggleClass('exp');
		});

	// Tree-Toggle
	$('#treeToggle').on('click',function(e) {
		e.preventDefault();
		$('.contentColumnTree').toggleClass('exp');
		});

	// Drag-Funktion fuer Dialog-Boxen
	$('.dialogBox').drags({handle:'.dialogHead'});

	// Tabs fuer Admin-Form
	$('.CMM_adminTabs').cmm3tabs({
		/*selectorToggleSet:'UL', selectorToggle:'LI', selectorContentSet:'> DIV', selectorContent:'> DIV', */
		classContainer:'CMM_adminTabs', classToggleSet:'CMM_adminTabsTabs', classToggle:'CMM_adminTabsTab', classContentSet:'CMM_adminTabsLayers', classContent:'CMM_adminTabsLayer', classSelected:'selected',
		useHashID: true,
		onToggleStart: function(currentTabID) { $('[name="CMM_tab"]').val(currentTabID); },
		onToggleComplete: function(currentTabID) {
	//	setTimeout(function() { 
			// Get and show RTEs on current layer, if not already shown
			currentTabRTEs = $('TEXTAREA.rte:visible',currentTabID);
			currentTabRTEs.each(function() {
				// Get current RTE
				var currentRTE = $(this);
				// Check if current rte was not already laoded
				if(jQuery.inArray(currentRTE.attr('id'),loadedRTEs) == -1)
					{
					// Re-init RTE - timeout required until tab is visible
					CMM_initRTE(currentRTE);
					// Add RTE-id to list of loaded RTEs
					loadedRTEs.push(currentRTE.attr('id'));
					}
				});
	//		},500);
			}
		}); 
	// Set url-hash as start-tab
	$('[name="CMM_tab"]').val(location.hash);


	// Create tabs in form-select-field
	$('.CMM_adminFormSelectTabs').cmm3tabs({
		/*selectorToggleSet:'UL', selectorToggle:'LI', selectorContentSet:'> DIV', selectorContent:'> DIV', */
		classContainer:'CMM_adminFormSelectTabs', classToggleSet:'CMM_adminFormSelectTabsTabs', classToggle:'CMM_adminFormSelectTabsTab', classContentSet:'CMM_adminFormSelectTabsLayers', classContent:'CMM_adminFormSelectTabsLayer', classSelected:'selected',
		useHashID: false,
		});

	// Kontext-Menus
	$('.CMM_treeIcon','.CMM_adminTree').cmm3contextMenu({ menu:'#contextMenuTemplate', cmm_menuitems:'' });
	$('.fileicon','.CMM_filelist').cmm3contextMenu({ menu:'#contextMenuTemplate', leftButton:true, cmm_menuitems:'' });

	// Tooltip
	$('A[title]','#headContainer').tipTip({defaultPosition:'bottom', edgeOffset:5});
	$('A[title], IMG[title], I[title], SPAN[title]','#contentContainer').tipTip({defaultPosition:'top', edgeOffset:5});
	$(document).ajaxComplete(function(event, xhr, settings) {
		$('A[title], IMG[title], I[title], SPAN[title]','#contentContainer').tipTip({defaultPosition:'top', edgeOffset:5});
		});

	// Set collect-array for loaded RTEs
	loadedRTEs = [];
	// Init only visible RTEs
	var visibleRTEs = $('textarea.rte:visible','#CMM_formDetails');
	CMM_initRTE(visibleRTEs);
	// Add visible RTEs to loaded list
	visibleRTEs.each(function(visibleRTE) {
		loadedRTEs.push($(this).attr('id'));
		});

	// Video-Player
	$('.CMM_adminList VIDEO').mediaelementplayer({alwaysShowControls:false, features:['playpause','current','duration','volume','fullscreen'], audioVolume:'vertical', pluginPath:'CMM/template/js/', flashName:'flashmediaelement.swf', silverlightName:'silverlightmediaelement.xap'});

	// Audio-Player
	$('.CMM_adminList AUDIO').mediaelementplayer({alwaysShowControls:true, features:['playpause','current','duration','volume'], audioVolume:'horizontal', audioWidth:'100%'});

	// Lightbox
	$("a.lightbox").colorbox({rel:$(this).attr('data-group'), maxWidth:'95%', maxHeight:'95%',previous:'&#xf053;' ,next:'&#xf054;' ,close:'&#xf00d;', current:'', slideshow:true, slideshowAuto:false, slideshowStart:'&#xf04b;' , slideshowStop:'&#xf04c;'});

	// Field-description - toggle
	$('.CMM_formDetails').on('click','.CMM_inputBoxTitle I.fa-question-circle',function(){
		// If field is open
		if($(this).hasClass('act'))
			{
			$(this).removeClass('act');
			$(this).closest('.CMM_inputBox').find('.CMM_inputBoxDescription').slideUp(500).animate({opacity:0},{queue:false, duration:250});
			}
		else
			{
			$(this).addClass('act');
			$(this).closest('.CMM_inputBox').find('.CMM_inputBoxDescription').css({opacity:0}).slideDown(500).animate({opacity:1},{queue:false, duration:750});
			}
		});

	// Config-Fields - hide if not set and toggle
	$('.CMM_inputBoxTitle INPUT[type=checkbox]','.CMM_formDetails').each(function() {
		if($(this).prop('checked') == false)
			{ $(this).closest('.CMM_inputBox').find('.CMM_inputBoxField').hide('fast'); }
		});
	$('.CMM_formDetails').on('click','.CMM_inputBoxTitle INPUT[type=checkbox]',function(){
		if($(this).prop('checked') == true)
			{ $(this).closest('.CMM_inputBox').find('.CMM_inputBoxField').slideDown(); }
		else
			{ $(this).closest('.CMM_inputBox').find('.CMM_inputBoxField').slideUp(); }
		});

	}); 
