/*************************************************************
* jQuery cmm3accordion plugin V 1.0.0
* This is a simple jQuery-based accordion-script.
* Copyright (c) 2016 Nicolas Berg GRAFIX21
* http://www.grafix21.de
*
* Licensed under the GNU General Public License: 
* http://www.gnu.org/licenses/gpl.html
**************************************************************/

(function($)
	{
    $.fn.cmm3accordion = function(options)
		{
		return this.each(function(i)
			{
			var accordion = this;
			accordion.accordion = $(this);
			accordion.index = i;

			// Combine default options with current options
			accordion.o = $.extend( {}, cmm3accordion.defaults, options );

			// Init vars
			accordion.toggles;
			accordion.panels;
			accordion.defaultIndex;
			accordion.blocked = false;
			accordion.maxPanelHeight = 0;

			// Init accordions
			cmm3accordion.init(accordion,i);
			});
		};
	
	////////////////////////////////////////


	cmm3accordion = {
		// init - set thumbs
		init: function(accordion,i)
			{
			// Check, if easing-plugin is loaded
			if(accordion.o.toggleEasing!='' && !jQuery.easing["jswing"])
				{
				console.log('Please install the jquery-easing-plugin for more organic animations on cmm3accordion!');
				accordion.o.toggleEasing = '';
				}

			// Set container-class
			if(accordion.o.classContainer!='' && !accordion.accordion.hasClass(accordion.o.classContainer))
				{ accordion.accordion.addClass(accordion.o.classContainer); }

			// Get toggles
			accordion.toggles = $(accordion.o.selectorToggle,accordion);
			// Set classes to toggles
			if(accordion.o.classToggle!='')
				{ accordion.toggles.addClass(accordion.o.classToggle); }

			// Get panels
			accordion.panels = $();
			accordion.toggles.each(function() {
				if(accordion.o.selectorPanel.indexOf('next()') > -1)
					{ currentPanel = $(this).next(); }
				else
					{ currentPanel = $(accordion.o.selectorPanel,accordion); }
				// Set classes to toggles
				if(accordion.o.classPanel!='')
					{ currentPanel.addClass(accordion.o.classPanel); }
				// Append to list
				accordion.panels = accordion.panels.add(currentPanel);
				});

			// Get max height panel
			if(accordion.o.equalizeHeight == true)
				{ cmm3accordion.getMaxHeightPanel(accordion); }

			// Set default panel (panel 0)
			accordion.defaultIndex = '';
			// Set default tab, if option alwasOpen == true (panel 0)
			if(accordion.o.defaultOpen == true)
				{
				accordion.defaultIndex = 0;
				}
			// Set default tab by plugin-option
			if(accordion.o.defaultIndex != '')
				{
				if(accordion.panels.eq(accordion.o.defaultIndex).length)
					{ accordion.defaultIndex = accordion.o.defaultIndex; }
				}
			// Set default tab by url-hash
			if(accordion.o.useHashIndex==true && window.location.hash)
				{
				var windowHash = window.location.hash.replace('#','');
				if(accordion.panels.eq(windowHash).length)
					{ accordion.defaultIndex = windowHash; }
				}
			accordion.defaultIndex = parseInt(accordion.defaultIndex);

			// Set default toggle
			accordion.toggles.eq(accordion.defaultIndex).addClass(accordion.o.classSelected);
			// Set default panel
			accordion.panels.eq(accordion.defaultIndex).addClass(accordion.o.classSelected);

			// Set click event
			$(accordion.toggles).each(function(index,element) {
				$(this).on('click',function(evt) {
					evt.preventDefault();
					// Call click function
					cmm3accordion.togglePanel(accordion,index);
					});
				});

			// Callback on init
			if(typeof accordion.o.onInit == 'function')
				{ accordion.o.onInit.call(accordion,accordion.defaultIndex); }
			},

		////////////////////////////////////////

		// Get panel max height
		getMaxHeightPanel: function(accordion)
			{
			// Loop each panel
			accordion.panels.each(function(index,element) {
				// Get height of panel selectorPanel
				panelHeight = $(this).outerHeight();

				// Set max height
				if(panelHeight > accordion.maxPanelHeight)
					{ accordion.maxPanelHeight = panelHeight; }
				});
			},

		////////////////////////////////////////

		// toggle the panels (by index)
		togglePanel: function(accordion,index)
			{
			if(accordion.blocked==false)
				{
				// Block while change is in progress
				accordion.blocked = true;

				// Close
				if(accordion.toggles.eq(index).hasClass(accordion.o.classSelected))
					{
					// Update location hash
					if(accordion.o.useHashIndex==true)
						{ window.location.hash = ''; }

					// Close current panel
					cmm3accordion.closePanel(accordion,index);
					}
				// Open
				else
					{
					// Update location hash
					if(accordion.o.useHashIndex==true)
						{ window.location.hash = index; }

					// Open current panel
					cmm3accordion.openPanel(accordion,index);
					}

				// Unblock after change is complete
				window.setTimeout(function() {
					accordion.blocked = false;
					}, accordion.o.toggleSpeed + 10);
				}
			},

		////////////////////////////////////////

		// show the panels (by index or all)
		openPanel: function(accordion,index)
			{
			// Open/Close toggles
			accordion.toggles.each(function(ind,element) {
				// Open selected or all
				if((ind == index || index==='') && !accordion.toggles.eq(ind).hasClass(accordion.o.classSelected))
					{ $(this).addClass(accordion.o.classSelected); }
				// Close - IF index not empty (open all) AND INDEX not current item AND current item has selected class AND o.multipleOpen is false
				else if((ind!=index || index!=='') && accordion.toggles.eq(ind).hasClass(accordion.o.classSelected) && accordion.o.multipleOpen==false)
					{ $(this).removeClass(accordion.o.classSelected); }
				});

			// Open panels
			accordion.panels.each(function(ind,element) {
				// Open IF index is curretn item OR index is empty and current item not has selected class
				if((ind===index || index==='') && !accordion.panels.eq(ind).hasClass(accordion.o.classSelected))
					{
					// Callback at start
					if(typeof accordion.o.onOpenStart == 'function')
						{ accordion.o.onOpenStart.call(accordion,ind); }

					// If equalize panel height - slideDown with animate function
					if(accordion.o.equalizeHeight==true && accordion.maxPanelHeight>0)
						{
						// Slide down
						$(this).css({'display':'block','height':0}).animate({height:accordion.maxPanelHeight+'px'},accordion.o.toggleSpeed,accordion.o.toggleEasing,function() {
							// Add class
							$(this).addClass(accordion.o.classSelected);

							// Callback at complete
							if(typeof accordion.o.onOpenComplete == 'function')
								{ accordion.o.onOpenComplete.call(accordion,ind); }
							});
						}
					// Regular slide down
					else
						{
						// Slide down
						$(this).slideDown(accordion.o.toggleSpeed,accordion.o.toggleEasing,function() {
							// Add class
							$(this).addClass(accordion.o.classSelected);

							// Callback at complete
							if(typeof accordion.o.onOpenComplete == 'function')
								{ accordion.o.onOpenComplete.call(accordion,ind); }
							});
						}
					}
				// Close - IF index not empty (open all) AND INDEX not current item AND current item has selected class AND o.multipleOpen is false
				else if((ind!=index || index!=='') && accordion.panels.eq(ind).hasClass(accordion.o.classSelected) && accordion.o.multipleOpen==false)
					{
					// Callback at start
					if(typeof accordion.o.onCloseStart == 'function')
						{ accordion.o.onCloseStart.call(accordion,ind); }
					// Remove class
					$(this).removeClass(accordion.o.classSelected);
					// Slide up
					$(this).slideUp(accordion.o.toggleSpeed,accordion.o.toggleEasing,function() {
						// Callback at complete
						if(typeof accordion.o.onCloseComplete == 'function')
							{ accordion.o.onCloseComplete.call(accordion,ind); }
						});
					}
				});

			},

		////////////////////////////////////////

		// Hide the panels (by index or all)
		closePanel: function(accordion,index)
			{
			// If index is set - close defined panel
			if(index !== '')
				{
				// Close toggle
				accordion.toggles.eq(index).removeClass(accordion.o.classSelected);
				// Callback at start
				if(typeof accordion.o.onCloseStart == 'function')
					{ accordion.o.onCloseStart.call(accordion,index); }
				// Close panel
				accordion.panels.eq(index).removeClass(accordion.o.classSelected).slideUp(accordion.o.toggleSpeed,accordion.o.toggleEasing,function() {
					// Callback at complete
					if(typeof accordion.o.onCloseComplete == 'function')
						{ accordion.o.onCloseComplete.call(accordion,index); }
					});
				}
			// Else - close all panels
			else
				{
				// Close toggles
				accordion.toggles.each(function(index,element) {
					$(this).removeClass(accordion.o.classSelected);
					});
				// Close panels
				accordion.panels.each(function(index,element) {
					// Callback at start
					if(typeof accordion.o.onCloseStart == 'function')
						{ accordion.o.onCloseStart.call(accordion,index); }
					// Close
					$(this).removeClass(accordion.o.classSelected).slideUp(accordion.o.toggleSpeed,accordion.o.toggleEasing,function() {
						// Callback at complete
						if(typeof accordion.o.onCloseComplete == 'function')
							{ accordion.o.onCloseComplete.call(accordion,index); }
						});
					});
				}
			},

		////////////////////////////////////////

		// Plugin defaults
		defaults: {

			toggleSpeed: 500, // Speed to for panel change
			toggleEasing: 'easeOutQuad', // Animation-Easing (requires the jquery-easing-plugin)
	
			defaultOpen: true, // always one panel open
			multipleOpen: false, // always one panel open
			defaultIndex: '', // Set id of start-panel ("#ID")
			useHashIndex: false, // Get and set slected panel by URL-hash
			equalizeHeight: false, // Equalize height of content-panels
	
			onInit: '', // Callback-function to perform when tabs are initialized
			onOpenStart: '', // Callback-function to perform when panel open starts
			onOpenComplete: '', // Callback-function to perform when panel open finished
			onCloseStart: '', // Callback-function to perform when panel close starts
			onCloseComplete: '', // Callback-function to perform when panel close finished
	
			selectorToggle: 'H3,H4', // Selector/Tag of the accordion toggles
			selectorPanel: "next()", // Selector/Tag of the accordion selectorPanel or simply use "next()"
	
			classContainer: 'accordion', // Class for container - will only be set, if not present
			classToggle: 'accordionToggle',
			classPanel: 'accordionContent',
			classSelected: 'act' // Class added to selected panel and toggle
			}

		}

	}(jQuery));
