/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

// V 1.0 First release
// V 2.0.0 Total recode

(function($)
	{
    $.fn.cmm3contextMenu = function(options)
		{
		return this.each(function(i)
			{
			var el = this;
			el = $(el);
			el.container = $(this);

			// Combine default options with current options
			el.o = $.extend( {}, cmm3contextMenu.defaults, options );

			var menu = $('<div>');
			menu.status = false;

			// Init cmm3contextMenu
			cmm3contextMenu.init(el,menu);
			});
		};
	
	////////////////////////////////////////

	cmm3contextMenu = {
		// Init
		init: function(el,menu)
			{
			// Add open menu event
			$(el).on('click contextmenu',function(evt) {
				evt.preventDefault();

					// Hide and remove menu					
				//	cmm3contextMenu.hideContextMenu(el,menu);
				// Show menu
				cmm3contextMenu.showContextMenu(el,menu,evt);
				});

			return ($(this));
			},

		//////////////////////////////////

		populateContextMenu: function(el,menu)
			{
			// Add contextMenu class
			menu = $(el.o.menu).clone();
			menu.removeAttr('id');
			menu.addClass(el.o.classContainer);

			// Get menu-item infos from data-Attrib "data-info"
			contextInfo = {};
			if(el.data('info'))
				{ contextInfo = el.data('info'); }

			// Replace variable-patterns with vars
			$.each(contextInfo, function(key, value) {
				var regexp = new RegExp('###'+key.toUpperCase()+'###',"g");
				menu.html(menu.html().replace(regexp,value));
				});

			// Get menu-item actions from data-Attrib "data-info"
			contextActions = {};
			if(el.data('actions'))
				{ contextActions = el.data('actions'); }

			// Enable/Disable menu-actions by action name
			$.each(contextActions, function(key, value) {
				if(value!=1)
					{ $('.'+key,menu).each(function() { $(this).remove(); }); }
				});

			// Insert menu into DOM
			menu.appendTo('body');

			// Set/Remove hover classes
			$(menu).find('A').mouseover(function() {
				$(this).parent().addClass(el.o.classHover);
			}).mouseout(function() {
				$(this).parent().removeClass(el.o.classHover);
				});

			return menu;
			},

		//////////////////////////////////

		showContextMenu: function(el,menu,evt)
			{
			menu = cmm3contextMenu.populateContextMenu(el,menu)

			// get mouse-click position
			x = evt.pageX;
			y = evt.pageY;

			// Show menu (first info-bar, second menu-items)
			$('> UL',menu).css('display','none');
			menu.css({display:'block', opacity:0, top:y, left:x-10 }).delay(200).animate({left:x, opacity:1}, el.o.inSpeed, function() {
				$('> UL',menu).slideDown(el.o.inSpeed);
				});

			// Set delay after show-event
			setTimeout(function()
				{
				// Set hot keys
				cmm3contextMenu.setHotKeys(el,menu);
				// Add close event to document 
				$(document).on('click.cmm3contextMenu contextmenu',function(evt) {
					// Hide and remove menu					
					cmm3contextMenu.hideContextMenu(el,menu);
					});
				},20);


			return el;
			},

		//////////////////////////////////

		hideContextMenu: function(el,menu)
			{
			// Fade out and remove menu
			$(menu).fadeOut(el.o.outSpeed,function() {
				$(this).remove();
				});

			// Remove close event from document
			$(document).off('click.cmm3contextMenu contextmenu');
			// Remove key events
			$(document).off('keyup.cmm3contextMenu');

			return el;
			},

		////////////////////////////////////////

		setHotKeys: function(el,menu)
			{
			// Keyboard
			$(document).on('keyup.cmm3contextMenu',function(evt) {
				// Get current hover item
				hoverItem = menu.find('LI.'+el.o.classHover);
				// Get current list
				if(hoverItem.length > 0)
					{ hoverItemList = hoverItem.closest('UL'); }
				else
					{ hoverItemList = $('UL',menu).eq(0); }

				// Switch for different keys
				switch(evt.keyCode)
					{
					// up
					case 38:
						if(hoverItem.length == 0)
							{ hoverItem = hoverItemList.find('> LI:last'); }
						else
							{
							hoverItem.removeClass(el.o.classHover);
							if(hoverItem.prevAll(':not(.separator)').first().length)
								{ hoverItem = hoverItem.prevAll(':not(.separator)').first(); }
							else
								{ hoverItem = hoverItemList.empty().find('> LI:last'); }
							}
						hoverItem.addClass(el.o.classHover);
						break;
					// down
					case 40:
						if(hoverItem.length == 0)
							{ hoverItem = hoverItemList.find('> LI:first'); }
						else
							{
							hoverItem.removeClass(el.o.classHover);
							if(hoverItem.nextAll(':not(.separator)').first().length)
								{ hoverItem = hoverItem.nextAll(':not(.separator)').first(); }
							else
								{ hoverItem = hoverItemList.find('> LI:first'); }
							}
						hoverItem.addClass(el.o.classHover);
						break;
					// enter
					case 13:
						hoverItem.find('> A')[0].click();
						break;
					// esc
					case 27:
						$(document).trigger('click');
						break
					}
				});
			},

		////////////////////////////////////////

		// Plugin defaults
		defaults: {
			// Dtemplateefaults
			menu: '', // selector for menu-template 
			inSpeed: 250, // Speed for opening effects
			outSpeed: 250, // Speed for closing effects
			leftButton: true, // show on left click
			rightButton: true, // show on right click
	
			classContainer: 'contextMenu', // Class for container - will be set, if not already present
			classHover: 'hov' // Class used to mark hovered menu items - reequired for hot-key events
			}

		}

	}(jQuery));
