/*
 * multiselect jQuery plugin
 * requires a SELECT-field with the possible options varname[options]
 * and a hidden-field with the selected values als csv-data varname[select]
 *
 * Copyright (c) 2014 Nicolas Berg
 * Dual licensed under the MIT (MIT-LICENSE.txt)
 * and GPL (GPL-LICENSE.txt) licenses.
 *
 * http://www.grafix21.de
 *
 */

(function($)
	{
	// Update the selected value
	function updateHiddenFieldValue(fieldRight,fieldHidden)
		{
		newHiddenValue = [];
		fieldRight.find('OPTION').each(function() {
			newHiddenValue.push($(this).val());
			});
		fieldHidden.val(newHiddenValue.join(','));
		};

	// Sort internal
	function internalSort(a, b)
		{
		var compA = $(a).text().toUpperCase();
		var compB = $(b).text().toUpperCase();
		return (compA < compB) ? -1 : (compA > compB) ? 1 : 0;
		};

	var methods = {
		init: function(options) {
			var o = {
				labelTop: 'Top',
				labelBottom: 'Bottom',
				labelUp: 'Up',
				labelDown: 'Down',
				labelLeft: 'Available',
				labelRight: 'Selected',
				maxSelected: -1,
				autoSort: false,
				autoSortAvailable: false,
				caseSensitive: false,
				delay: 200,
				minSize: 6
			};

			return this.each(function ()
				{
				var	el = $(this);
				var data = el.data('multiselect');

				if(options)
					{ $.extend(o, options); }

				if(!data)
					{ el.data('multiselect',o); }

				// Define field names
				var fieldOptions = el;
				var fieldHidden = el.prev();

				var	originalName = el.attr('name');
				var	fieldNameLeft = originalName.replace('[options]','[left]');
				var	fieldNameRight = originalName.replace('[options]','[right]');

				var selectedValues = fieldHidden.val().split(',');

				var size = el.attr("size");
				// SIZE MIN
				if(size < o.minSize)
					{
					$(this).attr("size", "" + o.minSize);
					size = o.minSize;
					}

				// CREATE NEW ELEMENT (AND HIDE IT) AFTER THE HIDDED ORGINAL SELECT
				var htmlToAdd =
					'<div class="multiselectContainer">' +
						'<div class="multiselectLeft">' +
						  '<div class="multiselectField">' +
						    '<div class="multiselectFieldLabel">' + o.labelLeft + '</div>' +
						    '<select title="' + o.labelLeft + '" name="' + fieldNameLeft + '" id="' + fieldNameLeft + '" size="' + size + '" multiple="multiple" ></select>' +
						  '</div>' +
						  '<div class="multiselectButtons">' +
							'<p class="multiselectButAddOne" title="Add Selected">&rsaquo;</p>' +
							'<p class="multiselectButAddAll" title="Add All">&raquo;</p>' +
							'<p class="multiselectButRemoveOne" title="Remove Selected">&lsaquo;</p>' +
							'<p class="multiselectButRemoveAll" title="Remove All">&laquo;</p>' +
						  '</div>' +
						'</div>' +
						'<div class="multiselectRight">' +
						  '<div class="multiselectField">' +
						    '<div class="multiselectFieldLabel">' + o.labelRight + '</div>' +
							'<select title="' + o.labelRight + '" name="' + fieldNameRight + '" id="' + fieldNameRight + '" size="' + size + '" multiple="multiple" ></select>' +
						  '</div>' +
						  '<div class="multiselectButtons">' +
							'<p class="multiselectButMoveTop" title="Move on top selected option">' + o.labelTop + '</p>' +
							'<p class="multiselectButMoveUp" title="Move up selected option">' + o.labelUp + '</p>' +
							'<p class="multiselectButMoveDown" title="Move down selected option">' + o.labelDown + '</p>' +
							'<p class="multiselectButMoveBottom" title="Move on bottom selected option">' + o.labelBottom + '</p>' +
						  '</div>'+
						'</div>' +
					'</div>';

				// Insert new elements after original select
				el.after(htmlToAdd).hide();

				// Get the left and the right select
				var allSel = el.parent().find(".multiselectContainer").find('SELECT');
				var	fieldLeft = el.parent().find(".multiselectLeft").find('SELECT');
				var	fieldRight = el.parent().find(".multiselectRight").find('SELECT');

				// POLPULATE LEFT AND RIGHT SELECT, FILTERED BY HIDDEN FIELD VALUES
				el.find('OPTION').each(function() {
					if(jQuery.inArray($(this).val(),selectedValues) == -1)
						{ $(this).clone().appendTo(fieldLeft); }
					});

				jQuery.map(selectedValues,function(value,index) {
					el.find('OPTION').each(function() {
						if($(this).val() == value)
							{ $(this).clone().appendTo(fieldRight); }
						});
					});

				// ON CHANGE SORT SELECTED OPTIONS
				var	nLastAutosort = 0;
				if(o.autoSort)
					{
					allSel.change(function()
						{
						var	fieldRightOptions = fieldRight.find('OPTION');

						if(fieldRightOptions.length != nLastAutosort)
							{
							// SORT SELECTED ELEMENT
							fieldRightOptions.sort(internalSort);
							// FIRST REMOVE FROM ORIGINAL SELECT
							el.find('OPTION:selected').remove();
							// AFTER ADD ON ORIGINAL AND RIGHT SELECT
							fieldRightOptions.each(function() {
								fieldRight.append($(this).clone());
								$(this).appendTo(el).attr('selected', true);
								});
							nLastAutosort = fieldRightOptions.length;
							}
						});
					}

				// ON CHANGE SORT AVAILABLE OPTIONS (NOT NECESSARY IN ORIGINAL SELECT)
				var	nLastAutosortAvailable = 0;
				if(o.autoSortAvailable)
					{
					allSel.change(function()
						{
						var	fieldLeftOptions = fieldLeft.find('OPTION');

						if(fieldLeftOptions.length != nLastAutosortAvailable)
							{
							// SORT SELECTED ELEMENT
							fieldLeftOptions.sort(internalSort);
							// REMOVE ORIGINAL ELEMENTS AND ADD SORTED
							fieldLeft.find('OPTION').remove();
							fieldLeftOptions.each(function() {
								fieldLeft.append($(this).clone());
								});
							nLastAutosortAvailable = fieldLeftOptions.length;
							}
						});
					}

				// ON CHANGE REFRESH ALL BUTTON STATUS
				allSel.change(function()
					{
					var	div = $(this).parent().parent();
					var	fieldLeftOptions = fieldLeft.children();
					var	fieldRightOptions = fieldRight.children();
					var	fieldLeftOptionsSelected = fieldLeft.find('OPTION:selected');
					var	fieldRightOptionsSelected = fieldRight.find('OPTION:selected');

					if(fieldLeftOptionsSelected.size() == 0 || (o.maxSelected >= 0 && (fieldLeftOptionsSelected.size() + fieldRightOptions.size()) > o.maxSelected))
						{ div.find(".multiselectButAddOne").addClass('multiselectDisabled'); }
					else
						{ div.find(".multiselectButAddOne").removeClass('multiselectDisabled'); }

					// FIRST HIDE ALL
					div.find(".multiselectButRemoveOne, .multiselectButMoveUp, .multiselectButMoveDown, .multiselectButMoveTop, .multiselectButMoveBottom").addClass('multiselectDisabled');
					if(fieldRightOptionsSelected.size() > 0)
						{
						div.find(".multiselectButRemoveOne").removeClass(' multiselectDisabled');
						// ALL SELECTED - NO MOVE
						if(fieldRightOptionsSelected.size() < fieldRightOptions.size())
							{
							// FIRST OPTION, NO UP AND TOP BUTTON
							if(fieldRightOptionsSelected.first().val() != fieldRightOptions.first().val())
								{ div.find(".multiselectButMoveUp, .multiselectButMoveTop").removeClass('multiselectDisabled'); }
							// LAST OPTION, NO DOWN AND BOTTOM BUTTON
							if(fieldRightOptionsSelected.last().val() != fieldRightOptions.last().val())
								{ div.find(".multiselectButMoveDown, .multiselectButMoveBottom").removeClass('multiselectDisabled'); }
							}
						}

					if(fieldLeftOptions.size() == 0 || (o.maxSelected >= 0 && fieldLeftOptions.size() >= o.maxSelected))
						{ div.find(".multiselectButAddAll").addClass('multiselectDisabled'); }
					else
						{ div.find(".multiselectButAddAll").removeClass('multiselectDisabled'); }

					if(fieldRightOptions.size() == 0)
						{ div.find(".multiselectButRemoveAll").addClass('multiselectDisabled'); }
					else
						{ div.find(".multiselectButRemoveAll").removeClass('multiselectDisabled'); }
					});

				// DOUBLE CLICK ON LEFT SELECT OPTION
				fieldLeft.dblclick(function () {
					$(this).find('OPTION:selected').each(function(i, selected)
						{
						if(o.maxSelected < 0 || fieldRight.children().size() < o.maxSelected) {
							$(this).remove().appendTo(fieldRight);
							el.find("[value='" + $(selected).val() + "']").remove().appendTo(el).attr('selected', true);
							}
						});

					fieldLeft.trigger('change');
					// Update hidden field value
					updateHiddenFieldValue(fieldRight,fieldHidden);
					});

				// DOUBLE CLICK ON RIGHT SELECT OPTION
				fieldRight.dblclick(function () {
					$(this).find('OPTION:selected').each(function(i, selected){
						$(this).remove().appendTo(fieldLeft);
						el.find("[value='" + $(selected).val() + "']").removeAttr('selected').remove().appendTo(el);
					});

					fieldRight.trigger('change');
					// TRIGGER CHANGE AND VALUE NULL FORM OPTGROUP SEARCH (IF EXIST)
					el.val("__null__").trigger("change");
					// Update hidden field value
					updateHiddenFieldValue(fieldRight,fieldHidden);
					});

				// CLICK ON OPTION
				$(this).parent().find('.multiselectLeft .multiselectButtons').children().click(function ()
					{
					if(!$(this).hasClass("multiselectDisabled"))
						{
						if($(this).hasClass("multiselectButAddOne"))
							{
							fieldLeft.find('OPTION:selected').each(function(i, selected){
								$(this).remove().appendTo(fieldRight);
								el.find("[value='" + $(selected).val() + "']").remove().appendTo(el).attr('selected', true);
								});
							}
						// ALL SELECTED
						else if($(this).hasClass("multiselectButAddAll"))
							{
							// TEST IF HAVE A FILTER OR A SELECT OPTGROUP
							if((el.length > 0 && el.val() != "__null__"))
								{
								fieldLeft.children().each(function(i, selected) {
									$(this).remove().appendTo(fieldRight);
									el.find("[value='" + $(selected).val() + "']").remove().appendTo(el).attr('selected', true);
									});
								}
							else
								{
								fieldLeft.children().remove().appendTo(fieldRight);
								el.find('option').attr('selected', true);
								// el.children().attr('selected', true); -- PROBLEM WITH OPTGROUP
								}
							}
						else if($(this).hasClass("multiselectButRemoveOne"))
							{
							fieldRight.find('OPTION:selected').each(function(i, selected){
								$(this).remove().appendTo(fieldLeft);
								el.find("[value='" + $(selected).val() + "']").remove().appendTo(el).removeAttr('selected');
								});
							// TRIGGER CHANGE AND VALUE NULL FORM OPTGROUP SEARCH (IF EXIST)
							el.val("__null__").trigger("change");
							}
						// ALL REMOVED
						else if($(this).hasClass("multiselectButRemoveAll"))
							{	
							fieldRight.children().appendTo(fieldLeft);
							fieldRight.children().remove();
							el.find('option').removeAttr('selected');
							//el.children().removeAttr('selected'); -- PROBLEM WITH OPTGROUP
							// TRIGGER CHANGE AND VALUE NULL FORM OPTGROUP SEARCH (IF EXIST)
							el.val("__null__").trigger("change");
							}
						}

					fieldLeft.trigger('change');
					// Update hidden field value
					updateHiddenFieldValue(fieldRight,fieldHidden);
					});

				// CLICK ON UP - DOWN
				$(this).parent().find('.multiselectRight .multiselectButtons').children().click(function ()
					{
					var	fieldRightOptions = fieldRight.find('OPTION');
					var	fieldRightOptionsSelected = fieldRight.find('OPTION:selected');

					if(!$(this).hasClass("multiselectDisabled"))
						{
						if($(this).hasClass("multiselectButMoveUp"))
							{
							var	prev = fieldRightOptionsSelected.first().prev();
							var	hPrev = el.find("[value='" + prev.val() + "']");

							fieldRightOptionsSelected.each(function() {
								$(this).insertBefore(prev);
								el.find("[value='" + $(this).val() + "']").insertBefore(hPrev);	// HIDDEN SELECT
								});
							}
						else if($(this).hasClass("multiselectButMoveDown"))
							{
							var	next = fieldRightOptionsSelected.last().next();
							var	hNext = el.find("[value='" + next.val() + "']");

							fieldRightOptionsSelected.each(function() {
								$(this).insertAfter(next);
								el.find("[value='" + $(this).val() + "']").insertAfter(hNext);	// HIDDEN SELECT
								});
							}
						else if($(this).hasClass("multiselectButMoveTop"))
							{
							var	first = fieldRightOptions.first();
							var	hFirst = el.find("[value='" + first.val() + "']");

							fieldRightOptionsSelected.each(function() {
								$(this).insertBefore(first);
								el.find("[value='" + $(this).val() + "']").insertBefore(hFirst);	// HIDDEN SELECT
								});
							}
						else if($(this).hasClass("multiselectButMoveBottom"))
							{
							var	last = fieldRightOptions.last();
							var	hLast = el.find("[value='" + last.val() + "']");

							fieldRightOptionsSelected.each(function() {
								last = $(this).insertAfter(last);	// WITH last = SAME POSITION OF SELECTED OPTION AFTER MOVE
								hLast = el.find("[value='" + $(this).val() + "']").insertAfter(hLast);	// HIDDEN SELECT
								});
							}
						}

					fieldRight.trigger('change');
					// Update hidden field value
					updateHiddenFieldValue(fieldRight,fieldHidden);
					});

				// UPDATE BUTTON ON START
				fieldLeft.trigger('change');

				// SHOW WHEN ALL READY
				$(this).parent().show();
			});
		},

		destroy: function( ) {
			return this.each(function () {
				var	el = $(this);
				var data = el.data('multiselect');

				if(!data)
					return;

				el.show().next().remove();
			});
		},
	};

  $.fn.multiselect = function(method)
  	{
    if(methods[method])
		{ return methods[method].apply( this, Array.prototype.slice.call(arguments, 1)); }
	else if(typeof method === 'object' || ! method)
		{ return methods.init.apply(this, arguments); }
	else
		{ $.error('Method ' +  method + ' does not exist on jQuery.multiselect' ); }
	};

})(jQuery);