/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

/*************************************************************
* jQuery TableBuilder plugin V 0.8.1
**************************************************************/

(function($)
	{
    $.fn.tableBuilder = function (options) {

		var container = this;
		var containerTable;
		var containerButtons;
		var tableHtml;
		var tableValues = '';

		////////////////////////////////////////

		function tableBuilderInit()
			{
			// Button-Container einfuegen
			container.prepend('<div class="CMM_tableBuilderButtons"></div>');
			// Tabellen-Container initialisieren
			containerButtons = $('.CMM_tableBuilderButtons',container);
			// Button zum Erzeuge der Tabelle einfuegen
			containerButtons.append('<input type="button" value="Tabelle erzeugen" class="CMM_tableBuilderButAddTable CMM_button" />');
			$('.CMM_tableBuilderButAddTable',container).click(function() { addTable(); });
			// Button zum Ein-/Ausblenden des Datenfeldes
			containerButtons.append('<input type="button" value="Datenfeld ein-/ausblenden" class="CMM_tableBuilderButToggleData CMM_button" />');
			$('.CMM_tableBuilderButToggleData',container).click(function() { $('TEXTAREA',container).parent().slideToggle(); });
			$('.CMM_tableBuilderButToggleData',container).hide();
			// Button zum Loeschen der Tabelle
			containerButtons.append('<input type="button" value="Tabelle löschen" class="CMM_tableBuilderButDeleteTable CMM_button" />');
			$('.CMM_tableBuilderButDeleteTable',container).click(function() { deleteTable(); });
			$('.CMM_tableBuilderButDeleteTable',container).hide();

			// Tabellen-Container einfuegen
			container.prepend('<div class="CMM_tableBuilderTable"></div>');
			// Tabellen-Container initialisieren
			containerTable = $('.CMM_tableBuilderTable',container);

			// Ueberwachung der Input-Felder
			$('INPUT',containerTable).live('keyup',function() { fixInputValue(this); });

			// bereits Vorhandene Tabellen-Daten aufbereiten
			if($('TEXTAREA',container).val() != '')
				{
				addTable();
				$('TEXTAREA',container).parent().hide();
				}
			}

		////////////////////////////////////////

		// Eingabewerte fixen
		function fixInputValue(input)
			{
			// Pipe-Symbol aus Tebellenfeld entfernen
			var tableCellInput = $(input).val();
			if(tableCellInput.indexOf('|') > -1)
				{
				tableCellInput = tableCellInput.replace(/[|]/g,"");
				$(input).val(tableCellInput);
				}
		
			// Daten in Textarea uebertragen
			updateTableData();
			}

		////////////////////////////////////////

		// Eingabewerte uebertragen
		function updateTableData()
			{
			// Tabellenfelder auslesen
			tableValues = '';
			$('TR',containerTable).each(function(rowIndex) {
				rowIndex > 1 ? tableValues+= "\r\n" : '';
				$('TD INPUT',this).each(function(colIndex) {
					colIndex > 0 ? tableValues+= '|' : '';
					// Zellenwert auslesen
					cellValue = $(this).val().trim();
					tableValues+=cellValue;
					});
				});
			// Tabellenferlder als String an Textarea uebergeben
			$('TEXTAREA',container).val(tableValues);
			}

		////////////////////////////////////////

		// leere Tabelle erzeugen
		function addTable()
			{
			// Daten auslesen und in Array umwandeln
			tableData = $('TEXTAREA',container).val();
			
			// Daten in Datenfeld vorhanden
			if(tableData.replace(/^ /,"&nbsp;").replace(/ $/,"&nbsp;") != '')
				{
				tableData = tableData.replace(/&nbsp;/g,' ').replace(/\r/g,'').split("\n");
				cols = 0;
				rows = tableData.length;
				for(line=0; line<tableData.length; line++)
					{
					tableData[line] = tableData[line].split("|");
					// maximale Spaltenanzahl ermitteln
					tableData[line].length > cols ? cols = tableData[line].length : '';
					}
				}
			// keine Daten in Datenfeld vorhanden - Musterdaten erzeugen
			else
				{
				tableData = new Array();
				cols = 3;
				rows = 3;
				for(tr=0; tr<4; tr++)
					{
					tableData[tr] = new Array();
					for(td=0; td<4; td++)
						{
						tableData[tr][td] = '';
						}	
					}	
				}

			// Tabelle konstruieren
			tableHtml = '<table>';
			for(tr=-1; tr<rows; tr++)
				{
				tableHtml+= '<tr>';
				// erste Zeile
				if(tr == -1)
					{
					for(td=-1; td<cols; td++)
						{
						// erste Spalte
						if(td == -1)
							{ tableHtml+= '<th width="50">&nbsp;</th>'; }
						// folgende Spalten
						else
							{ tableHtml+= '<th><span class="CMM_tableBuilderButAddColumn" title="Spalte rechts einfügen"></span><span class="CMM_tableBuilderButDeleteColumn" title="Spalte löschen"></span></th>'; }
						}
					}
				// folgende Zeilen
				else
					{
					for(td=-1; td<cols; td++)
						{
						// erste Spalte
						if(td == -1)
							{ tableHtml+= '<th><span class="CMM_tableBuilderButAddRow" title="Zeile unterhalb einfügen"></span><span class="CMM_tableBuilderButDeleteRow" title="Zeile löschen"></span></th>'; }
						// folgende Spalten
						else
							{ tableHtml+= '<td><input value="'+tableData[tr][td]+'" /></td>'; }
						}
					}
				tableHtml+= '</tr>';
				}
			tableHtml+= '</table>';

			// Tabellen-Code einfuegen
			containerTable.append(tableHtml);

			// Textarea ausblenden
			containerTable.slideDown();
			
			// Button zum Einfuegen einer Zeile
			$('.CMM_tableBuilderButAddRow',containerTable).unbind('click').click(function() { addTableRow(this); });

			// Button zum Loeschen einer Zeile
			$('.CMM_tableBuilderButDeleteRow',containerTable).unbind('click').click(function() { deleteTableRow(this); });

			// Button zum Einfuegen einer Spalte
			$('.CMM_tableBuilderButAddColumn',containerTable).unbind('click').click(function() { addTableColumn(this); });

			// Button zum Loeschen einer Spalte
			$('.CMM_tableBuilderButDeleteColumn',containerTable).unbind('click').click(function() { deleteTableColumn(this); });
		
			// Button Tabelle erzeugen verbergen
			$('.CMM_tableBuilderButAddTable',container).hide();

			// Button Tabellen-Daten ein-/ausblenden einblenden
			$('.CMM_tableBuilderButToggleData',container).show();

			// Button Tabelle löschen einblenden
			$('.CMM_tableBuilderButDeleteTable',container).show();
		
			// Textarea ausblenden
			$('TEXTAREA',container).parent().slideUp();

			// Daten in Textarea uebertragen
			updateTableData();
			}

		////////////////////////////////////////

		// Tabelle loeschen
		function deleteTable()
			{
			// Bestaetigung
			if(confirm('Wollen Sie die gesamte Tabelle löschen?')==true)
				{
				// leeren String an Textarea uebergeben
				$('TEXTAREA',container).val('');

				// Tabelle entfernen
				containerTable.slideUp(500,	function(){
					$('.CMM_tableBuilderButToggleData',containerTable).remove();
					$('TABLE',containerTable).remove();
					});
				$('TEXTAREA',container).parent().slideDown();
				
				// Button Tabelle erzeugen einblenden
				$('.CMM_tableBuilderButAddTable',container).show();

				// Button Tabellen-Daten ein-/ausblenden einblenden
				$('.CMM_tableBuilderButToggleData',container).hide();

				// Button Tabelle löschen einblenden
				$('.CMM_tableBuilderButDeleteTable',container).hide();
				}
			}

		////////////////////////////////////////

		// Zeile einfuegen
		function addTableRow(button)
			{
			// Zeile identifizieren
			var rowIndex = button.parentNode.parentNode.rowIndex;
		
			// Zeilen und Spalten zaehlen
			var rowCount = $('TABLE TR TD:nth-child(2)',containerTable).length;
			var columnCount = $("TABLE TR:nth-child(2) TD",containerTable).length;
		
			// neue Zeile konstruieren
			var tableNewRow = '<tr><th><span class="CMM_tableBuilderButAddRow" title="Zeile unterhalb einfügen"></span><span class="CMM_tableBuilderButDeleteRow" title="Zeile löschen"></span></th>';
			for(i=0; i<columnCount; i++)
				{ tableNewRow+= '<td><input type="text" value=""></td>'; }
			tableNewRow+= '</tr>';
		
			// neue Zeile anfuegen
		//	$(datafield+' .CMM_tableBuilderTable TABLE').append(CMM_tableNewRow);
			$('TABLE TR',containerTable).eq(rowIndex).after(tableNewRow);
		
			// Button zum Einfuegen einer Zeile
			$('.CMM_tableBuilderButAddRow',containerTable).unbind('click').click(function() { addTableRow(this); });

			// Button zum Loeschen einer Zeile
			$('.CMM_tableBuilderButDeleteRow',containerTable).unbind('click').click(function() { deleteTableRow(this); });

			// Daten in Textarea uebertragen
			updateTableData();
			}
		
		////////////////////////////////////////
		
		// Zeile loeschen
		function deleteTableRow(button)
			{
			// Zeile identifizieren
			var rowIndex = button.parentNode.parentNode.rowIndex;
		
			// Zeilen und Spalten zaehlen
			var rowCount = $('TABLE TR TD:nth-child(2)',containerTable).length;
			var columnCount = $("TABLE TR:nth-child(2) TD",containerTable).length;
		
			// nur loeschen, wenn mehr als eine Zeile vorhanden ist
			if(rowCount>1)
				{
				$('TABLE TR',containerTable).eq(rowIndex).remove();
				}
		
			// Daten in Textarea uebertragen
			updateTableData();
			}
		
		////////////////////////////////////////
		
		// Spalte hinzufuegen
		function addTableColumn(button)
			{
			// Zeile identifizieren
			var cellIndex = button.parentNode.cellIndex;
		
			// Zeilen und Spalten zaehlen
			var rowCount = $('TABLE TR TD:nth-child(2)',containerTable).length;
			var columnCount = $("TABLE TR:nth-child(2) TD",containerTable).length;
		
			// neue Spalte konstruieren (Kopfzeile)
			var tableNewColumn = '<th><span class="CMM_tableBuilderButAddColumn" title="Spalte rechts einfügen"></span><span class="CMM_tableBuilderButDeleteColumn" title="Spalte löschen"></span></th>';
			$('TABLE TR:nth-child(1) TH',containerTable).eq(cellIndex).after(tableNewColumn);
		
			// neue Spalte konstruieren (Folgezeilen)
			for(i=1; i<=rowCount; i++)
				{
				tableNewColumn = '<td><input type="text" value=""></td>';
				$('TABLE TR:nth-child('+(i+1)+') TD',containerTable).eq(cellIndex-1).after(tableNewColumn);
				}
	
			// Button zum Einfuegen einer Spalte
			$('.CMM_tableBuilderButAddColumn',containerTable).unbind('click').click(function() { addTableColumn(this); });

			// Button zum Loeschen einer Spalte
			$('.CMM_tableBuilderButDeleteColumn',containerTable).unbind('click').click(function() { deleteTableColumn(this); });

			// Daten in Textarea uebertragen
			updateTableData();
			}
		
		////////////////////////////////////////
		
		// Spalte loeschen
		function deleteTableColumn(button)
			{
			// Zeile identifizieren
			var cellIndex = button.parentNode.cellIndex;
		
			// Zeilen und Spalten zaehlen
			var rowCount = $('TABLE TR TD:nth-child(2)',containerTable).length;
			var columnCount = $("TABLE TR:nth-child(2) TD",containerTable).length;
		
			// nur loeschen, wenn mehr als eine Spalte vorhanden ist
			if(columnCount>1)
				{
				// Spalte entfernen (Kopfzeile)
				$('TABLE TR:nth-child(1) TH',containerTable).eq(cellIndex).remove();
				// Spalte entfernen (Folgezeilen)
				for(i=1; i<=rowCount; i++)
					{ $('TABLE TR:nth-child('+(i+1)+') TD',containerTable).eq(cellIndex-1).remove(); }
				}
		
			// Daten in Textarea uebertragen
			updateTableData();
			}
		
		////////////////////////////////////////
		
		// TabelBuilder starten
		if(this.html() != null)
			{ tableBuilderInit(); }

		}

	})(jQuery);
