/*************************************************************
* jQuery cmm3tabs plugin V 1.0.0
* This is a simple jQuery-based tabs-script.
* Copyright (c) 2016 Nicolas Berg GRAFIX21
* http://www.grafix21.de
*
* Licensed under the GNU General Public License: 
* http://www.gnu.org/licenses/gpl.html
**************************************************************/

(function($)
	{
    $.fn.cmm3tabs = function(options)
		{
		return this.each(function(i)
			{
			var tabs = this;
			tabs.tabs = $(this);
			tabs.index = i;

			// Combine default options with current options
			tabs.o = $.extend( {}, cmm3tabs.defaults, options );

			// Init vars
			tabs.toggleSet;
			tabs.toggles;
			tabs.panelSet;
			tabs.panels;
			tabs.panelIDs;
			tabs.defaultID;
			tabs.currentID;
			tabs.newID;
			tabs.blocked = false;
			tabs.maxContentHeight = 0;

			// Init tabss
			cmm3tabs.init(tabs,i);
			});
		};
	
	////////////////////////////////////////


	cmm3tabs = {
		// init - set thumbs
		init: function(tabs,i)
			{
			// Check, if easing-plugin is loaded
			if(tabs.o.toggleEasing!='' && !jQuery.easing["jswing"])
				{
				console.log('Please install the jquery-easing-plugin for more organic animations on cmm3tabs!');
				tabs.o.toggleEasing = '';
				}
			// Set container-class
			if(tabs.o.classContainer!='' && !tabs.tabs.hasClass(tabs.o.classContainer))
				{ tabs.tabs.addClass(tabs.o.classContainer); }

			// Get toggles
			tabs.toggleSet = $(tabs.o.selectorToggleSet,tabs);
			tabs.toggles = $(tabs.o.selectorToggle,tabs.toggleSet);
			// Set classes to toggles
			if(tabs.o.classToggleSet!='')
				{ tabs.toggleSet.addClass(tabs.o.classToggleSet); }
			if(tabs.o.classToggle!='')
				{ tabs.toggles.addClass(tabs.o.classToggle); }

			// Get panels
			tabs.panelSet = $(tabs.o.selectorContentSet,tabs);
			tabs.panels = $(tabs.o.selectorContent,tabs.panelSet);
			// Set classes to panels
			if(tabs.o.classContentSet!='')
				{ tabs.panelSet.addClass(tabs.o.classContentSet); }
			if(tabs.o.classContent!='')
				{ tabs.panels.addClass(tabs.o.classContent); }
	
			// Get max height panel
			if(tabs.o.equalizeHeight == true)
				{ cmm3tabs.getMaxHeightContent(tabs); }

			// Get all panel-IDs
			tabs.panelIDs = [];
			$('A',tabs.toggleSet).each(function() {
				tabs.panelIDs.push($(this).attr('href'));
				});
		
			// Set default tab (panel 0)
			tabs.defaultID = tabs.panelIDs[0];
			// Set default tab by plugin-option
			if(tabs.o.defaultID != false)
				{
				if($.inArray(tabs.o.defaultID,tabs.panelIDs) > -1)
					{ tabs.defaultID = tabs.o.defaultID; }
				}
			// Set default tab by url-hash
			if(tabs.o.useHashID==true && window.location.hash)
				{
				var windowHash = window.location.hash;
				if($.inArray(windowHash,tabs.panelIDs) > -1)
					{ tabs.defaultID = windowHash; }
				}
			// Set current id
			tabs.currentID = tabs.defaultID;
	
			// Set default toggle
			$('A[href="'+tabs.defaultID+'"]',tabs.toggleSet).closest(tabs.o.selectorToggle.replace('> ','')).addClass(tabs.o.classSelected);
			// Set default panel
			$(tabs.defaultID,tabs.panelSet).addClass(tabs.o.classSelected);
	
			// Set click event
			$('A',tabs.toggleSet).each(function(index,element) {
				$(this).on('click',function(evt) {
					evt.preventDefault();
					// Call click function
					cmm3tabs.toggle(tabs,$(this).attr('href'));
					});
				});

			// Callback on init
			if(typeof tabs.o.onInit == 'function')
				{ tabs.o.onInit.call(tabs,tabs.defaultIndex); }
			},
	
	
		////////////////////////////////////////


		// Get panel max height
		getMaxHeightContent: function(tabs)
			{
			// Loop each panel
			tabs.panels.each(function(index,element) {
				// Get height of panel selectorContent
				panelHeight = $(this).outerHeight();

				// Set max height
				if(panelHeight > tabs.maxContentHeight)
					{ tabs.maxContentHeight = panelHeight; }
				});
			},


		////////////////////////////////////////
	
	
		// Change tabs
		toggle: function(tabs,newID)
			{
			// Change only if not currently shown
			if(newID != tabs.currentID && tabs.blocked==false)
				{
				// Get id of clicked toggle
				tabs.newID = newID;

				// Block while toggle is in progress
				tabs.blocked = true;

				// Callback at start
				if(typeof tabs.o.onToggleStart == 'function')
					{ tabs.o.onToggleStart.call(tabs,tabs.newID); }
	
				// Update location hash
				if(tabs.o.useHashID==true)
					{ window.location.hash = tabs.newID; }

				// Get current toggle (element around a-tag)
				currentToggle = $(tabs.o.selectorToggle+' [href="'+tabs.newID+'"]',tabs.toggleSet).closest(tabs.o.selectorToggle.replace('> ',''));

				// Change toggles
				$(tabs.o.selectorToggle,tabs.toggleSet).removeClass(tabs.o.classSelected);
				currentToggle.addClass(tabs.o.classSelected);
	
				// Slide effect
				if(tabs.o.toggleEffect == 'slide')
					{
					// Equal height - animate
					if(tabs.o.equalizeHeight==true && tabs.maxContentHeight>0)
						{
						$(tabs.panels).slideUp(tabs.o.toggleSpeed,tabs.o.toggleEasing).removeClass(tabs.o.classSelected);
						$(tabs.o.selectorContent+tabs.newID, tabs.panelSet).css({'display':'block','height':0}).animate({height:tabs.maxContentHeight+'px'},tabs.o.toggleSpeed,tabs.o.toggleEasing,function() {
							$(this).addClass(tabs.o.classSelected);
							tabs.currentID = tabs.newID;
	
							// Callback at complete
							if(typeof tabs.o.onToggleComplete == 'function')
								{ tabs.o.onToggleComplete.call(tabs,tabs.newID); }
	
							// Unblock tabs
							tabs.blocked = false;
							});
						}
					// Different height - slideDown
					else
						{
						$(tabs.panels).slideUp(tabs.o.toggleSpeed,tabs.o.toggleEasing).removeClass(tabs.o.classSelected);
						$(tabs.o.selectorContent+tabs.newID, tabs.panelSet).slideDown(tabs.o.toggleSpeed,tabs.o.toggleEasing,function() {
							$(this).addClass(tabs.o.classSelected);
							tabs.currentID = tabs.newID;
	
							// Callback at complete
							if(typeof tabs.o.onToggleComplete == 'function')
								{ tabs.o.onToggleComplete.call(tabs,tabs.newID); }
	
							// Unblock tabs
							tabs.blocked = false;
							});
						}
					}
				// Fade effect
				else
					{
					$(tabs.panels).css('display','none').removeClass(tabs.o.classSelected);
					if(tabs.o.equalizeHeight==true && tabs.maxContentHeight>0)
						{ $(tabs.o.selectorContent+tabs.newID, tabs.panelSet).css({height:tabs.maxContentHeight+'px'}); }
					$(tabs.o.selectorContent+tabs.newID, tabs.panelSet).fadeIn(tabs.o.toggleSpeed,tabs.o.toggleEasing,function() {
						$(this).addClass(tabs.o.classSelected);
						tabs.currentID = tabs.newID;
	
						// Callback at complete
						if(typeof tabs.o.onToggleComplete == 'function')
							{ tabs.o.onToggleComplete.call(tabs,tabs.newID); }
	
						// Unblock tabs
						tabs.blocked = false;
						});
					}
				}
			},
	

		////////////////////////////////////////

	
		// These are the defaults
		defaults: {
			toggleSpeed: 500, // Speed to for panel toggle
			toggleEasing: 'easeOutQuart', // Animation-Easing (requires the jquery-easing-plugin)
			toggleEffect: 'fade', // Effect for panel toggle (fade/slide)
	
			defaultID: false, // Set id of start-panel ("#ID")
			useHashID: false, // Get and set slected panel by URL-hash
			equalizeHeight: false, // Equalize height of content-panels

			onInit: '', // Callback-function to perform when tabs are initialized
			onToggleStart: '', // Callback-function to perform when panel chang starts
			onToggleComplete: '', // Callback-function to perform when panel has toggled
	
			selectorToggleSet: '> UL', // Selector for toggles (has to be inside the tab-container)
			selectorToggle: '> LI', // Selector for each toggle (has to be inside the toggles-container)
			selectorContentSet: '> DIV', // Selector for panels (has to be inside the tab-container)
			selectorContent: '> DIV', // Selector for each panel (has to be inside the panels-container)

			classContainer: 'tabs', // Class set to container
			classToggleSet: 'tabsToggles', // Class set to toggles-container
			classToggle: 'tabsToggle', // Class set to each toggle
			classContentSet: 'tabsContents', // Class set to panel-container
			classContent: 'tabsContent', // Class set to each panel
			classSelected: 'act' // Class added to selected panel and toggle
			}

		}

	})(jQuery);