<?PHP
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////
// Plugin fuer Navigationen                              //
///////////////////////////////////////////////////////////
// V 1.0 First release
// V 1.0.1 marginale Anpassungen
// V 1.1.0 Parameterverarbeitung
// V 1.2.0 Umstellung auf CMM3
// V 1.2.1 Umzug con CMM_Contents nach CMM_Page[CMM]
// V 1.2.2 um Parameter wrapText erweitert
// V 1.2.3 BUGFIX: nur Seiten in Navi aus DB holen
// V 1.2.4 Erkennung metaMode -> keine Ausfuehrung
// V 1.2.5 Feld-Definitionen eingefuegt
// V 1.2.6 Korrektur beim Laden der Seitenliste
// V 1.2.7 QUALITY-FIX
// V 1.2.8 wrapLink eingefuegt, Defaults angepasst
// V 1.2.9 Navi-Objekt angepasst
// V 1.3.0 params absolute and domain added
///////////////////////////////////////////////////////////

include_once(CMM_ROOT_DIR.'CMM/classes/class.page.php');

/* PARAMS START - Marker-Comments required! */
$params = array(
	'startID' => 1, // Start-ID
	'startLevel' => 0, // Ausgabe Start ab Level
	'range' => '', // Anzahl der Ebenen ab startLevel
	'absolute' => 0, // Make Links absolute
	'domain' => '', // Use this Domain for absolute links

	// Eigenschaften fuer alle Ebenen
	'expAll' => '', // alle Navigationspunkte der Ebene aktiviere/ausgeben
	'enableStatus' => 'nor,act,cur,sub', // 'nor,act,cur,norsub,actsub,cursub', // Erlaubte Navigationszustaende
	'target' => '', // Linkt-Target
	'crop' => '', // Ausgabe des Titels kuerzen
	'wrapAll' => '', // Wrap um gesamte Navi
	'wrapLevel' => '<ul>*</ul>', // Wrap um Navigationsebene
	'wrapItemAndSub' => '<li class="###STATUS######FIRSTLAST###">*</li>', // Wrap um Navigationspunkt und Unterpunkte
	'wrapItem' => '', // Wrap um Navigationspunkt
	'wrapLink' => '<a href="###LINK###" ###TARGET### title="###TITLE###" ###EXTERNAL###>*</a>', // Wrap Link
	'wrapText' => '###ICON###*', // Wrap um Navigationstext
	'cacheTimeout' => 86400

	// Eigenschaften fuer spezielle Ebenen (0-n)
//	'expAll0' => '',
//	'enableStatus0' => 'nor,act,cur',
//	'target0' => '',
//	'crop0' => '',
//	'wrapItem0' => '<div>*</div><span>###DESCRIPTION###</span>',
//	'wrapItemAndSub0' => '<li class="###STATUS######FIRSTLAST###">*</li>',
//	'wrapLevel0' => '<ul>*</ul>'
	);
/* PARAMS END */

/* FIELDSET START - Marker-Comments required! */
$fieldset = array(
	'startID' => array('label'=>'Start-Seite (PID)','type'=>'linkfield','position'=>'left'),
	'startLevel' => array('label'=>'Start-Ebene','type'=>'textfield','datatype'=>'int','position'=>'left'),
	'range' => array('label'=>'Anzahl der Ebenen ab startLevel','type'=>'textfield','datatype'=>'int','position'=>'left'),
	'expAll' => array('label'=>'Alle Ebenen der Navigation anzeigen','type'=>'checkbox','options'=>array(array('value'=>'1','text'=>'{LANG_CMM_YES}')),'text'=>'ja','datatype'=>'text','position'=>'left'),
	'enableStatus' => array('label'=>'Navigations-Stati (nor,act,cur,norifsub,actifsub,curifsub)','type'=>'textfield','datatype'=>'text','position'=>'right','shy'=>1),
	'target' => array('label'=>'Link: Target','type'=>'textfield','datatype'=>'text','position'=>'right','shy'=>1),
	'crop' => array('label'=>'Titel: Ausgabe kuerzen (Zeichen)','type'=>'textfield','datatype'=>'int','position'=>'right','shy'=>1),
	'absolute' => array('label'=>'Link: absolute (mit Domain)','type'=>'checkbox','options'=>array(array('value'=>'1','text'=>'{LANG_CMM_YES}')),'text'=>'ja','position'=>'right','shy'=>1),
	'domain' => array('label'=>'Link: Protokoll und Domain','type'=>'textfield','datatype'=>'code','position'=>'right','shy'=>1),
	'wrapAll' => array('label'=>'Wrap um gesamte Navigation','type'=>'textfield','datatype'=>'code','position'=>'bottom','shy'=>1),
	'wrapLevel' => array('label'=>'Wrap um Navigationsebene','type'=>'textfield','datatype'=>'code','position'=>'bottom','shy'=>1),
	'wrapItemAndSub' => array('label'=>'Wrap um Navigationspunkt mit Unterpunkten','type'=>'textfield','datatype'=>'code','position'=>'bottom','shy'=>1),
	'wrapItem' => array('label'=>'Wrap um Navigationspunkt','type'=>'textfield','datatype'=>'code','position'=>'bottom','shy'=>1),
	'wrapLink' => array('label'=>'Wrap um Link (inkl. A-Tag)','type'=>'textfield','datatype'=>'code','position'=>'bottom','shy'=>1),
	'wrapText' => array('label'=>'Wrap um Navigationspunkt-Text','type'=>'textfield','datatype'=>'code','position'=>'bottom','shy'=>1),
	'cacheTimeout' => array('label'=>'{LANG_CMM_CACHE_TIMEOUT}','type'=>'textfield','datatype'=>'int','position'=>'bottom','shy'=>1)
	);
/* FIELDSET END */


// Set customer group
$params['CustomerCustomergroupID'] = isset($GLOBALS['CustomergroupUID']) ? $GLOBALS['CustomergroupUID'] : 0;
// Set language
$params['LID'] = isset($GLOBALS['LanguageUID']) ? $GLOBALS['LanguageUID'] : 1;

// Merge params and pluginParams
if(is_array($pluginParams) && sizeof($pluginParams) > 0)
	{
	foreach($pluginParams as $pluginParamsKey => $pluginParamsValue)
		{
		if(isset($params[$pluginParamsKey]) && isset($pluginParams[$pluginParamsKey]) && is_array($params[$pluginParamsKey]) && is_array($pluginParams[$pluginParamsKey]))
			{ $params[$pluginParamsKey] = array_merge($params[$pluginParamsKey],$pluginParams[$pluginParamsKey]); }
		else
			{ $params[$pluginParamsKey] = $pluginParams[$pluginParamsKey]; }
		}	
	}

// Inhalt ausgeben, wenn nicht im metaMode 
$mainNavi = new Navi;
// alle aktiven und fuer Navi frei gegebenen Seiten einlesen
!empty($_SESSION['customer']['CustomergroupID']) ? $CoustomergroupID = $_SESSION['customer']['CustomergroupID'] : $CoustomergroupID='';
$mainNaviPages = DB_CMM_pageGetList($CONFIG['CMM']['database']['cmm_cmm_pages'],array('LID'=>$GLOBALS['LanguageUID'],'CustomerCustomergroupID'=>$GLOBALS['CustomergroupUID'],'filter'=>array(),'sort'=>'PagePID ASC, PageSort ASC'));
// Naviebenen aufbauen
$pluginContent = $mainNavi->createNaviTree($mainNaviPages,$params,$mainNavi->pageUID);
//echo $moduleContent;

unset($params);
?>