<?PHP
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////
// Modul fuer (Sub)Page-Index                            //
///////////////////////////////////////////////////////////
// V 1.0 First release
// V 1.0.1 marginale Anpassungen
// V 1.1.0 Parameterverarbeitung
// V 1.2.0 Umstellung auf CMM3
// V 1.2.1 Umzug con CMM_Contents nach CMM_Page[CMM]
// V 1.2.2 Erkennung metaMode -> keine Ausfuehrung
// V 1.2.3 Feld-Definitionen eingefuegt
// V 1.2.4 Feld fuer Titel-Laenge eingefuegt
// V 1.2.5 Pageindex 1,2,3 vereinigt
// V 1.2.6 ignoreNotInNavi hinzugefuegt
// V 1.2.7 Max-Seiten und Sortieung hinzugefuegt
// V 1.2.8 Navi-Objekt angepasst
// V 1.2.9 Mehrere Start-IDs möglich
// V 1.3.0 Neuer Typ 4 (nur Bild)
// V 1.4.0 mod. params select/radio options, added sort by FIELD()
///////////////////////////////////////////////////////////
include_once(CMM_ROOT_DIR.'CMM/classes/class.page.php');

/* PARAMS START - Marker-Comments required! */
$params = array(
	'templateFile' => 'CMM/template/html/CMM_CMM_Pageindex.html',
	'type' => 0,
	'startID' => '',
	'IDlist' => '',
	'ignoreNotInNavi' => 0,
	'titleLength' => 36,
	'descriptionLength' => 200,
	'imageWidth' => 50,
	'imageHeight' => 50,
	'target' => '',
	'sort' => 'PageSort ASC',
	'number' => '' // PageSort
	);
/* PARAMS END */

/* FIELDSET START - Marker-Comments required! */
$fieldset = array(
	'templateFile' => array('label'=>'HTML-Vorlagen-Datei','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'type' => array('label'=>'Anzeige-Typ','type'=>'radio','options'=>array(array('value'=>0,'text'=>'nur Titel'),array('value'=>1,'text'=>'Titel und Bild'),array('value'=>2,'text'=>'Titel und Beschreibung'),array('value'=>3,'text'=>'Titel, Beschreibung und Bild'),array('value'=>4,'text'=>'nur Bild')),'position'=>'top'),
	'startID' => array('label'=>'Start-Seite(n) (PID,PID,...)','type'=>'linkfield','position'=>'left'),
	'IDlist' => array('label'=>'Liste definierter Seiten (PID,PID,...) (dominant)','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'ignoreNotInNavi' => array('label'=>'Feld &quot;Seite nicht in Navi anzeigen&quot; ignorieren','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'left'),
	'titleLength' => array('label'=>'Titel: Max-Länge (Zeichen)','type'=>'textfield','datatype'=>'int','position'=>'right'),
	'descriptionLength' => array('label'=>'Beschreibung: Max-Länge (Zeichen)','type'=>'textfield','datatype'=>'int','position'=>'right'),
	'imageWidth' => array('label'=>'Bild: Breite (px)','type'=>'textfield','datatype'=>'int','position'=>'right'),
	'imageHeight' => array('label'=>'Bild: Höhe (px)','type'=>'textfield','datatype'=>'int','position'=>'right'),
	'target' => array('label'=>'Link: Zielfenster (Target)','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'sort' => array('label'=>'Sortierung','type'=>'select','options'=>array(array('value'=>'PageSort ASC','text'=>'Wie in Navigation'),array('value'=>'PageTitle_lbc ASC','text'=>'Nach Seitentitel'),array('value'=>'FIELD()','text'=>'Wie in Liste angegeben'),array('value'=>'RAND()','text'=>'Zufall')),'position'=>'left'),
	'number' => array('label'=>'Max. Anzahl der Seiten','type'=>'textfield','datatype'=>'int','position'=>'right')
	);
/* FIELDSET END */


// Get user-group
$params['CustomerCustomergroupID'] = isset($GLOBALS['CustomergroupUID']) ? $GLOBALS['CustomergroupUID'] : 0;
// Get language
$params['LID'] = isset($GLOBALS['LanguageUID']) ? $GLOBALS['LanguageUID'] : 1;

// Merge  plugin-params (default an explicitly set)
$params = CMM_mergePluginParams($params,$pluginParams);

// Create instance of navi-object
$pageIndex = new Navi;

// Get list of defined pages
if(!empty($params['IDlist']))
	{
	// Sort like id-list - MySQL-specific !
	if($params['sort'] == 'FIELD()')
		{ $params['sort'] = 'FIELD(PageUID, '.$params['IDlist'].')'; }

	// Prepare id-list
	$params['IDlist'] = str_replace(' ','',$params['IDlist']);
	$params['IDlist'] = str_replace(',','|',$params['IDlist']);

	// Set filter
	$resultFilter = array();
	$resultFilter['PageUID'] = $params['IDlist'];

	// Filter in navi?
	empty($params['ignoreNotInNavi']) ? $resultFilter['PageShowInNavi']=1 : '';

	// Get pages
	$pageIndexPages = DB_CMM_pageGetList($CONFIG['CMM']['database']['cmm_cmm_pages'],array('PID'=>'','LID'=>$GLOBALS['LanguageUID'],'CustomerCustomergroupID'=>$GLOBALS['CustomergroupUID'],'filter'=>$resultFilter,'sort'=>$params['sort']));
	}
// Get subpages of start-page(s)
else
	{
	// Remove sort like id-list - MySQL-specific !
	if($params['sort'] == 'FIELD()')
		{ $params['sort'] = ''; }

	// Start id
	empty($params['startID']) ? $params['startID'] = $pageIndex->pageUID : '';
	$resultFilter = array();
	empty($params['ignoreNotInNavi']) ? $resultFilter['PageShowInNavi']=1 : '';

	// One or more start-ids?
	if(stristr($params['startID'],','))
		{ $params['startID'] = explode(',',$params['startID']); }
	else
		{ $params['startID'] = array($params['startID']); }

	// Get pages for each start-id
	$pageIndexPages = array();
	foreach($params['startID'] as $startID)
		{
		$pagesTemp = DB_CMM_pageGetList($CONFIG['CMM']['database']['cmm_cmm_pages'],array('PID'=>$startID,'LID'=>$GLOBALS['LanguageUID'],'CustomerCustomergroupID'=>$GLOBALS['CustomergroupUID'],'filter'=>$resultFilter,'sort'=>$params['sort']));
		$pageIndexPages = array_merge($pageIndexPages,$pagesTemp);
		}
	}

// Limit number of pages
if(!empty($params['number']))
	{ $pageIndexPages = array_slice($pageIndexPages,0,$params['number']); }

// Create page-index
$pluginContent = $pageIndex->createPageindex($pageIndexPages,$params);

unset($params);
?>
