<?PHP
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////
// Plugin fuer Navigationen                              //
///////////////////////////////////////////////////////////
// V 1.0 First release basierend auf Navi-Plugin
// V 1.0.1 marginale Anpassungen
// V 1.1.0 Parameterverarbeitung
// V 1.2.0 Umstellung auf CMM3
// V 1.2.1 Umzug con CMM_Contents nach CMM_Page[CMM]
// V 1.2.2 um Parameter wrapText erweitert
// V 1.2.3 Erkennung metaMode -> keine Ausfuehrung
// V 1.2.4 Feld-Definitionen eingefuegt
// V 1.2.5 param ignoreNotInSitemap added
// V 1.2.6 param ignoreHideInSitemap added
///////////////////////////////////////////////////////////
include_once(CMM_ROOT_DIR.'CMM/classes/class.page.php');

/* PARAMS START - Marker-Comments required! */
$params = array(
	'startID' => 1, // Start page-id for output
	'startLevel' => 0, // Start level for output
	'range' => '', // Nuber of levels from start-level
	'ignoreNotInNavi' => 0, // Igrnore "not in navi"
	'ignoreHideInSitemap' => 0, // Igrnore "not in sitemap"
	// Eigenschaften fuer alle Ebenen
	'expAll' => 1, // alle Navigationspunkte der Ebene aktiviere/ausgeben
	'enableStatus' => 'nor,act,cur', // 'nor,act,cur,norifsub,actifsub,curifsub', // Erlaubte Navigationszustaende
	'target' => '', // Linkt-Target
	'crop' => '', // Ausgabe des Titels kuerzen
	'wrapAll' => '<div class="CMM_sitemap">*</div>', // Wrap um gesamte Navi
	'wrapLevel' => '<ul>*</ul>', // Wrap um Navigationsebene
	'wrapItemAndSub' => '<li class="###STATUS######FIRSTLAST###">*</li>', // Wrap um Navigationspunkt und Unterpunkte
	'wrapItem' => '*', // Wrap um Navigationspunkt
	'wrapLink' => '<a href="###LINK###" title="###TITLE###">*</a>', // Wrap Link
	'wrapText' => '*', // Wrap um Navigationstext

	// Eigenschaften fuer spezielle Ebenen (0-n)
//	'expAll0' => '',
//	'enableStatus0' => 'nor,act,cur',
//	'target0' => '',
//	'crop0' => '',
//	'wrapItem0' => '<div>*</div><span>###DESCRIPTION###</span>',
//	'wrapItemAndSub0' => '<li class="###STATUS######FIRSTLAST###">*</li>',
//	'wrapLevel0' => '<ul>*</ul>'
	);
/* PARAMS END */

/* FIELDSET START - Marker-Comments required! */
$fieldset = array(
	'startID' => array('label'=>'Start-Seite (PID)','type'=>'linkfield','position'=>'left'),
	'startLevel' => array('label'=>'Start-Ebene','type'=>'textfield','datatype'=>'int','position'=>'left'),
	'range' => array('label'=>'Anzahl der Ebenen ab startLevel','type'=>'textfield','datatype'=>'int','position'=>'left'),
	'ignoreNotInNavi' => array('label'=>'&quot;Seite nicht in Navi anzeigen&quot; ignorieren','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'left'),
	'ignoreHideInSitemap' => array('label'=>'&quot;Seite nicht in Sitemap anzeigen&quot; ignorieren','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'left'),
	'expAll' => array('label'=>'Alle Ebenen der Navigation anzeigen','type'=>'checkbox','options'=>array(array('value'=>'1','text'=>'{LANG_CMM_YES}')),'text'=>'ja','datatype'=>'text','position'=>'right'),
	'enableStatus' => array('label'=>'Navigations-Stati (nor,act,cur,norifsub,actifsub,curifsub)','type'=>'textfield','datatype'=>'text','position'=>'bottom'),
	'target' => array('label'=>'Link-Target','type'=>'textfield','datatype'=>'text','position'=>'right'),
	'crop' => array('label'=>'Ausgabe des Titels kuerzen (Zeichenanzahl)','type'=>'textfield','datatype'=>'int','position'=>'right'),
	'wrapAll' => array('label'=>'Wrap um gesamte Navigation','type'=>'textfield','datatype'=>'code','position'=>'bottom','shy'=>1),
	'wrapLevel' => array('label'=>'Wrap um Navigationsebene','type'=>'textfield','datatype'=>'code','position'=>'bottom','shy'=>1),
	'wrapItemAndSub' => array('label'=>'Wrap um Navigationspunkt mit Unterpunkten','type'=>'textfield','datatype'=>'code','position'=>'bottom','shy'=>1),
	'wrapItem' => array('label'=>'Wrap um Navigationspunkt','type'=>'textfield','datatype'=>'code','position'=>'bottom','shy'=>1),
	'wrapLink' => array('label'=>'Wrap um Navigationspunkt-Link','type'=>'textfield','datatype'=>'code','position'=>'bottom','shy'=>1),
	'wrapText' => array('label'=>'Wrap um Navigationspunkt-Text','type'=>'textfield','datatype'=>'code','position'=>'bottom','shy'=>1)
	);
/* FIELDSET END */


// Set customer group
$params['CustomerCustomergroupID'] = isset($GLOBALS['CustomergroupUID']) ? $GLOBALS['CustomergroupUID'] : 0;
// Set language
$params['LID'] = isset($GLOBALS['LanguageUID']) ? $GLOBALS['LanguageUID'] : 1;

// Merge params and pluginParams
$params = CMM_mergePluginParams($params,$pluginParams);

// Inhalt ausgeben
$sitemap = new Navi;

// alle aktiven und fuer Navi frei gegebenen Seiten einlesen
$resultFilter = array();
$resultFilter['PageTID'] = '0|1';
empty($params['ignoreNotInNavi']) ? $resultFilter['PageShowInNavi']=1 : '';
empty($params['ignoreHideInSitemap']) ? $resultFilter['PageHideInSitemap']=0 : '';
!empty($_SESSION['customer']['CustomergroupID']) ? $CoustomergroupID = $_SESSION['customer']['CustomergroupID'] : $CoustomergroupID='';
$sitemapPages = DB_CMM_pageGetList($CONFIG['CMM']['database']['cmm_cmm_pages'],array('LID'=>$GLOBALS['LanguageUID'],'CustomerCustomergroupID'=>$GLOBALS['CustomergroupUID'],'filter'=>$resultFilter,'sort'=>'PageSort ASC, PagePID ASC','debug'=>0));

// Naviebenen aufbauen
$sitemap->pageUID = $params['startID'];
$pluginContent = $sitemap->createNaviTree($sitemapPages,$params,$sitemap->pageUID);

unset($params);
?>