<?PHP
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////
// Plugin zur Verkettung von CSS-Dateien                 //
///////////////////////////////////////////////////////////
// V 1.0 First release
// V 1.0.1 Parameter base hinzugefuegt
// V 1.0.2 Variablen-Ersatz in Parametern eingefuegt
// V 1.0.3 BUGFIX: Entfernen leerer CSS-Klassen korrigiert
// V 1.0.4 QUALITY-FIX
// V 1.0.5 generierter Dateinamen mit Parameter zur Reduzierung der Cache-Dateien
// V 1.0.6 Added param and logic for return
// V 1.0.7 External class scssphp included
// V 1.0.8 Replaced eval with CMM_replaceParamsVars()
///////////////////////////////////////////////////////////

/* PARAMS START - Marker-Comments required! */
$params = array(
	'timestamp' => 1, // Zeitstempel
	'concat' => 0, // Verketten
	'minify' => 0, // Komprimieren
	'return' => 'tag', // return only filename
	'base' => '{CMM_ROOT_DIR}' // Basis-URL des relativen Pfades
	// CSS-Dateien werden als <link rel="stylesheet">-Tag zeilenweise uebergeben
	);
/* PARAMS END */

/* FIELDSET START - Marker-Comments required! */
$fieldset = array(
	'timestamp' => array('label'=>'Zeitstempel setzen','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'left'),
	'concat' => array('label'=>'Dateien verketten','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'left'),
	'minify' => array('label'=>'Dateien komprimieren (nur bei Verkettung möglich)','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'right'),
	'return' => array('label'=>'Ausgabe der optimierten Datei','type'=>'radio','options'=>array(array('value'=>'tag','text'=>'&lt;link&gt;-Tag'),array('value'=>'url','text'=>'URL')),'position'=>'right'),
	'base' => array('label'=>'Basis-URL des relativen Pfades','type'=>'textfield','datatype'=>'text','position'=>'bottom')
	);
/* FIELDSET END */


// Set customer group
$params['CustomerCustomergroupID'] = isset($GLOBALS['CustomergroupUID']) ? $GLOBALS['CustomergroupUID'] : 0;
// Set language
$params['LID'] = isset($GLOBALS['LanguageUID']) ? $GLOBALS['LanguageUID'] : 1;

// Merge params and pluginParams
$params = CMM_mergePluginParams($params,$pluginParams);

// Replace params placeholders with real vars
$params = CMM_replaceParamsVars($params);


///////////////////////////////////////////////////////////////////


// Verarbeitung des kopletten Plugin-Params-String
$pluginParamsString = explode("\n",str_replace("\r",'',$pluginParamsString));

// Analyze CSS-file links
$cssFiles = array();
$cssLatestTimestamp = 0;
$cssTempFilename = array();
foreach($pluginParamsString as $pluginParamsStringItem)
	{
	// nur CSS-Links verarbeiten, keine normalen Parameter
	if(stristr($pluginParamsStringItem,'<link'))
		{
		// CSS-Datei-Pfade sammeln
		preg_match('|href=\"(.*)\"|siU',$pluginParamsStringItem,$matchItem);
		$cssFile = trim($matchItem[1]);

		// If is external file
		if(strstr($cssFile,'://') || substr($cssFile,0,2)=='//')
			{
			// Add file to array
			$cssFiles[] = array('path'=>$cssFile, 'timestamp'=>0, 'type'=>'external');
			}
		// Esle is internal file
		else if(file_exists($params['base'].$cssFile))
			{
			// Detect if SCSS-proccessing is required
			stristr($cssFile,'.scss') ? $scssRequired=true : '';

			// Get timestamp
			$cssFileTimestamp = filemtime($params['base'].$cssFile);
			$cssLatestTimestamp < $cssFileTimestamp ? $cssLatestTimestamp=$cssFileTimestamp : '';

			// Temp-Filename
			$cssTempFilename[] = basename($cssFile);

			// Add file to array
			$cssFiles[] = array('path'=>$cssFile, 'timestamp'=>$cssFileTimestamp, 'type'=>'internal');
			}
		}
	}


///////////////////////////////////////////////////////////////////


// Ausgabe
$pluginContent = '';
$scssClassPath = CMM_ROOT_DIR.'CMM/scssphp/scss.inc.php';
$scssClassIncluded = false;

if(sizeof($cssFiles)>0)
	{
	// Temporaeren Dateinamen konstruieren (Namen der 3 ersten Dateien + etc)
	$cssTempFilename = 'CMM3_'.md5(implode('-',$cssTempFilename));

	// Ausgabe mit Verkettung
	if(!empty($params['concat']))
		{
		// Temporaere CSS-Datei fehlt oder ist veraltet - neu erstellen
		if(!file_exists($params['base'].$CONFIG['CMM']['config']['dirs']['tempPath'].$cssTempFilename.'.css') || filemtime($params['base'].$CONFIG['CMM']['config']['dirs']['tempPath'].$cssTempFilename.'.css') < $cssLatestTimestamp)
			{
			// Datei-Inhalt einlesen und temporaere Datei erzeugen
			$cssFileContents = '';
			foreach($cssFiles as $cssFilesKey => $cssFilesItem)
				{
				// Skip external files
				if($cssFilesItem['type']!='internal')
					{ continue; }

				// Get file-contents
				$cssFileContent = file_get_contents($params['base'].$cssFilesItem['path']).PHP_EOL;

				// Detect scss
				if(stristr($cssFilesItem['path'],'.scss'))
					{
					// Include scss-class
					if($scssClassIncluded == false)
						{
						include_once($scssClassPath);
						$scssClassIncluded = true;
						}
					// Proccess scss-file
					$scss = new scssc();
					$cssFileContent = $scss->compile($cssFileContent);
					}
				// Rewrite ralative paths in file-content
				$cssFileContent = CMM_changeCssPaths($cssFileContent,dirname($params['base'].$cssFilesItem['path']).'/',$params['base'].$CONFIG['CMM']['config']['dirs']['tempPath']);
				// Append file-content to global string
				$cssFileContents.= $cssFileContent;
				}
	
			if(!empty($params['minify']))
				{
				// Remove comments - keep them in some cases
				$cssFileContents = preg_replace('@>/\\*\\s*\\*/@', '>/*keep*/', $cssFileContents);
				$cssFileContents = preg_replace('@/\\*\\s*\\*/\\s*:@', '/*keep*/:', $cssFileContents);
				$cssFileContents = preg_replace('@:\\s*/\\*\\s*\\*/@', ':/*keep*/', $cssFileContents);
				$cssFileContents = preg_replace('@/\*.+?\*/@si', '', $cssFileContents);
				// Remove white spaces on :;{}
				$cssFileContents = preg_replace('@\\s*{\\s*@', '{', $cssFileContents);
				$cssFileContents = preg_replace('@\\s*}@', '}', $cssFileContents);
				$cssFileContents = preg_replace('@\\s*url\(@', ' url(', $cssFileContents);
				$cssFileContents = preg_replace('@\\s*;\\s*@', ';', $cssFileContents);
				$cssFileContents = preg_replace('@\\s*:\\s*@', ':', $cssFileContents);
				$cssFileContents = preg_replace('@  +@', ' ', $cssFileContents);
				// Conclude ,-separated identifiers in one line
				$cssFileContents = preg_replace("/,[\s\t]*[\n\r]+/m", ', ', $cssFileContents);
				// Remove empty classes
				$cssFileContents = preg_replace('@[#\w\s\.\,\>\*\-\[\]\=\^\~\:]+\{[\s\n\r\t]*\}@', '', $cssFileContents);
				// replace any white space including newlines with a single newline
				$cssFileContents = preg_replace('/(^[\r\n]*|[\r\n]+)[\s\t]*[\r\n]+/', "\r\n", $cssFileContents);
				$cssFileContents = str_replace('}}',"}\r\n}", $cssFileContents);
				$cssFileContents = trim($cssFileContents);
				}
				
			file_put_contents($params['base'].$CONFIG['CMM']['config']['dirs']['tempPath'].$cssTempFilename.'.css',$cssFileContents);
			}

		// Output external files
		foreach($cssFiles as $cssFilesKey => $cssFilesItem)
			{
			// Skip external files
			if($cssFilesItem['type'] != 'external')
				{ continue; }
			if($params['return']=='tag')
				{ $pluginContent.= '<link href="'.$cssFilesItem['path'].'" rel="stylesheet" type="text/css">'.PHP_EOL; }
			else
				{ $pluginContent.= $cssFilesItem['path']; }
			}
		// Output joined internal files
		if($params['return']=='tag')
			{ $pluginContent.= '<link href="'.$CONFIG['CMM']['config']['dirs']['tempPath'].$cssTempFilename.'.css'.(!empty($params['timestamp']) ? '?'.filemtime($params['base'].$CONFIG['CMM']['config']['dirs']['tempPath'].$cssTempFilename.'.css') : '').'" rel="stylesheet" type="text/css">'.PHP_EOL; }
		else
			{ $pluginContent.= $CONFIG['CMM']['config']['dirs']['tempPath'].$cssTempFilename.'.css?'.filemtime($params['base'].$CONFIG['CMM']['config']['dirs']['tempPath'].$cssTempFilename.'.css'); }
		}
	
	// Ausgabe normal - ohne Verkettung
	else
		{
		foreach($cssFiles as $cssFilesItem)
			{
			if($params['return']=='tag')
				{ $pluginContent.= '<link href="'.$cssFilesItem['path'].(!empty($params['timestamp']) ? '?'.$cssFilesItem['timestamp'] : '').'" rel="stylesheet" type="text/css">'.PHP_EOL; }
			else
				{ $pluginContent.= $cssFilesItem['path'].(!empty($params['timestamp']) ? '?'.$cssFilesItem['timestamp'] : ''); }
			}
		}
	}

unset($params);
?>