<?PHP
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////
// Plugin zur Verkettung von JS-Dateien                 //
///////////////////////////////////////////////////////////
// V 1.0 First release
// V 1.0.1 Parameter base hinzugefuegt
// V 1.0.2 Variablen-Ersatz in Parametern eingefuegt
// V 1.0.3 Verkettung optimiert
// V 1.0.4 Added param and logic for return
// V 1.0.5 Replaced eval with CMM_replaceParamsVars()
///////////////////////////////////////////////////////////

/* PARAMS START - Marker-Comments required! */
$params = array(
	'timestamp' => 1, // Zeitstempel
	'concat' => 0, // Verketten
//	'minify' => 0, // Komprimieren
	'return' => 'tag', // return only filename
	'base' => '{CMM_ROOT_DIR}' // Basis-URL des relativen Pfades
	// JS-Dateien werden als <script type="text/javascript">-Tag zeilenweise uebergeben
	);
/* PARAMS END */

/* FIELDSET START - Marker-Comments required! */
$fieldset = array(
	'timestamp' => array('label'=>'Zeitstempel setzen','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'left'),
	'concat' => array('label'=>'Dateien verketten','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'left'),
//	'minify' => array('label'=>'Dateien komprimieren (nur bei Verkettung möglich)','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'right'),
	'return' => array('label'=>'Ausgabe der optimierten Datei','type'=>'radio','options'=>array(array('value'=>'tag','text'=>'&lt;link&gt;-Tag'),array('value'=>'url','text'=>'URL')),'position'=>'right'),
	'base' => array('label'=>'Basis-URL des relativen Pfades','type'=>'textfield','datatype'=>'text','position'=>'bottom')
	);
/* FIELDSET END */


// Set customer group
$params['CustomerCustomergroupID'] = isset($GLOBALS['CustomergroupUID']) ? $GLOBALS['CustomergroupUID'] : 0;
// Set language
$params['LID'] = isset($GLOBALS['LanguageUID']) ? $GLOBALS['LanguageUID'] : 1;

// Merge params and pluginParams
$params = CMM_mergePluginParams($params,$pluginParams);

// Replace params placeholders with real vars
$params = CMM_replaceParamsVars($params);


///////////////////////////////////////////////////////////////////


// Verarbeitung des kopletten Plugin-Params-String
$pluginParamsString = explode("\n",str_replace("\r",'',$pluginParamsString));

// JS-Dateien separieren
$jsFiles = array();
$jsLatestTimestamp = 0;
$jsTempFilename = array();
foreach($pluginParamsString as $pluginParamsStringItem)
	{
	// nur JS-Links verarbeiten, keine normalen Parameter
	if(stristr($pluginParamsStringItem,'<script'))
		{
		// JS-Datei-Pfade sammeln
		preg_match('|src=\"(.*)\"|siU',$pluginParamsStringItem,$matchItem);
		$jsFile = trim($matchItem[1]);

		// If is external file
		if(strstr($jsFile,'://') || substr($jsFile,0,2)=='//')
			{
			// Add file to array
			$jsFiles[] = array('path'=>$jsFile, 'timestamp'=>0, 'type'=>'external');
			}
		// Esle is internal file
		else if(file_exists($params['base'].$jsFile))
			{
			// Timestamp ermitteln
			$jsFileTimestamp = filemtime($params['base'].$jsFile);
			$jsLatestTimestamp < $jsFileTimestamp ? $jsLatestTimestamp=$jsFileTimestamp : '';

			// Temp-Filename
			$jsTempFilename[] = basename($jsFile,'.js');
			// Datei in Array aufnehmen
			$jsFiles[] = array('path'=>$jsFile, 'timestamp'=>$jsFileTimestamp ,'type'=>'internal');
			}
		}
	}


///////////////////////////////////////////////////////////////////


// Ausgabe
$pluginContent = '';

if(sizeof($jsFiles)>0)
	{
	// Temporaeren Dateinamen konstruieren (Namen der 3 ersten Dateien + etc)
	$jsTempFilename = 'CMM3_'.md5(implode('-',$jsTempFilename));

	// Ausgabe mit Verkettung
	if(!empty($params['concat']))
		{
		// Temporaere JS-Datei fehlt oder ist veraltet - neu erstellen
		if(!file_exists($params['base'].$CONFIG['CMM']['config']['dirs']['tempPath'].$jsTempFilename.'.js') || filemtime($params['base'].$CONFIG['CMM']['config']['dirs']['tempPath'].$jsTempFilename.'.js') < $jsLatestTimestamp)
			{
			// Datei-Inhalt einlesen und temporaere Datei erzeugen
			$jsFileContents = '';
			foreach($jsFiles as $jsFilesKey => $jsFilesItem)
				{
				// Skip external files
				if($jsFilesItem['type']!='internal')
					{ continue; }

				// Get file-contents
				$jsFileContent = trim(file_get_contents($params['base'].$jsFilesItem['path']));
				// Append trailing ";" if missing
				if(substr($jsFileContent,-1) != ';')
					{ $jsFileContent.= ';'; }
				// Append file-content to global string
				$jsFileContents.= $jsFileContent.PHP_EOL;
				}
	
			if(!empty($params['minify']))
				{
				// Remove comments - keep them in some cases
//				$jsFileContents = preg_replace('@/\*.+?\*/@si', '', $jsFileContents);
//				$jsFileContents = preg_replace('@//.*?\n@', "\n", $jsFileContents);
				// Remove multiple spaces
//				$jsFileContents = preg_replace('/(\s)+/s',' ',$jsFileContents);
				// replace any white space including newlines with a single newline
				$jsFileContents = preg_replace('/(^[\r\n]*|[\r\n]+)[\s\t]*[\r\n]+/', "\r\n", $jsFileContents);
				// Remove Single-line JS-Comments
		//		$jsFileContents = preg_replace('|[ \t]*//.*[ \t]*[\r\n]|', '', $jsFileContents);
				// Remove Multi-line JS-comments
				if(stristr($jsFileContents,'/*'))
					{ $jsFileContents = preg_replace('/(\/\*.*\*\/)/sU','', $jsFileContents); }
				}
				
			file_put_contents($params['base'].$CONFIG['CMM']['config']['dirs']['tempPath'].$jsTempFilename.'.js',$jsFileContents);
			}

		// Output external files
		foreach($jsFiles as $jsFilesKey => $jsFilesItem)
			{
			// Skip external files
			if($jsFilesItem['type'] != 'external')
				{ continue; }
			if($params['return']=='tag')
				{ $pluginContent.= '<script type="text/javascript" src="'.$jsFilesItem['path'].'"></script>'.PHP_EOL; }
			else
				{ $pluginContent.= $jsFilesItem['path']; }
			}

		// Output joined internal files
		if($params['return']=='tag')
			{ $pluginContent.= '<script type="text/javascript" src="'.$CONFIG['CMM']['config']['dirs']['tempPath'].$jsTempFilename.'.js'.(!empty($params['timestamp']) ? '?'.filemtime($params['base'].$CONFIG['CMM']['config']['dirs']['tempPath'].$jsTempFilename.'.js') : '').'"></script>'.PHP_EOL; }
		else
			{ $pluginContent.= $CONFIG['CMM']['config']['dirs']['tempPath'].$jsTempFilename.'.js'.(!empty($params['timestamp']) ? '?'.filemtime($params['base'].$CONFIG['CMM']['config']['dirs']['tempPath'].$jsTempFilename.'.js') : ''); }
		}
	
	// Ausgabe normal - ohne Verkettung
	else
		{
		foreach($jsFiles as $jsFilesItem)
			{
			if($params['return']=='tag')
				{ $pluginContent.= '<script type="text/javascript" src="'.$jsFilesItem['path'].(!empty($params['timestamp']) ? '?'.$jsFilesItem['timestamp'] : '').'"></script>'.PHP_EOL; }
			else
				{ $pluginContent.= $jsFilesItem['path'].(!empty($params['timestamp']) ? '?'.$jsFilesItem['timestamp'] : ''); }
			}
		}
	}

unset($params);
?>