/*************************************************************
* jQuery cmm3menu plugin V 1.1.1
* This is a jQuery-based navi-sidebar-script with two modes
* normal/regular (switch by css-defined window-width)
* and an option to make the regular navi sticky (at top of window).
* Copyright (c) 2017 Nicolas Berg GRAFIX21
* http://www.grafix21.de
*
* Licensed under the GNU General Public License: 
* http://www.gnu.org/licenses/gpl.html
**************************************************************/

(function($) {
    $.fn.cmm3menu = function (options) {

		// Combine default options with current options
		var opts = $.extend( {}, $.fn.cmm3menu.defaults, options );
		var sidebarContainer;

		// Define object for regular menu
		regularMenu = $(this);


		////////////////////////////////////////


		function sidebarInit()
			{
			//////// REGULAR-NAVI ////////

			// Add indicator/toggle icons
			$('a',regularMenu).each(function() {
				if($(this).closest('li').children('ul').length)
					{ $(this).closest('li').prepend('<i class="subtoggle"></div>'); }
				});
			// Open submenus by hover
			if(opts.regularHoverEnable == true)
				{ toggleRegularSubmenu(regularMenu); }
			// Add class to regular menu
			regularMenu.addClass(opts.classRegular);

			// Check, if easing-plugin is loaded
			if(opts.sidebarEasing!='' && !jQuery.easing["jswing"])
				{
				console.log('Please install the jquery-easing-plugin for more organic animations on cmm3menu!');
				opts.sidebarEasing = '';
				}

			//////// SIDEBAR-CONTAINER ////////

			// Create wrapper for nav-sidebar
			sidebarContainer = $('<div class="'+opts.classSidebar+' '+(opts.sidebarPosition=='right' ? 'menuSidebarRight' : 'menuSidebarLeft')+'" id="menuSidebar" />');
			sidebarContainerInner = $('<div class="menuSidebarInner" />');
			sidebarContainer.append(sidebarContainerInner);

			// console.log(sidebarContainer);
			$('BODY').prepend(sidebarContainer);

			//////// SIDEBAR-OVERLAY ////////

			if(opts.sidebarOverlay == true)
				{
				sidebarOverlay = $('<div class="'+opts.classSidebarOverlay+'" />');
				$('BODY').prepend(sidebarOverlay);
				}

			// Add toggle function to overlay
			sidebarOverlay.on('click', function() {
				toggleSidebar();
				});

			//////// SIDEBAR-TOGGLE ////////

			// Insert toggle or use defined element as toggle
			if(opts.sidebarToggle!=='')
				{
				sidebarToggle = $(opts.sidebarToggle);
				}
			else
				{
				sidebarToggle = $('<div class="'+opts.classToggle+'" title="'+opts.sidebarToggleText+'"><span>'+opts.sidebarToggleText+'</span></div>');
				sidebarContainer.append(sidebarToggle);
				}
			// Add toggle function to navi-button outside of the sidebar
			sidebarToggle.on('click', function(evt) {
				evt.preventDefault();
				toggleSidebar();
				});

			//////// SIDEBAR-CLOSE ////////

			// Prepend close button to nav-sidebar
			sidebarContainerClose = $('<div class="'+opts.classClose+'" title="'+opts.sidebarToggleText+'"></div>');
			sidebarContainer.append(sidebarContainerClose);

			// Add toggle function to close-button in sidebar
			sidebarContainerClose.on('click', function() {
				toggleSidebar();
				});

			//////// SIDEBAR-CONTENTS ////////

			// Insert contents
			if(opts.sidebarContents!=='')
				{
				// Split contents to obtain defined elements order
				opts.sidebarContents = opts.sidebarContents.split(',');
				// clone elements to nav-sidebar
				$(opts.sidebarContents).each(function(index,element) {
					// console.log(index,$(element));
					sidebarContainerInner.append($(element).clone().off().removeAttr('id').removeAttr('class').addClass(opts.classSidebar+'_section'+index))
					});
				}

			// Add toggle function to toggle/indicator items in sidebar
			$('.subtoggle',sidebarContainer).each(function() {
				$(this).on('click',function(evt) {
				    evt.preventDefault();
					toggleSidebarSubmenu($(this));
					});
				});

			// Add close function to link-tags
			$('A',sidebarContainer).each(function() {
				$(this).on('click',function(evt) {
					toggleSidebar();
					});
				});

			// Callback on init
			if(typeof opts.onInit == 'function')
				{ opts.onInit.call(sidebarContainer,opts); }
			}

		
		////////////////////////////////////////


		// Open submenu by hover
		function toggleRegularSubmenu(regularMenu)
			{
			// Open/close submenu and add/remove hover class to LI
			$('li',regularMenu).on('mouseenter',function() {
				currentLI = $(this);
				$(currentLI).stop(true,true).addClass('hov');
				$('> ul',currentLI).stop(true,true).delay(opts.regularTimeout).slideDown(opts.regularSpeed);
				});

			$('li',regularMenu).on('mouseleave',function() {
				currentLI = $(this);
				$('> ul',currentLI).stop(true,true).delay(opts.regularTimeout).fadeOut(opts.regularSpeed);
				$(currentLI).stop(true,true).removeClass('hov');
				});
	
			}


		////////////////////////////////////////


		// Toggle whole sidebar
		function toggleSidebar()
			{
			// Toggle act-class on toggle
			sidebarToggle.toggleClass(opts.classToggleAct);

			// right sidebar
			if(opts.sidebarPosition=='right')
				{
				// close
				if(sidebarContainer.css('right')=='0px')
					{
					// Body slide
					if(opts.bodySlide == 1)
						{
						$('body').animate({'right':'0px'},opts.sidebarToggleSpeed,opts.sidebarEasing,function() {
							$('body').css({'position':'','width':''});
							$('html').css({'overflow-x':''});
							});
						}
					// Overlay
					if(opts.sidebarOverlay == true)
						{ sidebarOverlay.fadeOut(opts.sidebarToggleSpeed); }
					// Sidebar container
					sidebarContainer.removeClass('menuSidebarOpen');
					sidebarContainer.animate({'right':'-'+sidebarContainer.outerWidth()+'px'},opts.sidebarToggleSpeed,opts.sidebarEasing);
					}
				// open
				else
					{
					if(opts.bodySlide == 1)
						{
						$('html').css({'overflow-x':'hidden'});
						$('body').css({'position':'absolute','width':'100%'}).animate({'right':sidebarContainer.outerWidth()+'px'},opts.sidebarToggleSpeed,opts.sidebarEasing);
						}
					// Overlay
					if(opts.sidebarOverlay == true)
						{ sidebarOverlay.fadeIn(opts.sidebarToggleSpeed); }
					// Sidebar container
					sidebarContainer.animate({'right':'0px'},opts.sidebarToggleSpeed,opts.sidebarEasing);
					sidebarContainer.addClass('menuSidebarOpen');
					}
				}
			// left sidebar - default
			else
				{
				// close
				if(sidebarContainer.css('left')=='0px')
					{
					// Body slide
					if(opts.bodySlide == 1)
						{
						$('body').animate({'left':'0px'},opts.sidebarToggleSpeed,opts.sidebarEasing,function() {
							$('body').css({'position':'','width':''});
							$('html').css({'overflow-x':''});
							});
						}
					// Overlay
					if(opts.sidebarOverlay == true)
						{ sidebarOverlay.fadeOut(opts.sidebarToggleSpeed); }
					// Sidebar container
					sidebarContainer.removeClass('menuSidebarOpen');
					sidebarContainer.animate({'left':'-'+sidebarContainer.outerWidth()+'px'},opts.sidebarToggleSpeed,opts.sidebarEasing);
					}
				// open
				else
					{
					// Body slide
					if(opts.bodySlide == 1)
						{
						$('html').css({'overflow-x':'hidden'});
						$('body').css({'position':'absolute','width':'100%'}).animate({'left':sidebarContainer.outerWidth()+'px'},opts.sidebarToggleSpeed,opts.sidebarEasing);
						}
					// Overlay
					if(opts.sidebarOverlay == true)
						{ sidebarOverlay.fadeIn(opts.sidebarToggleSpeed); }
					// Sidebar container
					sidebarContainer.animate({'left':'0px'},opts.sidebarToggleSpeed,opts.sidebarEasing);
					sidebarContainer.addClass('menuSidebarOpen');
					}
				}
			}


		////////////////////////////////////////


		// Open submenu in sidebar by click
		function toggleSidebarSubmenu(subtoggle)
			{
			//console.log('CLICK');
			// select the subsidebar
			childUL = subtoggle.closest('li').children('ul');
			childULs = subtoggle.closest('ul').children('li').children('ul');

			// Open subsidebar
			if(childUL.is(':hidden'))
				{
				// Close other (all) submenus on same level (accordion behavior)
				childULs.each(function() {
					if(!$(this).is(':hidden'))
						{
						$(this).slideUp(opts.sidebarSpeed);
						$(this).closest('li').find('.subtoggle').eq(0).removeClass('open');
						}
					});
				// Open only the selected subsidebar
				childUL.slideDown(opts.sidebarSpeed);
				subtoggle.addClass('open');
				}
			// Close subsidebar
			else
				{
				childUL.slideUp(opts.sidebarSpeed);
				subtoggle.removeClass('open');
				}
			}


		////////////////////////////////////////


		// Render sidebar, if not empty
		if(this.html() != null)
			{ sidebarInit(); }

		}


	////////////////////////////////////////

	// Plugin defaults
	$.fn.cmm3menu.defaults = {
		// These are the defaults
		sidebarToggleText: 'Menu', // Text in the toggle-bar of the mobile version
		sidebarPosition: 'left', // Position of the nav-sidebar (left/right)
		sidebarOverlay: true, // Create overlay behind sidebar
		sidebarToggleSpeed: 500, // Speed to open/close whole sidebar
		sidebarSpeed: 250, // Speed to open/close subsidebar
		sidebarEasing: 'easeOutQuart', // Animation-Easing (requires the jquery-easing-plugin)

		bodySlide: 1, // Slide website-body with sidebar

		regularHoverEnable: true, // Enable slideDown on hover in regular menu
		regularSpeed: 250, // Speed to open submenu in regular menu
		regularTimeout: 250, // Timeout for mouseleave submenu in regular menu

		sidebarContents: '', // List of Selectors of the sidebar contents (#menu, #searchBox, ...)
		sidebarToggle: '', // Custom menu-toggle / if empty, toggle will be generated
	
		onInit: '', // Callback-function to perform when menu is initialized

		classRegular: 'menuRegular', // class for regular menu
		classSidebar: 'menuSidebar', // class for sidebar menu
		classSidebarOverlay: 'menuSidebarOverlay', // class for sidebar overlay
		classToggle: 'menuSidebarToggle', // class for sidebar toggle icon
		classToggleAct: 'act', // Class added to toggle for active state
		classClose: 'menuSidebarClose', // class for sidebar close icon
		};

}(jQuery));
