/*************************************************************
* jQuery cmm3parallax plugin V 1.0.0
* This is a simple jQuery-based parallax-background-script.
* Copyright (c) 2016 Nicolas Berg GRAFIX21
* http://www.grafix21.de
*
* Licensed under the GNU General Public License: 
* http://www.gnu.org/licenses/gpl.html
**************************************************************/

(function($)
	{
	$.fn.cmm3parallax = function(options)
		{
		return this.each(function(i)
			{
			var parallax = this;
			parallax.parallax = $(this);
			parallax.index = i;

			// Combine default options with current options
			parallax.o = $.extend( {}, cmm3parallax.defaults, options );

			// Init accordions
			cmm3parallax.init(parallax,i);
			});
		};
	
	////////////////////////////////////////

	cmm3parallax = {

		// Init - set defaults
		init: function(parallax,i)
			{
			parallax.window = $(window);
			// Get window height
			var windowHeight = $(window).height();
			// Update window height onchange
			parallax.window.bind('resize',function() {
				windowHeight = $(window).height();
				});

			// Get the initial top offset of panel	
			parallax.panelOffsetTop = parallax.parallax.offset().top;
			// Get the initial height of panel
			parallax.panelHeight = cmm3parallax.getHeight(parallax);

			// Update background-position first time
			cmm3parallax.update(parallax);
			// Update background-position on scroll
			parallax.window.bind('scroll resize',function() {
				cmm3parallax.update(parallax);
				});

			// Add CSS-class
			if(!parallax.parallax.hasClass(parallax.o.classContainer))
				{ parallax.parallax.addClass(parallax.o.classContainer); }

			// Callback on init
			if(typeof parallax.o.onInit == 'function')
				{ parallax.o.onInit.call(parallax); }
			},

		////////////////////////////////////////

		// Get the panel height
		getHeight: function(parallax)
			{
			if(parallax.o.useOuterHeight)
				{ return parallax.parallax.outerHeight(true); }
			else
				{ return parallax.parallax.height() + parallax.parallax.css('padding-top') + parallax.parallax.css('padding-bottom'); }
			},

		////////////////////////////////////////

		// Update the background position on scoll
		update: function(parallax)
			{
			// Get current scroll pos
			parallax.windowScrollTop = parallax.window.scrollTop();				
			// Get current panel offset
			parallax.panelOffsetTop = parallax.parallax.offset().top;

			// Check if totally above or totally below viewport
			if(parallax.panelOffsetTop + parallax.panelHeight < parallax.windowScrollTop || parallax.panelOffsetTop > parallax.windowScrollTop + parallax.windowHeight)
				{ return; }

			// Move background position
			parallax.parallax.css('backgroundPosition', parallax.o.backgroundPosX + " " + Math.round((parallax.panelOffsetTop - parallax.windowScrollTop) * parallax.o.speedFactor) + "px");
			},	

		////////////////////////////////////////

		// Set plugin defaults
		defaults: {
			backgroundPosX: 'center', // horizontal position ab background
			speedFactor: 0.5, // Move-speed-fatctor (0-1)
			useOuterHeight: true, // Use outerHeight or height property? (bool)
	
			onInit: '', // Callback-function to perform when tabs are initialized
		
			classContainer: 'backgroundParallax' // Class for container - will only be set, if not present
			}

		}

	}(jQuery));
