/*************************************************************
* jQuery cmm3showhide plugin V 1.0.0
* This is a simple jQuery-based toggle-box-script.
* Copyright (c) 2016 Nicolas Berg GRAFIX21
* http://www.grafix21.de
*
* Licensed under the GNU General Public License: 
* http://www.gnu.org/licenses/gpl.html
**************************************************************/

(function($)
	{
    $.fn.cmm3showhide = function(options)
		{
		return this.each(function(i)
			{
			var showhide = this;
			showhide.container = $(this);
			showhide.index = i;

			// Combine default options with current options
			showhide.o = $.extend( {}, cmm3showhide.defaults, options );

			// Init vars
			showhide.toggle;
			showhide.panel;
			showhide.status;
			showhide.blocked = false;

			// Init showhide
			cmm3showhide.init(showhide,i);
			});
		};
	
	////////////////////////////////////////

	cmm3showhide = {

		// Init
		init: function(showhide,i)
			{
			// Check, if easing-plugin is loaded
			if(showhide.o.toggleEasing!='' && !jQuery.easing["jswing"])
				{
				console.log('Please install the jquery-easing-plugin for more organic animations on cmm3showhide!');
				showhide.o.toggleEasing = '';
				}

			// Check, if cookie-plugin is loaded
			if(showhide.o.useCookie==true && !$.cookie)
				{
				console.log('Please install the jquery-cookie-plugin to use cookies with cmm3showhide!');
				showhide.o.toggleEasing = '';
				}

			// Set container-class
			if(showhide.o.classContainer!='' && !showhide.container.hasClass(showhide.o.classContainer))
				{ showhide.container.addClass(showhide.o.classContainer); }

			// Get toggle
			showhide.toggle = $(showhide.o.selectorToggle,showhide);
			// Set class to toggle
			if(showhide.o.classToggle!='')
				{ showhide.toggle.addClass(showhide.o.classToggle); }

			// Get panel
			showhide.panel = $();
			if(showhide.o.selectorPanel.indexOf('next()') > -1)
				{ showhide.panel = showhide.toggle.next(); }
			else
				{ showhide.panel = $(showhide.o.selectorPanel,showhide); }
			// Set class to panel
			if(showhide.o.classPanel!='')
				{ showhide.panel.addClass(showhide.o.classPanel); }

			// Set panel status
			showhide.status = false;
			// Set panel status true, if option alwasOpen == true
			if(showhide.o.defaultOpen == true)
				{ showhide.status = true; }
			// Set panel status by cookie
			if(showhide.o.useCookie == true && showhide.o.cookieName != '' && $.cookie)
				{
				// Check cookie
				if($.cookie(showhide.o.cookieName) == 'true')
					{ showhide.status = true; }
				else
					{ showhide.status = false; }
				}

			// Open toggle and panel if status is true
			if(showhide.status == true)
				{
				showhide.toggle.addClass(showhide.o.classSelected);
				showhide.panel.addClass(showhide.o.classSelected).css({display:'block'});
				}

			// Set click event
			$(showhide.toggle).on('click',function(evt) {
				evt.preventDefault();
				// Call click function
				cmm3showhide.togglePanel(showhide);
				});

			// Callback on init
			if(typeof showhide.o.onInit == 'function')
				{ showhide.o.onInit.call(showhide,showhide.defaultIndex); }
			},

		////////////////////////////////////////

		// Toggle the panel
		togglePanel: function(showhide,index)
			{
			if(showhide.blocked==false)
				{
				// showhide while change is in progress
				showhide.blocked = true;

				// Close
				if(showhide.toggle.hasClass(showhide.o.classSelected))
					{
					// Update cookie
					if(showhide.o.useCookie == true && showhide.o.cookieName != '' && $.cookie)
						{ $.cookie(showhide.o.cookieName,false, {path:'/'}); }

					// Close current panel
					cmm3showhide.closePanel(showhide);
					}
				// Open
				else
					{
					// Update cookie
					if(showhide.o.useCookie == true && showhide.o.cookieName != '' && $.cookie)
						{ $.cookie(showhide.o.cookieName,true, {path:'/'}); }

					// Open current panel
					cmm3showhide.openPanel(showhide);
					}

				// Unblock after change is complete
				window.setTimeout(function() {
					showhide.blocked = false;
					}, showhide.o.toggleSpeed + 10);
				}
			},

		////////////////////////////////////////

		// Show the panel
		openPanel: function(showhide,index)
			{
			// Open toggle
			showhide.toggle.addClass(showhide.o.classSelected);

			// Callback at start
			if(typeof showhide.o.onOpenStart == 'function')
				{ showhide.o.onOpenStart.call(showhide,index); }

			// Open panel
			showhide.panel.slideDown(showhide.o.toggleSpeed,showhide.o.toggleEasing,function() {
				// Add class
				showhide.panel.addClass(showhide.o.classSelected);
				// Callback at complete
				if(typeof showhide.o.onOpenComplete == 'function')
					{ showhide.o.onOpenComplete.call(showhide,index); }
				});

			},

		////////////////////////////////////////

		// Hide the panel
		closePanel: function(showhide)
			{
			// Close toggle
			showhide.toggle.removeClass(showhide.o.classSelected);

			// Callback at start
			if(typeof showhide.o.onCloseStart == 'function')
				{ showhide.o.onCloseStart.call(showhide,index); }

			// Close panel
			showhide.panel.removeClass(showhide.o.classSelected);
			showhide.panel.slideUp(showhide.o.toggleSpeed,showhide.o.toggleEasing,function() {
				// Callback at complete
				if(typeof showhide.o.onCloseComplete == 'function')
					{ showhide.o.onCloseComplete.call(showhide,index); }
				});
			},

		////////////////////////////////////////

		// Plugin defaults
		defaults: {

			toggleSpeed: 500, // Speed to for panel change
			toggleEasing: 'easeOutQuad', // Animation-Easing (requires the jquery-easing-plugin)
	
			defaultOpen: false, // Open the panel by default
			useCookie: false, // Use cookie to save open/close state
			cookieName: '', // Name of the cookie
	
			onInit: '', // Callback-function to perform when tabs are initialized
			onOpenStart: '', // Callback-function to perform when panel open starts
			onOpenComplete: '', // Callback-function to perform when panel open finished
			onCloseStart: '', // Callback-function to perform when panel close starts
			onCloseComplete: '', // Callback-function to perform when panel close finished
	
			selectorToggle: 'H3,H4', // Selector/Tag of the showhide toggle
			selectorPanel: "next()", // Selector/Tag of the showhide panel or simply use "next()"
	
			classContainer: 'showhide', // Class for container - will only be set, if not present
			classToggle: 'showhideToggle',
			classPanel: 'showhideContent',
			classSelected: 'act' // Class added to selected panel and toggle
			}

		}

	}(jQuery));
