/*************************************************************
* jQuery cmm3tree plugin V 1.0.0
* This is a simple jQuery-based script for an expandable UL-based tree.
* Copyright (c) 2016 Nicolas Berg GRAFIX21
* http://www.grafix21.de
*
* Licensed under the GNU General Public License: 
* http://www.gnu.org/licenses/gpl.html
**************************************************************/

(function($)
	{
    $.fn.cmm3tree = function(options)
		{
		return this.each(function(i)
			{
			var tree = this;
			tree.tree = $(this);
			tree.index = i;

			// Combine default options with current options
			tree.o = $.extend( {}, cmm3tree.defaults, options );

			// Init vars
			tree.toggles;
			tree.items;
			tree.subs;
			tree.blocked = false;

			// Init trees
			cmm3tree.init(tree,i);
			});
		};
	
	////////////////////////////////////////

	cmm3tree = {

		// Init - set basic structure
		init: function(tree,i)
			{
			// Check, if easing-plugin is loaded
			if(tree.o.toggleEasing!='' && !jQuery.easing["jswing"])
				{
				console.log('Please install the jquery-easing-plugin for more organic animations on cmm3tree!');
				tree.o.toggleEasing = '';
				}

			// Set container-class
			if(tree.o.classContainer!='' && !tree.tree.hasClass(tree.o.classContainer))
				{ tree.tree.addClass(tree.o.classContainer); }

			// Get items
			tree.items = $(tree.o.selectorItem,tree);
			// Loop items
			tree.items.each(function(index,element) {
				// Get current item
				var currentItem = $(this);
				// Set class for item
				if(tree.o.classItem!='')
					{ currentItem.addClass(tree.o.classItem); }
				// Set class for item with sub
				if(tree.o.classItemWithSub!='' && $(tree.o.selectorSub,currentItem).length > 0)
					{ currentItem.addClass(tree.o.classItemWithSub); }
				});

			// Get substructures from inside the items
			tree.subs = $();
			// Loop items
			tree.items.each(function(index,element) {
				// If item has substructure
				if($('> '+tree.o.selectorSub,this).length > 0)
					{
					// Get current item
					var currentSub = $('> '+tree.o.selectorSub,this);
					// Add class to subs
					if(tree.o.classSub!='')
						{ currentSub.addClass(tree.o.classSub); }
					// Append to list
					tree.subs = tree.subs.add(currentSub);
					}
				});

			// Set and get toggles
			tree.toggles = $();
			// Loop items
			tree.items.each(function(index,element) {
				// If item has substructure
				if($('> '+tree.o.selectorSub,this).length > 0)
					{
					// Get current item
					var currentItem = $(this);
					// Get already present toggle
					if(tree.o.classToggle!='' && $('> '+tree.o.classToggle,currentItem).length > 0)
						{
						var toggle = $('> '+tree.o.classToggle,currentItem);
						}
					// Create a new toggle
					else(tree.o.classToggle!='' && $('> '+tree.o.classToggle,currentItem).length == 0)
						{
						var toggle = $(tree.o.wrapToggle);
						toggle.addClass(tree.o.classToggle);
						currentItem.prepend(toggle);
						}
	
					toggle.on('click',function(evt) {
						evt.preventDefault();
						// Call click function
						cmm3tree.toggleSub(tree,index);
						});
					}
				});

			// Callback on init
			if(typeof tree.o.onInit == 'function')
				{ tree.o.onInit.call(tree); }

			},


		////////////////////////////////////////

		// toggle the panels (by index)
		toggleSub: function(tree,index)
			{
			if(tree.blocked==false)
				{
				// Block while change is in progress
				tree.blocked = true;

				// Close
				if(tree.items.eq(index).hasClass(tree.o.classSelected))
					{
					// Close current panel
					cmm3tree.closeSub(tree,index);
					}
				// Open
				else
					{
					// Open current panel
					cmm3tree.openSub(tree,index);
					}

				// Unblock after change is complete
				window.setTimeout(function() {
					tree.blocked = false;
					}, tree.o.toggleSpeed + 10);
				}
			},

		////////////////////////////////////////

		// show the panels (by index or all)
		openSub: function(tree,index)
			{
			// Loop all items
			tree.items.each(function(ind,element) {
				// Open selected or all
				if((ind == index || index===''))
					{
					if(!$(this).hasClass(tree.o.classSelected))
						{
						// Add class to item
						var currentItem = $(this);
						currentItem.addClass(tree.o.classSelected);
	
						// Add class to toggle
						var currentToggle = $('.'+tree.o.classToggle,this).first();
						currentToggle.addClass(tree.o.classSelected);
	
						// Add class to substructure and open it
						var currentSub = $('.'+tree.o.classSub,this).first();
	
						// Callback at start
						if(typeof tree.o.onOpenStart == 'function')
							{ tree.o.onOpenStart.call(tree,index); }
	
						// Slide down
						currentSub.slideDown(tree.o.toggleSpeed,tree.o.toggleEasing,function() {
							// Add class
							currentSub.addClass(tree.o.classSelected);
	
							// Callback at complete
							if(typeof tree.o.onOpenComplete == 'function')
								{ tree.o.onOpenComplete.call(tree,index); }
							});
						}
					}
				});
			},

		////////////////////////////////////////

		// Hide the panels (by index or all)
		closeSub: function(tree,index)
			{
			// Loop all items
			tree.items.each(function(ind,element) {
				// Close selected or all
				if((ind == index || index===''))
					{
					if($(this).hasClass(tree.o.classSelected))
						{
						// Add class to item
						var currentItem = $(this);
						currentItem.removeClass(tree.o.classSelected);
	
						// Add class to toggle
						var currentToggle = $('.'+tree.o.classToggle,this).first();
						currentToggle.removeClass(tree.o.classSelected);
	
						// Add class to substructure and open it
						var currentSub = $('.'+tree.o.classSub,this).first();
	
						// Callback at start
						if(typeof tree.o.onCloseStart == 'function')
							{ tree.o.onCloseStart.call(tree,index); }
	
						// Slide down
						currentSub.slideUp(tree.o.toggleSpeed,tree.o.toggleEasing,function() {
							// Add class
							currentSub.removeClass(tree.o.classSelected);
	
							// Callback at complete
							if(typeof tree.o.onCloseComplete == 'function')
								{ tree.o.onCloseComplete.call(tree,index); }
							});
						}
					}
				});
			},

		////////////////////////////////////////

		// Plugin defaults
		defaults: {

			toggleSpeed: 500, // Speed to for panel change
			toggleEasing: 'easeOutQuad', // Animation-Easing (requires the jquery-easing-plugin)
		
			onInit: '', // Callback-function to perform when tabs are initialized
			onOpenStart: '', // Callback-function to perform when panel open starts
			onOpenComplete: '', // Callback-function to perform when panel open finished
			onCloseStart: '', // Callback-function to perform when panel close starts
			onCloseComplete: '', // Callback-function to perform when panel close finished
	
			wrapToggle: '<DIV>', // Selector/Tag to prepend to each toggle block as toggle-handle
			selectorItem: "LI", // Selector/Tag of the elements containing substructures
			selectorSub: "UL", // Selector/Tag for the substructures
	
			classContainer: 'tree', // Class for container - will only be set, if not present
			classToggle: 'treeToggle', // Class for existing or new added toggle
			classItem: 'treeItem', // Class for each item
			classItemWithSub: 'treeItemWithSub', // Class for each item containing a substructure
			classSub: 'treeSub', // Class for the substructure
			classSelected: 'act' // Class added to selected item, toggle and substructure
			}

		}

	}(jQuery));
