<?PHP
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////
// Plugin fuer Feeds-Liste                               //
///////////////////////////////////////////////////////////
// V 1.0 First release
// V 1.2.0 included import-function CMM_getFeedData()
// V 1.3.0 Full recoded
// V 1.4.0 Full recoded for new object-logic
// V 1.4.1 field full_picture added
// V 1.4.2 Improved error handling
// V 1.4.2 Added fbType status
// V 1.4.3 Token-Processing changed
///////////////////////////////////////////////////////////

include_once(CMM_ROOT_DIR.'CMM_Feeds/index.php');

/* PARAMS START - Marker-Comments required! */
$params = array(
	'templateFile'=>'CMM_Feeds/template/html/CMM_Feeds_fbfeed.html',
	'feedUrl' => '',
	'fbAppID' => '',
	'fbSecret' => '',
	'fbTypes' => 'link,photo,video,offer,event,status',
	'fbFields' => 'id,message,picture,full_picture,link,name,description,type,icon,created_time,from,object_id,comments.limit(1).summary(true),likes.limit(1).summary(true)',
	'feedLimit'=>30,
	'pagenaviShow'=>1,
	'pagenaviPages'=>'',
	'limit'=>'{$_REQUEST["CMM_Feeds"]["limit"]}',
	'limitShow' => 1,
	'limitOptions'=>'{array(6,12,18,24,36)}',
	'start'=>'{$_REQUEST["CMM_Feeds"]["start"]}',
//	'agent' => 'Mozilla/4.0 (compatible; MSIE 10.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)',
	'cacheTimeout' => 3600,
	'cacheHashItems' => 'feedUrl,feedLimit,fbAppID,fbSecret,fbFields',
	'cacheStorage' => 'db'
	);
/* PARAMS END */

/* FIELDSET START - Marker-Comments required! */
$fieldset = array(
	'templateFile' => array('label'=>'HTML-Vorlagen-Datei','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'feedUrl' => array('label'=>'Facebook: Seiten-ID','description'=>'Facebook-Seiten-ID','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'fbAppID' => array('label'=>'Facebook: App-ID','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'fbSecret' => array('label'=>'Facebook: Secret-Key','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'fbTypes' => array('label'=>'Facebook: erlaubte Post-Typen','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'fbFields' => array('label'=>'Facebook: abzufragende Felder','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'feedLimit' => array('label'=>'Facebook: Anzahl der einzulesenden Einträge','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'pagenaviShow' => array('label'=>'Seitennavigation: anzeigen','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'right'),
	'pagenaviPages' => array('label'=>'Seitennavigation: max. Seiten','type'=>'textfield','datatype'=>'code','position'=>'right'),
	'limit' => array('label'=>'Seitennavigation: Einträge pro Seite (Anzahl oder Variable)','type'=>'textfield','datatype'=>'code','position'=>'right'),
	'limitShow' => array('label'=>'Einträge pro Seite: Auswahl anzeigen','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'right'),
	'limitOptions' => array('label'=>'Einträge pro Seite: Auswahlwerte','type'=>'textfield','datatype'=>'code','position'=>'right'),
	'start' => array('label'=>'Liste beginnen bei (Anzahl oder Variable)','type'=>'textfield','position'=>'right','shy'=>1),
//	'agent' => array('label'=>'simulierter Browser: (User-Agent-String)','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'cacheTimeout' => array('label'=>'Cache: Dauer','type'=>'textfield','datatype'=>'int','position'=>'bottom','shy'=>1),
	'cacheHashItems' => array('label'=>'Cache: Elemente zur Indentifikation des Datensatzes','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'cacheStorage' => array('label'=>'Cache: Speicher (file/db)','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1)
	);
/* FIELDSET END */


///////////////////////////////////////////////////////////


// Merge global plugin-params with params of this instance
$params = CMM_mergePluginParams($params,$pluginParams);

// Get CID and Start from page-tail (last part of url)
if($CONFIG['CMM']['config']['seoUseSeoUrls']==true)
	{
	if(isset($params['CID']) && strstr($params['CID'],'{') && substr_count($GLOBALS['PageTail'],'/') > 1)
		{
		$tempCID = CMM_getPagetailParams($GLOBALS['PageTail'],'first');
		!empty($tempCID) ? $params['CID'] = $tempCID : '';
		}
	if(isset($params['start']) && strstr($params['start'],'{') && !empty($GLOBALS['PageTail']))
		{
		$tempStart = CMM_getPagetailParams($GLOBALS['PageTail'],'start');
		!empty($tempStart) ? $params['start'] = $tempStart : '';
		}
	}


///////////////////////////////////////////////////////////


// Init new object
$extFeedsList = new CMM_Feeds;

// Merge params with object-properties
$extFeedsList->params = CMM_mergePluginParams($extFeedsList->params,$params);

// Get cached content
$extFeedsList->getCache();

///////////////////////////////////////////////////////////


// If cache is empty or obsolete
if(empty($extFeedsList->items))
	{
	!is_array($extFeedsList->params['fbTypes']) ? $extFeedsList->params['fbTypes'] = explode(',',$extFeedsList->params['fbTypes']) : '';

	// Get access-token
	$fbURLToken = 'https://graph.facebook.com/oauth/access_token?client_id='.$extFeedsList->params['fbAppID'].'&client_secret='.$extFeedsList->params['fbSecret'].'&grant_type=client_credentials';
	$connect = curl_init();
	curl_setopt($connect, CURLOPT_SSL_VERIFYPEER, false);
	curl_setopt($connect, CURLOPT_VERBOSE, true);
	curl_setopt($connect, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($connect, CURLOPT_USERAGENT, $_SERVER['HTTP_USER_AGENT']); //$extFeedsList->params['agent']
	curl_setopt($connect, CURLOPT_URL,$fbURLToken);
	@$tokenResult = curl_exec($connect);
	//var_dump($tokenResult);

	// No result
	if($tokenResult == false)
		{ $extFeedsList->errors[] = 'No token data recieved from facebook.'; }

	// Get error or result
	if(stristr($tokenResult,'error'))
		{
		$error = json_decode($tokenResult,true);
		$extFeedsList->errors[] = $error['error']['type'].' ('.$error['error']['code'].'): '.$error['error']['message'];
		}
	else
		{
		$tokenResult = json_decode($tokenResult,true);
		$fbToken = $tokenResult['access_token'];
		}

	// Get facebook-feed
	$fbURLContent = 'https://graph.facebook.com/'.$extFeedsList->params['feedUrl'].'/feed?'.(!stristr($fbToken,'access_token=') ? 'access_token=' : '').$fbToken.'&fields='.$extFeedsList->params['fbFields'].'&limit='.$extFeedsList->params['feedLimit'];
	$connect = curl_init();
	curl_setopt($connect, CURLOPT_SSL_VERIFYPEER, false);
	curl_setopt($connect, CURLOPT_VERBOSE, true);
	curl_setopt($connect, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($connect, CURLOPT_USERAGENT, $_SERVER['HTTP_USER_AGENT']); //$extFeedsList->params['agent']
	curl_setopt($connect, CURLOPT_URL,$fbURLContent);
	@$contentResult = curl_exec($connect);
	//var_dump($contentResult);

	// No result
	if($contentResult == false)
		{ $extFeedsList->errors[] = 'No feed data recieved from facebook.'; }

	// Get error or result
	if(stristr($contentResult,'error'))
		{
		$error = json_decode($contentResult,true);
		$extFeedsList->errors[] = $error['error']['type'].' ('.$error['error']['code'].'): '.$error['error']['message'];
		}
	else
		{ $content = json_decode($contentResult,true); }

	$items = array();
	if(!empty($content['data']))
		{
		// Loop data-items
		foreach($content['data'] as $item)
			{
			if(in_array($item['type'],$extFeedsList->params['fbTypes']))
				{
				$id = !empty($item['id']) ? $item['id'] : '';
				$type = !empty($item['type']) ? $item['type'] : '';
				$date = !empty($item['created_time']) ? date('Y-m-d H:i:s', strtotime($item['created_time'])) : '';
				$title = !empty($item['message']) ? $item['message'] : '';
				$text = !empty($item['description']) ? $item['description'] : '';
				$link = !empty($item['link']) ? $item['link'] : '';
	
				$title = str_replace(array("\r","\n","\t"),'',$title);
				$text = str_replace(array("\r","\n","\t"),'',$text);
	
				$likes = !empty($item['likes']['summary']['total_count']) ? $item['likes']['summary']['total_count'] : 0;
				$comments = !empty($item['comments']['summary']['total_count']) ? $item['comments']['summary']['total_count'] : 0;
	
				$images = !empty($item['picture']) ? '<img src="'.$item['picture'].'" />' : '';
				!empty($item['full_picture']) ? $images = '<img src="'.$item['full_picture'].'" />' : '';

				// Add new item to post list
				if(!empty($title))
					{ $items[] = array('id'=>$id,'date'=>$date,'title'=>$title,'text'=>$text,'images'=>$images,'link'=>$link,'type'=>$type,'likes'=>$likes,'comments'=>$comments); }
				}
			}

		// Transfer items to object-property and set cache
		if(!empty($items))
			{
			$extFeedsList->items = $items;
			// Set cache
			$extFeedsList->setCache();
			}
		}
	}


///////////////////////////////////////////////////////////


// Create content
$pluginContent = $extFeedsList->createContent();

// Error, if config-missing data
if(empty($extFeedsList->params['feedUrl']) || empty($extFeedsList->params['fbAppID']) || empty($extFeedsList->params['fbSecret']))
	{ $pluginContent.= CMM_createMessage('Please be sure to set all requiered data: feedUrl(Facebook-PageID), App-ID and App-Secret!','error'); }

// Unset plugin-params
unset($params);
?>