<?PHP
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////
// Plugin fuer Feeds-Liste                               //
///////////////////////////////////////////////////////////
// V 1.0 First release
// V 1.2.0 included import-function CMM_getFeedData()
// V 1.3.0 Full recoded
// V 1.4.0 Full recoded for new object-logic
// V 1.4.1 Improved error handling
///////////////////////////////////////////////////////////

include_once(CMM_ROOT_DIR.'CMM_Feeds/index.php');

/* PARAMS START - Marker-Comments required! */
$params = array(
	'templateFile'=>'CMM_Feeds/template/html/CMM_Feeds_fbgallery.html',
	'feedUrl' => '', //108657762554404',
	'fbAppID' => '',
	'fbSecret' => '',
	'fbTypes' => 'link,photo,video,offer,event',
	'fbFields' => 'id,message,picture,link,name,description,type,icon,created_time,from,object_id,comments.limit(1).summary(true),likes.limit(1).summary(true)',
	'pagenaviShow'=>0,
	'limitShow' => 0,
	'agent' => 'Mozilla/4.0 (compatible; MSIE 10.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)',
	'cacheTimeout' => 3600,
	'cacheHashItems' => 'feedUrl',
	'cacheStorage' => 'db'
	);
/* PARAMS END */

/* FIELDSET START - Marker-Comments required! */
$fieldset = array(
	'templateFile' => array('label'=>'HTML-Vorlagen-Datei','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'feedUrl' => array('label'=>'Facebook: Seiten-ID','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'fbAppID' => array('label'=>'Facebook: App-ID','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'fbSecret' => array('label'=>'Facebook: Secret-Key','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'fbTypes' => array('label'=>'Facebook: erlaubte Post-Typen','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'fbFields' => array('label'=>'Facebook: abzufragende Felder','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'pagenaviShow' => array('label'=>'Seitennavigation: anzeigen','type'=>'hidden','value'=>0,'position'=>'right'),
	'limitShow' => array('label'=>'Einträge pro Seite: Auswahl anzeigen','type'=>'hidden','value'=>0,'position'=>'right'),
	'agent' => array('label'=>'simulierter Browser: (User-Agent-String)','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'cacheTimeout' => array('label'=>'Cache: Dauer','type'=>'textfield','datatype'=>'int','position'=>'bottom','shy'=>1),
	'cacheHashItems' => array('label'=>'Cache: Elemente zur Indentifikation des Datensatzes','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'cacheStorage' => array('label'=>'Cache: Speicher (file/db)','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1)
	);
/* FIELDSET END */


///////////////////////////////////////////////////////////


// Merge global plugin-params with params of this instance
$params = CMM_mergePluginParams($params,$pluginParams);

// CID und Start aus Pagetail ermitteln
if($CONFIG['CMM']['config']['seoUseSeoUrls']==true)
	{
	if(isset($params['CID']) && strstr($params['CID'],'{') && substr_count($GLOBALS['PageTail'],'/') > 1)
		{
		$tempCID = CMM_getPagetailParams($GLOBALS['PageTail'],'first');
		!empty($tempCID) ? $params['CID'] = $tempCID : '';
		}
	if(isset($params['start']) && strstr($params['start'],'{') && !empty($GLOBALS['PageTail']))
		{
		$tempStart = CMM_getPagetailParams($GLOBALS['PageTail'],'start');
		!empty($tempStart) ? $params['start'] = $tempStart : '';
		}
	}


///////////////////////////////////////////////////////////


// Init new object
$extFeedsList = new CMM_Feeds;

// Merge params with object-properties
$extFeedsList->params = CMM_mergePluginParams($extFeedsList->params,$params);

// Get cached content
$extFeedsList->getCache();


///////////////////////////////////////////////////////////


// If cache is empty or obsolete
if(empty($extFeedsList->items))
	{
	// Connect with external data source
	$connect = curl_init();
	curl_setopt($connect, CURLOPT_SSL_VERIFYPEER, false);
	curl_setopt($connect, CURLOPT_VERBOSE, true);
	curl_setopt($connect, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($connect, CURLOPT_USERAGENT, $params['agent']);
	curl_setopt($connect, CURLOPT_URL,$params['url']);
	@$result = curl_exec($connect);
	//var_dump($result);

	// No result
	if($result == false)
		{ $extFeedsList->errors[] = 'No data on &quot;'.$extFeedsList->params['feedUrl'].'&quot;.'; }

	$resultMatch = $result;

	// Hochkomma entfenen -> sonst Fehler in SQL-STATEMENT
	$resultMatch = str_replace("'",'',$resultMatch);
			
	// Render post
	$items = array();
	if(!empty($result))
		{
		// Date + Timestamp
		preg_match("|fbPhotoAlbumActionList.*data-utime=\"([0-9]+)\"|siU",$resultMatch,$dateMatch);
		$timestamp = $dateMatch[1];
		$date = date('Y-m-d H:i:s',$dateMatch[1]);
		// Title
		preg_match("|<h1 class=\"fbPhotoAlbumTitle\">(.*)</h1>|siU",$resultMatch,$titleMatch);
		$title = strip_tags($titleMatch[1]);
		$title = str_replace('\'','´',$title);
		// Text
		preg_match("|<span class=\"fbPhotoCaptionText\">(.*)</span>|siU",$resultMatch,$textMatch);
		$text = strip_tags($textMatch[1]);
		$text = str_replace('\'','´',$text);
		// Images
		preg_match_all("|<a class=\"uiMediaThumb.*</a>|siU",$resultMatch,$imageMatch);
		$images = $imageMatch[0];
		// Anzahl begrenzen - nur erstes
//		if(sizeof($images) > 1)
//			{ $images = array_slice($images,0,1); }
		foreach($images as $i => $imagesItem)
			{
			preg_match('|background-image: url\((.*)\)|siU',$imagesItem,$imageSrc);
		//	preg_match('|href="(.*)"|siU',$imagesItem,$imageLink);
			preg_match('|aria-label="(.*)"|siU',$imagesItem,$imageCaption);
		//	$images[$i] = '<img src="'.$imageSrc[1].'" link="'.$imageLink[1].'" alt="'.$imageCaption[1].'" caption="'.$imageCaption[1].'" />';
			$images[$i] = '<img src="'.str_replace('p206x206/','',$imageSrc[1]).'" alt="'.$imageCaption[1].'" caption="'.$imageCaption[1].'" />';
			}
		$images = implode('',$images);

		// Add new item to post list
		$items[] = array('date'=>$date,'title'=>$title,'text'=>$text,'images'=>$images);
		}

	return $items;
	}


///////////////////////////////////////////////////////////


// Create content
$pluginContent = $extFeedsList->createContent();

// TEMP WARNING
$pluginContent.= '<big>FB-GALLERY-IMPORT is currently not available because still UNDER CONSTRUCTION!</big>';

// Error, if config-missing data
if(empty($extFeedsList->params['feedUrl']) || empty($extFeedsList->params['fbAppID']) || empty($extFeedsList->params['fbSecret']))
	{ $pluginContent.= CMM_createMessage('Please be sure to set all requiered data: feedUrl(Facebook-PageID), App-ID and App-Secret!','error'); }


// Unset plugin-params
unset($params);
?>