<?PHP
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////
// Plugin fuer Feeds-Liste                               //
///////////////////////////////////////////////////////////
// V 1.0 First release
// V 1.2.0 included import-function CMM_getFeedData()
// V 1.3.0 Full recoded
// V 1.4.0 Full recoded for new object-logic
// V 1.4.1 Improved error handling
///////////////////////////////////////////////////////////

include_once(CMM_ROOT_DIR.'CMM_Feeds/index.php');

/* PARAMS START - Marker-Comments required! */
$params = array(
	'templateFile'=>'CMM_Feeds/template/html/CMM_Feeds_rssfeed_detail.html',
	'feedUrl'=>'',
	'feedLimit'=>20,
	'utf8encode'=>0,
	'listPID'=>'',
	'detailPID'=>'',
	'UIDinPageAlias'=>1,
	'pagenaviShow'=>1,
	'pagenaviPages'=>'',
	'limit'=>1,
	'limitShow'=>1,
	'limitOptions'=>'',
	'start'=>'{$_REQUEST["CMM_Feeds"]["start"]}',
	'agent'=>'Mozilla/4.0 (compatible; MSIE 10.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)',
	'cacheTimeout'=>3600,
	'cacheHashItems'=>'feedUrl,feedLimit',
	'cacheStorage'=>'file'
	);
/* PARAMS END */

/* FIELDSET START - Marker-Comments required! */
$fieldset = array(
	'templateFile' => array('label'=>'HTML-Vorlagen-Datei','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'feedUrl' => array('label'=>'Feed: URL','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'feedLimit' => array('label'=>'Feed: Anzahl einzulesender Einträge','type'=>'textfield','datatype'=>'int','position'=>'left'),
	'utf8encode' => array('label'=>'Feed: Zusätzlich UTF8-codieren','type'=>'checkbox','options'=>array(array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'left','shy'=>1),
	'listPID' => array('label'=>'Seite: Listen-Anzeige (PID)','type'=>'linkfield','position'=>'left'),
	'detailPID' => array('label'=>'Seite: Detail-Anzeige (PID)','type'=>'linkfield','position'=>'left'),
	'UIDinPageAlias' => array('label'=>'Eintrag: UID aus SEO-URL ermitteln','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'left','shy'=>1),
	'pagenaviShow' => array('label'=>'Seitennavigation: anzeigen','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'right'),
	'pagenaviPages' => array('label'=>'Seitennavigation: max. Seiten','type'=>'textfield','datatype'=>'code','position'=>'right'),
	'limit' => array('label'=>'Seitennavigation: Einträge pro Seite (Anzahl oder Variable)','type'=>'textfield','datatype'=>'code','position'=>'right'),
	'limitShow' => array('label'=>'Einträge pro Seite: Auswahl anzeigen','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'right'),
	'limitOptions' => array('label'=>'Einträge pro Seite: Auswahlwerte','type'=>'textfield','datatype'=>'code','position'=>'right'),
	'start' => array('label'=>'Liste beginnen bei (Anzahl oder Variable)','type'=>'hidden','position'=>'right'),
	'agent' => array('label'=>'simulierter Browser: (User-Agent-String)','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'cacheTimeout' => array('label'=>'Cache: Dauer','type'=>'textfield','datatype'=>'int','position'=>'bottom','shy'=>1),
	'cacheHashItems' => array('label'=>'Cache: Elemente zur Indentifikation des Datensatzes','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'cacheStorage' => array('label'=>'Cache: Speicher (file/db)','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1)
	);
/* FIELDSET END */


///////////////////////////////////////////////////////////


// Merge global plugin-params with params of this instance
$params = CMM_mergePluginParams($params,$pluginParams);

// CID und Start aus Pagetail ermitteln
if($CONFIG['CMM']['config']['seoUseSeoUrls']==true)
	{
	//if(stristr($params['CID'],'{') && substr_count($GLOBALS['PageTail'],'/') > 1)
	//	{ $params['CID'] = CMM_getPagetailParams($GLOBALS['PageTail'],'first'); }
	if(isset($params['start']) && strstr($params['start'],'{') && !empty($GLOBALS['PageTail']))
		{
		$tempStart = CMM_getPagetailParams($GLOBALS['PageTail'],'start');
		!empty($tempStart) ? $params['start'] = $tempStart : '';
		}
	}


///////////////////////////////////////////////////////////


// Init new object
$extFeedsList = new CMM_Feeds;

// Merge params with object-properties
$extFeedsList->params = CMM_mergePluginParams($extFeedsList->params,$params);

// Get cached content
$extFeedsList->getCache();


///////////////////////////////////////////////////////////

// If cache is empty or obsolete
if(empty($extFeedsList->items))
	{
	// Connect with external data source
	$connect = curl_init();
	curl_setopt($connect, CURLOPT_SSL_VERIFYPEER, false);
	curl_setopt($connect, CURLOPT_VERBOSE, true);
	curl_setopt($connect, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($connect, CURLOPT_USERAGENT, $extFeedsList->params['agent']);
	curl_setopt($connect, CURLOPT_URL,$extFeedsList->params['feedUrl']);
	@$result = curl_exec($connect);
	//var_dump($result);

	// No result
	if($result == false)
		{ $extFeedsList->errors[] = 'No feed data on &quot;'.$extFeedsList->params['feedUrl'].'&quot;.'; }

	// Set UTF-8-Encoding
	if(sizeof($extFeedsList->errors) == 0 && !empty($extFeedsList->params['utf8encode']))
		{ $result = utf8_encode($result); }
	
	// Proccess with SimpleXML
	if(sizeof($extFeedsList->errors) == 0)
		{ $rss = simplexml_load_string($result); }

	// No result
	if($rss == false)
		{ $extFeedsList->errors[] = 'Data contains no valid XML-object.'; }

	// Get namespaces
	if(sizeof($extFeedsList->errors) == 0)
		{
		$ns = $rss->getNamespaces(true);

		// Render posts
		$items = array();
		if(!empty($rss->channel->item))
			{
			foreach($rss->channel->item as $item)
				{
				// Objekte mit eigenen Namespaces
				if(isset($ns['dc']))
					{ $nsDc = $item->children($ns['dc']); }
				if(isset($ns['content']))
					{ $nsContent = $item->children($ns['content']); }
	
				// Daten
				$date = (string) $item->pubDate;
				$date = date('Y-m-d H:i:s',strtotime($date));
	
				// Link
				$link = (string) $item->link;
				$link = trim($link);
	
				// Title
				$title = (string) $item->title;
				$title = trim(strip_tags($title));
				$title = str_replace(array('{','}','&lt;','&amp;#','"'),array('','','\'','´','&#','&quot;'),$title);
	
				// Text
				if(isset($nsContent->encoded))
					{ $text = trim($nsContent->encoded); }
				else
					{ $text = trim($item->description); }
				$text = CMM_forceUtf8(trim($text));
				$text = str_replace(array('{','}','&lt;','&amp;#','"'),array('','','\'','´','&#','&quot;'),$text);
				$text = strip_tags((string) $text);
	
				// Images
				if(isset($nsContent->encoded))
					{ $description = trim($nsContent->encoded); }
				else
					{ $description = trim($item->description); }
				$description = CMM_forceUtf8(trim($description));
				$description = str_replace(array('{','}','&lt;','&gt;','&amp;#'),array('','','<','>','&#'),$description);
				$images = '';
				if(stristr($description,'<img'))
					{
					// Search for image tags in description
					preg_match_all("|(<img.*>)|siU",$description,$imageMatch);
					if(sizeof($imageMatch[1]) > 0)
						{
						$images = $imageMatch[1];
						// Limit to first image
						if(sizeof($images) > 1)
							{ $images = array_slice($images,0,1); }
						// Analyze image tags
						foreach($images as $i => $imagesItem)
							{
							preg_match('|src="(.*)"|siU',$imagesItem,$imageSrc);
							$images[$i] = '<img src="'.$imageSrc[1].'" />';
							}
						// Concat image string
						$images = implode('',$images);
						}
					}
				else if(isset($item->enclosure))
					{
					$images = '<img src="'.$item->enclosure['url'].'" />';
					}
	
				// Add new item to post list
				if(!empty($title))
					{ $items[] = array('date'=>$date,'title'=>$title,'text'=>$text,'images'=>$images,'link'=>$link); }
				}
	
			// Transfer items to object-property and set cache
			if(!empty($items))
				{
				$extFeedsList->items = $items;
				// Set cache
				$extFeedsList->setCache();
				}
			}
		}
	}


///////////////////////////////////////////////////////////


// Create content
$pluginContent = $extFeedsList->createContent();

// Error, if config-missing data
if(empty($extFeedsList->params['feedUrl']))
	{ $pluginContent.= CMM_createMessage('Please be sure to set all requiered data: feedUrl(RSS-URL)!','error'); }

// Unset plugin-params
unset($params);
?>