<?PHP
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////
// Plugin fuer Feeds-Liste                               //
///////////////////////////////////////////////////////////
// V 1.0 First release
// V 1.2.0 included import-function CMM_getFeedData()
// V 1.3.0 Full recoded
// V 1.4.0 Full recoded for new object-logic
// V 1.4.1 Improved error handling
///////////////////////////////////////////////////////////

include_once(CMM_ROOT_DIR.'CMM_Feeds/index.php');

/* PARAMS START - Marker-Comments required! */
$params = array(
	'templateFile'=>'CMM_Feeds/template/html/CMM_Feeds_twitterfeed.html',
	'feedUrl'=>'',
	'feedLimit'=>30,
	'pagenaviShow'=>1,
	'pagenaviPages'=>'',
	'limit'=>'{$_REQUEST["CMM_Feeds"]["limit"]}',
	'limitShow' => 1,
	'limitOptions'=>'{array(6,12,18,24,36)}',
	'start'=>'{$_REQUEST["CMM_Feeds"]["start"]}',
	'agent' => 'Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2228.0 Safari/537.36',
	'cacheTimeout' => 3600,
	'cacheHashItems' => 'feedUrl,feedLimit',
	'cacheStorage' => 'db'
	);
/* PARAMS END */

/* FIELDSET START - Marker-Comments required! */
$fieldset = array(
	'templateFile' => array('label'=>'HTML-Vorlagen-Datei','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'feedUrl' => array('label'=>'Feed: URL','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'feedLimit' => array('label'=>'Feed: Anzahl einzulesender Einträge','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'pagenaviShow' => array('label'=>'Seitennavigation: anzeigen','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'right'),
	'pagenaviPages' => array('label'=>'Seitennavigation: max. Seiten','type'=>'textfield','datatype'=>'code','position'=>'right'),
	'limit' => array('label'=>'Seitennavigation: Einträge pro Seite (Anzahl oder Variable)','type'=>'textfield','datatype'=>'code','position'=>'right'),
	'limitShow' => array('label'=>'Einträge pro Seite: Auswahl anzeigen','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'right'),
	'limitOptions' => array('label'=>'Einträge pro Seite: Auswahlwerte','type'=>'textfield','datatype'=>'code','position'=>'right'),
	'start' => array('label'=>'Liste beginnen bei (Anzahl oder Variable)','type'=>'hidden','position'=>'right'),
	'agent' => array('label'=>'simulierter Browser: (User-Agent-String)','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'cacheTimeout' => array('label'=>'Cache: Dauer','type'=>'textfield','datatype'=>'int','position'=>'bottom','shy'=>1),
	'cacheHashItems' => array('label'=>'Cache: Elemente zur Indentifikation des Datensatzes','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'cacheStorage' => array('label'=>'Cache: Speicher (file/db)','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1)
	);
/* FIELDSET END */


///////////////////////////////////////////////////////////


// Merge global plugin-params with params of this instance
$params = CMM_mergePluginParams($params,$pluginParams);

// CID und Start aus Pagetail ermitteln
if($CONFIG['CMM']['config']['seoUseSeoUrls']==true)
	{
	if(isset($params['CID']) && strstr($params['CID'],'{') && substr_count($GLOBALS['PageTail'],'/') > 1)
		{
		$tempCID = CMM_getPagetailParams($GLOBALS['PageTail'],'first');
		!empty($tempCID) ? $params['CID'] = $tempCID : '';
		}
	if(isset($params['start']) && strstr($params['start'],'{') && !empty($GLOBALS['PageTail']))
		{
		$tempStart = CMM_getPagetailParams($GLOBALS['PageTail'],'start');
		!empty($tempStart) ? $params['start'] = $tempStart : '';
		}
	}


///////////////////////////////////////////////////////////


// Init new object
$extFeedsList = new CMM_Feeds;

// Merge params with object-properties
$extFeedsList->params = CMM_mergePluginParams($extFeedsList->params,$params);

// Get cached content
$extFeedsList->getCache();


///////////////////////////////////////////////////////////


// If cache is empty or obsolete
if(empty($extFeedsList->items))
	{
/* TWITTER-API */
/*
	require_once(__DIR__.'/incl/TwitterAPIExchange.php');

	$twUsername = '';
	$feedLimit = 30;
	$twConsumerKey = "";
	$twConsumerSecret = "";
	$twAccessToken = '';
	$twAccessTokenSecret = '';

	// Set access tokens here
	$settings = array(
		'consumer_key' => $twConsumerKey,
		'consumer_secret' => $twConsumerSecret,
		'oauth_access_token' => $twAccessToken,
		'oauth_access_token_secret' => $twAccessTokenSecret
		);

	$url = 'https://api.twitter.com/1.1/statuses/user_timeline.json';
	$getfield = '?screen_name=' . $twUsername . '&count=' . $feedLimit;
	$requestMethod = 'GET';

	$twitterInstance = new TwitterAPIExchange($settings);

	$query = $twitterInstance
		->setGetfield($getfield)
		->buildOauth($url,$requestMethod)
		->performRequest();

	$timeline = json_decode($query);

	var_dump($timeline);
*/

	// Connect with external data source
	$connect = curl_init();
	curl_setopt($connect, CURLOPT_SSL_VERIFYPEER, false);
	curl_setopt($connect, CURLOPT_VERBOSE, true);
	curl_setopt($connect, CURLOPT_TIMEOUT, 30);
	curl_setopt($connect, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($connect, CURLOPT_USERAGENT, $extFeedsList->params['agent']);
	curl_setopt($connect, CURLOPT_URL,$extFeedsList->params['feedUrl']);
	@$result = curl_exec($connect);
	//var_dump($result);

	// No result
	if($result == false)
		{ $extFeedsList->errors[] = 'No feed data on &quot;'.$extFeedsList->params['feedUrl'].'&quot;.'; }

	// Get posts
	$result = explode('<ol class="stream-items',$result);
	$result = $result[1];

	if(!empty($result))
		{
		$result = explode('<li class="js-stream-item',$result);
		array_shift($result);
		}
	else
		{ $result = array(); }

	// Render posts
	$items = array();
	if(!empty($result))
		{
		foreach($result as $resultItem)
			{
			// Hochkomma entfenen -> sonst Fehler in SQL-STATEMENT
			$resultItem = str_replace("'",'',$resultItem);
				
			// Date + Timestamp
			preg_match("|data-time=\"([0-9]+)\"|siU",$resultItem,$dateMatch);
			$timestamp = sizeof($dateMatch[1])>0 ?$dateMatch[1] : 0;
			$date = date('Y-m-d H:i:s',$timestamp);

			// Link
			preg_match("|url\=\"(.*)\"|siU",$resultItem,$linkMatch);
			$link = sizeof($linkMatch[1])>0 ? ''.$linkMatch[1] : '';

			// Title
			preg_match("|<p.*class=\".*tweet-text.*>(.*)</p>|siU",$resultItem,$titleMatch);
			$title = !empty($titleMatch[1]) ? $titleMatch[1] : '';
			// Tags entfernen
			$title = strip_tags($title);
			$title = str_replace(array('&nbsp;','…','\''),array(' ','','´'),strip_tags($title));
			// Hash-Links ergaenzen
		//	$title = str_replace('"/search','"https://www.twitter.com/search',$title);
			// Link-Target ergaenzen
		//	$title = str_replace('<a ','<a target="_blank" ',$title);

			// Text
			$text = $title;
			// Images
			$images = '';

			// Add new item to post list
			$items[] = array('date'=>$date,'title'=>$title,'text'=>$text,'images'=>$images,'link'=>$link);
			}

		// Transfer items to object-property and set cache
		if(!empty($items))
			{
			$extFeedsList->items = $items;
			// Set cache
			$extFeedsList->setCache();
			}
		}
	}


///////////////////////////////////////////////////////////


// Create content
$pluginContent = $extFeedsList->createContent();

// Error, if config-missing data
if(empty($extFeedsList->params['feedUrl']))
	{ $pluginContent.= CMM_createMessage('Please be sure to set all requiered data: feedUrl(Twitter-Profile-URL)','error'); }

// Unset plugin-params
unset($params);
?>