<?PHP
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////
// Plugin fuer eine Google-Map                           //
///////////////////////////////////////////////////////////
// V 1.0 First release
// V 1.0.1 (Breite und Höhe nun auch in %)
// V 1.0.2 Spanne fuer Zoom-Faktor angepasst
// V 1.0.3 Monochrom-Modus und Marker-Info eingefuegt
// V 1.0.4 Bugfix fuer Markerinfo
// V 1.0.5 Erweiterung um Optionen Farbton und Maus-Scrolling
// V 1.0.6 Marker sind nicht mehr mit {br} sondern {nl} verkettet
// V 1.0.7 Adressen nun als Adresse oder Koordinaten anzugeben
// V 1.0.8 Trennzeichen fuer Adressmarker in <nl> geaendert
// V 1.0.9 Marker-icon added
// V 1.1.0 Added global var googleMapsApi for api inclusion
// V 1.2.0 Cache added an reorganized output vars
// V 1.2.1 Input field options mod.
///////////////////////////////////////////////////////////

/* PARAMS START - Marker-Comments required! */
$params = array(
	'templateFile'=>'CMM_Pluginset/template/html/GoogleMap.html',
	'width'=>'100%',
	'height'=>'350',
	'zoom'=>'10',
	'maxZoom'=>'',
	'maptype'=>'ROADMAP',
	'monochrome'=>'0',
	'hue'=>'',
	'scrollwheel'=>'1',
	'address'=>'',
	'title'=>'',
	'info'=>'',
	'icon'=>'',
	'fitBounds'=>'0',
	'cacheTimeout'=>86400
	);
/* PARAMS END */

/* FIELDSET START - Marker-Comments required! */
$fieldset = array(
	'templateFile' => array('label'=>'HTML-Template-Datei','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'width' => array('label'=>'Breite (px oder %)','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'height' => array('label'=>'Höhe (px oder %)','type'=>'textfield','datatype'=>'text','position'=>'left'),
	'zoom' => array('label'=>'Zoomfaktor (1-20)','type'=>'textfield','datatype'=>'int','position'=>'right'),
	'maxZoom' => array('label'=>'maximal zulässiger Zoomfaktor (1-20)','type'=>'textfield','datatype'=>'int','position'=>'right','shy'=>1),
	'maptype' => array('label'=>'Kartentyp','type'=>'select','disablenone'=>1,'options'=>array(array('value'=>'ROADMAP','text'=>'Straßenkarte'),array('value'=>'SATELLITE','text'=>'Satellit'),array('value'=>'HYBRID','text'=>'Hybrid'),array('value'=>'TERRAIN','text'=>'Terrain')),'position'=>'right'),
	'monochrome' => array('label'=>'nur in Graustufen','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'left'),
	'hue' => array('label'=>'Karte einfärben (#hex)','type'=>'colorfield','position'=>'left'),
	'scrollwheel' => array('label'=>'Maus-Scolling','type'=>'radio','options'=>array(array('value'=>'0','text'=>'{LANG_CMM_NO}'),array('value'=>'1','text'=>'{LANG_CMM_YES}')),'position'=>'right'),
	'address' => array('label'=>'Adressen oder Koordinaten der Marker (ein Eintrag pro Zeile)','description'=>'Geben Sie pro Zeile einen Marker ein, wahlweise als Adresse oder Koordinaten.<br>Adresse: Straße 12, 12345 Ort<br>Koordinaten: 51.4990791,10.791581','type'=>'textarea','datatype'=>'text','attribs'=>array('rows'=>4),'position'=>'bottom'),
	'title' => array('label'=>'Titel der Marker (ein Eintrag pro Zeile)','type'=>'textarea','datatype'=>'text','attribs'=>array('rows'=>4),'position'=>'bottom'),
	'info' => array('label'=>'Info-Meldung der Marker (ein Eintrag pro Zeile)','type'=>'codearea','datatype'=>'text','attribs'=>array('rows'=>4),'position'=>'bottom'),
	'icon' => array('label'=>'optionale Marker-Grafik (relativer Pfad ab aktuellem Template Verzeichnis)','type'=>'textfield','datatype'=>'text','attribs'=>array('rows'=>4),'position'=>'bottom','shy'=>1),
	'fitBounds' => array('label'=>'Kartenausschnitt','type'=>'checkbox','options'=>array(array('value'=>'1','text'=>'{LANG_CMM_YES}')),'text'=>'um mehrere Marker zentrieren','position'=>'right'),
	'cacheTimeout' => array('label'=>'{LANG_CMM_CACHE_TIMEOUT}','type'=>'textfield','datatype'=>'int','position'=>'bottom','shy'=>1)
	);
/* FIELDSET END */

// Set customer group
$params['CustomerCustomergroupID'] = isset($GLOBALS['CustomergroupUID']) ? $GLOBALS['CustomergroupUID'] : 0;

// Set language
$params['LID'] = isset($GLOBALS['LanguageUID']) ? $GLOBALS['LanguageUID'] : 1;

// Merge params and pluginParams
$params = CMM_mergePluginParams($params,$pluginParams);

// Set global var to require maps api
$GLOBALS['googleMapsApi'] = true;

// Inhalt ausgeben
$params['title'] = explode('<nl>',$params['title']);
$params['address'] = explode('<nl>',$params['address']);
$params['info'] = explode("<nl>",$params['info']);
$countTitles = sizeof($params['title']);
$markers = array();
for($mt=0; $mt<$countTitles; $mt++)
	{
	!isset($params['title'][$mt]) ? $params['title'][$mt]='' : '';
	!isset($params['address'][$mt]) ? $params['address'][$mt]='' : '';
	!isset($params['info'][$mt]) ? $params['info'][$mt]='' : '';
	$markers[$mt] = array('title'=>$params['title'][$mt],'address'=>$params['address'][$mt],'info'=>$params['info'][$mt],'icon'=>$params['icon']);
	}

// Collect data for template
$view = array();
$view['params'] = $params;
$view['markers'] = $markers;
$view['ContentUID'] = $params['ContentUID'];

// Cache settings
$cacheSettings = array();
$cacheSettings['module'] = 'CMM_Contents:GoogleMap';
$cacheSettings['page'] = $GLOBALS['PageUID'];
$cacheSettings['params'] = $params;
$cacheSettings['lastmod'] = 0;
$cacheSettings['timeout'] = $params['cacheTimeout'];

// Init template-object
$pluginObj = new Template;
$pluginObj->templateFile = $params['templateFile'];
$pluginObj->cache = $cacheSettings;
$pluginObj->input = $view;

// Render template
$pluginContent = $pluginObj->templateIt();

unset($params);
?>
