<?PHP
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////
// Plugin fuer eine einfache Galerie (Bildverzeichnis)   //
///////////////////////////////////////////////////////////
// V 1.0 First release
// V 1.1.0 Intergration Slider und Gallery
// V 1.1.1 Added propperties border and shadow
// V 1.1.2 File-Ext made case insensitive
// V 1.1.3 Tennzeichen fuer caption geaendert br -> nl
// V 1.1.4 Some mods (fieldtypes, caption-breaks, ...)
// V 1.1.5 added params for limit and image-order
// V 1.2.0 Cache added an reorganized output vars
// V 1.2.1 Input field options mod.
///////////////////////////////////////////////////////////
/* PARAMS START - Marker-Comments required! */
$params = array(
	'templateFile'=>'CMM_Pluginset/template/html/MiniGallery.html',
	'path'=>'',
	'type'=>'Default',
	'width'=>'120',
	'height'=>'120',
	'limit'=>'',
	'zoom'=>'0',
	'border'=>'0',
	'shadow'=>'0',
	'order'=>'default',
	'alt'=>'',
	'caption'=>'',
	'cacheTimeout'=>86400
	);
/* PARAMS END */

/* FIELDSET START - Marker-Comments required! */
$fieldset = array(
	'templateFile' => array('label'=>'HTML-Template-Datei','type'=>'textfield','datatype'=>'text','position'=>'bottom','shy'=>1),
	'path' => array('label'=>'Pfad zum Bildverzeichnis (relativ ab ROOT)','type'=>'dirfield','datatype'=>'text','position'=>'top'),
	'type' => array('label'=>'Galerie-Typ','description'=>'Bei den Typen "Raster", "Galerie" und "Masonry" wird die Bildgröße für die Thumbnails verwendet. Beim Typ "Slider" gilt die Bildgröße für der Größe der Bilder im Slider.','type'=>'select','disablenone'=>1,'options'=>array(array('value'=>'Default','text'=>'Gitter'),array('value'=>'Slider','text'=>'Slider'),array('value'=>'Gallery','text'=>'Galerie'),array('value'=>'Masonry','text'=>'Masonry')),'position'=>'left'),
	'width' => array('label'=>'Bild-Breite (px)','description'=>'Erfolg keine Angabe wird der Standardwert "120" verwendet.<br>Durch die Angabe "0" werden die originalen Bildproportionen erhalten.','type'=>'textfield','datatype'=>'int','position'=>'left'),
	'height' => array('label'=>'Bild-Höhe (px)','description'=>'Erfolg keine Angabe wird der Standardwert "120" verwendet.<br>Durch die Angabe "0" werden die originalen Bildproportionen erhalten.','type'=>'textfield','datatype'=>'int','position'=>'left'),
	'limit' => array('label'=>'Max. Anzahl Bilder','type'=>'textfield','datatype'=>'int','position'=>'left'),
	'zoom' => array('label'=>'Click-Zoom','type'=>'checkbox','options'=>array(array('value'=>'1','text'=>'{LANG_CMM_YES}')),'text'=>'aktivieren','position'=>'right'),
	'border' => array('label'=>'Rahmen','type'=>'checkbox','options'=>array(array('value'=>'1','text'=>'{LANG_CMM_YES}')),'text'=>'aktivieren','position'=>'right'),
	'shadow' => array('label'=>'Schatten','type'=>'checkbox','options'=>array(array('value'=>'1','text'=>'{LANG_CMM_YES}')),'text'=>'aktivieren','position'=>'right'),
	'order' => array('label'=>'Sortierung','type'=>'radio','disablenone'=>1,'options'=>array(array('value'=>'default','text'=>'Normal (natsort)'),array('value'=>'reverse','text'=>'Umgekehrt (reverse)'),array('value'=>'shuffle','text'=>'Zufall (shuffle)')),'position'=>'right'),
	'alt' => array('label'=>'Alternativ-Text der Bilder (ein Eintrag pro Zeile)','type'=>'textarea','attribs'=>array('rows'=>'10'),'datatype'=>'text','position'=>'bottom'),
	'caption' => array('label'=>'Untertitel der Bilder (ein Eintrag pro Zeile)','type'=>'textarea','attribs'=>array('rows'=>'10'),'datatype'=>'text','position'=>'bottom'),
	'cacheTimeout' => array('label'=>'{LANG_CMM_CACHE_TIMEOUT}','type'=>'textfield','datatype'=>'int','position'=>'bottom','shy'=>1)
	);
/* FIELDSET END */

// Set customer group
$params['CustomerCustomergroupID'] = isset($GLOBALS['CustomergroupUID']) ? $GLOBALS['CustomergroupUID'] : 0;

// Set language
$params['LID'] = isset($GLOBALS['LanguageUID']) ? $GLOBALS['LanguageUID'] : 1;

// Merge params and pluginParams
$params = CMM_mergePluginParams($params,$pluginParams);

// If path is set an valid
$galleryImages = array();
if(!empty($params['path']) && file_exists(CMM_ROOT_DIR.$params['path']))
	{
	// Read images from folder
	$files = glob($params['path'].'{*.jpg,*.JPG,*.gif,*.GIF,*.png,*.PNG}', GLOB_BRACE);

	// Change image order
	if(empty($params['order']) || $params['order'] == 'default')
		{ natsort($files); }
	else if($params['order'] == 'reverse')
		{ natsort($files); $files = array_reverse($files); }
	else if($params['order'] == 'shuffle')
		{ shuffle($files); }

	// Set limit
	if(!empty($params['limit']) && $params['limit'] > 0)
		{ $files = array_slice($files,0,$params['limit']); }

	// Alt-Text und Untertitel splitten
	$params['alt'] = explode('<nl>',$params['alt']);
	$params['caption'] = explode('<nl>',$params['caption']);

	// Images-String für template-Engine konstruieren
	$galleryImages = array();
	$imageCounter = 0;
	foreach($files as $file)
		{
		$tag = '<img src="'.basename($file).'"'.
			(isset($params['alt'][$imageCounter]) ? ' alt="'.$params['alt'][$imageCounter].'"' : '').
			(isset($params['caption'][$imageCounter]) ? ' caption="'.$params['caption'][$imageCounter].'"' : '').
			' zoom="'.$params['zoom'].'" border="'.$params['border'].'" shadow="'.$params['shadow'].'" cache="1" path="'.$params['path'].'" imageset="gallery'.md5($params['path']).'"'.
			(!empty($params['width']) ? ' width="'.$params['width'].'"' : '').
			(!empty($params['height']) ? ' height="'.$params['height'].'"' : '').' />';
		$imageCounter++;
		$galleryImages[] = $tag;
		}
	$galleryImages = implode('',$galleryImages);
	//var_dump($galleryImages);
	}

// Collect data for template
$view = array();
$view['params'] = $params;
$view['images']= $galleryImages;
$view['ContentUID'] = $params['ContentUID'];

// Cache settings
$cacheSettings = array();
$cacheSettings['module'] = 'CMM_Contents:MiniGallery';
$cacheSettings['page'] = $GLOBALS['PageUID'];
$cacheSettings['params'] = $params;
$cacheSettings['lastmod'] = 0;
$cacheSettings['timeout'] = $params['cacheTimeout'];

// Init template-object
$pluginObj = new Template;
$pluginObj->templateFile = $params['templateFile'];
$pluginObj->cache = $cacheSettings;
$pluginObj->input = $view;

// Render template
$pluginContent = $pluginObj->templateIt();

unset($params);
?>
