<?PHP
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 Nicolas Berg
*  All rights reserved
*
*  This script is part of the CMM3 Content-Management-System.
*  CMM3 is provided only under a commercial license until now.
*  Maybe we will add a free license in future.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

///////////////////////////////////////////////////////////////////
// V 1.0 First release fuer CMM3
// [...]
// V 1.3.1 include class.navi.php
// V 1.3.2 Login/Logout mod.
// V 1.3.3 Language include mod.
// V 1.3.4 Changed https detection
// V 1.3.5 Cache class included
// V 1.3.6 Removes file globals.php
// V 1.3.6 Mod default CSS/JS file output
// V 1.4 Global mods for CMM3 V6
///////////////////////////////////////////////////////////////////

mb_internal_encoding("UTF-8");
ini_set('display_errors', true);
error_reporting(7); // 7 = Warnungen, 8 = alle

$timestamp = microtime();
$CONFIG = array();
$GLOBALS['isFrontend'] = true;

// Get loaction of current script
$rootDir = rtrim(dirname($_SERVER['SCRIPT_FILENAME']),'/\\').'/';
$rootUrl = ((empty($_SERVER['HTTPS']) || stristr($_SERVER['HTTPS'],'off')) ? 'http' : 'https').'://'.rtrim(dirname($_SERVER['HTTP_HOST'].$_SERVER['PHP_SELF']),'/\\').'/';
$cmmPath = str_replace($rootUrl,'',((empty($_SERVER['HTTPS']) || stristr($_SERVER['HTTPS'],'off')) ? 'http' : 'https').'://'.$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI']);
stristr($cmmPath,'?') ? $cmmPath=substr($cmmPath,0,strpos($cmmPath,'?')) : '';
$GLOBALS['CMM_ROOT_DIR'] = $rootDir;
$GLOBALS['CMM_ROOT_URL'] = $rootUrl;
$GLOBALS['CMM_PATH'] = $cmmPath;
$GLOBALS['CMM_PATH_ARRAY'] = explode('/',$cmmPath);
define('CMM_ROOT_DIR',$rootDir);
define('CMM_ROOT_URL',$rootUrl);
define('CMM_PATH',$cmmPath);


///////////////////////////////////////////////////////////////////
// INCLUDES LADEN                                                //
///////////////////////////////////////////////////////////////////
require_once(CMM_ROOT_DIR.'CMM/functions/functions-common.php');
require_once(CMM_ROOT_DIR.'CMM/functions/functions-web.php');
require_once(CMM_ROOT_DIR.'CMM/functions/functions-web-sql.php');
require_once(CMM_ROOT_DIR.'CMM/functions/functions-web-gui.php');

require_once(CMM_ROOT_DIR.'CMM/classes/class.template.php');
require_once(CMM_ROOT_DIR.'CMM/classes/class.page.php');
require_once(CMM_ROOT_DIR.'CMM/classes/class.navi.php');
require_once(CMM_ROOT_DIR.'CMM/classes/class.mailform.php');
require_once(CMM_ROOT_DIR.'CMM/classes/class.image.php');
require_once(CMM_ROOT_DIR.'CMM/classes/class.plugin.php');
require_once(CMM_ROOT_DIR.'CMM/classes/class.cache.php');

require_once(CMM_ROOT_DIR.'CMM/incl/connect.php');
require_once(CMM_ROOT_DIR.'CMM/incl/session-start.php');
require_once(CMM_ROOT_DIR.'CMM/incl/session.php');

// Include config
require_once(CMM_ROOT_DIR.'config.php');
CMM_connectDB();
CMM_getCustomConfig();
require_once(CMM_ROOT_DIR.'CMM/config.php');
require_once(CMM_ROOT_DIR.'CMM/structure.php');
if(!empty($CUSTOM['CMM']))
	{ $CONFIG['CMM'] = array_replace_recursive($CONFIG['CMM'],$CUSTOM['CMM']); }

///////////////////////////////////////////////////////////////////
// INIT FUNCTIONS                                                //
///////////////////////////////////////////////////////////////////
CMM_checkEnv();
CMM_setGlobals();
CMM_setConstants();
CMM_loginLogout();


///////////////////////////////////////////////////////////////////
// SET COMPRESSION                                               //
///////////////////////////////////////////////////////////////////
// Check if the browser supports gzip encoding, HTTP_ACCEPT_ENCODING 
if ($CONFIG['CMM']['config']['outputGzipByPhp'] == 1 && stristr($_SERVER['HTTP_ACCEPT_ENCODING'],'gzip') && function_exists('ob_gzhandler')) 
	{ ob_start("ob_gzhandler"); }
else
	{ ob_start(); }


///////////////////////////////////////////////////////////////////
// SET PAGE DATA                                                 //
///////////////////////////////////////////////////////////////////
// If db-connection is ready
if(CMM_DB_STATUS == 3)
	{
	// Get current language
	CMM_getCurrentLanguage();
	// echo $GLOBALS['LanguageUID'];
	// echo $GLOBALS['LanguageCode'];

	// Include language files
	CMM_includeLanguageFile('CMM');
	CMM_includeLanguageFile('template');

	// Get current usergroup
	CMM_getCurrentCustomergroup();
	// echo $GLOBALS['CustomergroupUID'];

	// Get current page
	CMM_getCurrentPage();
	// echo $GLOBALS['PageUID'];
	// echo $GLOBALS['PageAlias'];
	// echo $GLOBALS['PageTail'];

	////////////////////////////////////////

	// GET MODULES AND JS/CSS-LIBS OF INSTALLED MODULES
	$modulesExisting = CMM_getModulesExisting();
	$modulesInstalled = CMM_getModulesInstalled($modulesExisting);
	foreach($modulesInstalled as $module)
		{
		// Include config (basic module is already included)
		if($module != 'CMM')
			{ include_once(CMM_ROOT_DIR.$module.'/config.php'); }
	
		// Set CSS-libs
		if(!empty($CONFIG[$module]['FE']['include']['CSS']))
			{ CMM_addGlobalCSS($CONFIG[$module]['FE']['include']['CSS'],'head'); }
	
		// Set JS-libs
		if(!empty($CONFIG[$module]['FE']['include']['JS']))
			{ CMM_addGlobalJS($CONFIG[$module]['FE']['include']['JS'],'foot'); }
		}

	////////////////////////////////////////

	// Create output
	if(!empty($GLOBALS['PageUID']))
		{
		// Init page object
		$page = new Page;

		// Set standard-template and send headers
		if(stristr($_SERVER['REQUEST_URI'],'.rss'))
			{
			$page->templateFile = 'CMM_CMM_page_rss.html';
			header('Content-Type: application/rss+xml; charset=utf-8');
			}
		else if(stristr($_SERVER['REQUEST_URI'],'.xml'))
			{
			$page->templateFile = 'CMM_CMM_page_xml.html';
			header('Content-Type: application/xml; charset=utf-8');
			}
		else
			{
		//	$page->templateFile = 'CMM_CMM_page_default.html';
			header('Content-Type: text/html; charset=utf-8');
			}

		// Render page
		$output = $page->createPage();

		// Remove comments
		if($CONFIG['CMM']['config']['outputRemoveComments'] == 1)
			{ $output = CMM_removeComments($output); }

		// Remove white-spaces
		if($CONFIG['CMM']['config']['outputRemoveWhitespaces'] == 1 && !stristr($_SERVER['REQUEST_URI'],'.rss') && !stristr($_SERVER['REQUEST_URI'],'.xml'))
			{ $output = CMM_removeWhitespaces($output); }

		// Calculate and insert render-time of page
		$rendertime = (microtime() - $timestamp);
		$output = str_replace('{$rendertime}',$rendertime,$output);

		echo $output;
		}
	else
		{
		// Output error page
		echo CMM_createErrorPage(array('title'=>LANG_CMM_ERROR,'text'=>LANG_CMM_ERROR_ROOT_PAGE));
		}
	}
?>